@@ -1,23 +1,11 @@
 #!/usr/bin/env python
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and/or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: Editra.py                                                             #
+# Purpose: Implements Editras App object and the Main method                  #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -29,16 +17,12 @@
 #   This module defines the Editra Application object and the Main method  #
 # for running Editra.                                                      #
 #                                                                          #
-# METHODS:                                                                 #
-#   L{Editra} Application core object                                      #
-#   L{Main} Main runtime procedure                                         #
-#                                                                          #
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 549 2007-09-28 07:55:35Z CodyPrecord $"
-__revision__ = "$Revision: 549 $"
+__svnid__ = "$Id: Editra.py 49556 2007-10-31 13:03:26Z CJP $"
+__revision__ = "$Revision: 49556 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -62,6 +46,7 @@ import extern.events as events
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
+
 class Editra(wx.App, events.AppEventHandlerMixin):
     """The Editra Application Object
     @see: L{wx.App}
@@ -81,6 +66,9 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         self._windows = dict()
         self._pluginmgr = plugin.PluginManager()
 
+        self._log("[app][info] Registering Editra's ArtProvider")
+        wx.ArtProvider.PushProvider(ed_art.EditraArt())
+
     def OnInit(self):
         """Initialize the Editor
         @note: this gets called before __init__
@@ -89,16 +77,15 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """
         self.SetAppName(ed_glob.PROG_NAME)
         self._log = dev_tool.DEBUGP
-        self._log("[app][info] Registering Editra's ArtProvider")
-        wx.ArtProvider.PushProvider(ed_art.EditraArt())
         self._log("[app][info] Editra is Initializing")
+
         if Profile_Get('REPORTER', 'bool', True):
             sys.excepthook = dev_tool.ExceptionHook
 
         #---- Bind Events ----#
         self.Bind(wx.EVT_ACTIVATE_APP, self.OnActivate)
         self.Bind(wx.EVT_MENU, self.OnNewWindow, id=ed_glob.ID_NEW_WINDOW)
-
+ 
         return True
 
     def Exit(self, force=False):
@@ -128,6 +115,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         for window in self._windows:
             if not hasattr(self._windows[window][0], '__name__'):
                 continue
+
             if self._windows[window][0].__name__ == "MainWindow":
                 return self._windows[window][0]
         return None
@@ -174,7 +162,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
     def GetPluginManager(self):
         """Returns the plugin manager used by this application
         @return: Apps plugin manager
-        @see: L{plugin.py}
+        @see: L{plugin}
 
         """
         return self._pluginmgr
@@ -209,16 +197,17 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """Macintosh Specific code for opening files that are associated
         with the editor and double clicked on after the editor is already
         running.
-        @param: file path string
+        @param filename: file path string
         @postcondition: if L{MainWindow} is open file will be opened in notebook
         
         """
         window = self.GetTopWindow()
-        if window != None and window.__name__ == "MainWindow":
+        if getattr(window, '__name__', '') == "MainWindow":
             try:
                 window.DoOpen(wx.ID_ANY, util.DecodeString(filename))
                 self._log("[app][info] MacOpenFile Fired")
-            finally:
+            except Exception, msg:
+                self._log("[app][err] Failed to open drop file: %s" % str(msg))
                 pass
         else:
             pass
@@ -243,6 +232,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         e_id = -1
         if evt:
             e_id = evt.GetId()
+
         if e_id == ed_glob.ID_EXIT:
             # First loop is to ensure current top window is
             # closed first
@@ -283,6 +273,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         if caller:
             pos = caller.GetPosition()
             frame.SetPosition((pos.x + 22, pos.y + 22))
+
         self.RegisterWindow(repr(frame), frame, True)
         self.SetTopWindow(frame)
         if isinstance(fname, basestring) and fname != u'':
@@ -337,6 +328,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
             if not len(self._windows):
                 self._log("[app][info] No more open windows shutting down")
                 self.Exit()
+
             if name == repr(cur_top):
                 found = False
                 for key in self._windows:
@@ -348,6 +340,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
                             continue
                         found = True
                         break
+
                 if not found:
                     self._log("[app][info] No more top windows exiting app")
                     self.UnLock()
@@ -391,26 +384,45 @@ def InitConfig():
             # upgrade earlier profiles to current 
             if len(pstr) > 3 and pstr[-2:] == "pp":
                 pstr = pstr + u'b'
-            profiler.Profile().LoadDefaults()
+
+            # Load and update profile
+            profiler.Profile().Load(pstr)
+            profiler.Profile().Update()
+
+            ## Force some default values to be set on upgrade
             if wx.Platform == '__WXGTK__':
                 Profile_Set('ICONS', 'Default')
-            profiler.Profile().Write(pstr)  # Write out defaults
-            profiler.Profile().Load(pstr)   # Test reload profile
+            else:
+                Profile_Set('ICONS', 'Tango')
+
+            # NOTE: currently turned off by default due to performance issues
+            if wx.Platform == '__WXMAC__':
+                Profile_Set('WRAP', False)
+
+            # Write out updated profile
+            profiler.Profile().Write(pstr)
+
             # When upgrading from an older version make sure all
             # config directories are available.
             for cfg in ["cache", "styles", "plugins", "profiles"]:
                 if not util.HasConfigDir(cfg):
                     util.MakeConfigDir(cfg)
+
             profile_updated = True
     else:
+        # Fresh install
         util.CreateConfigDir()
+
+    # Set debug mode
     if 'DEBUG' in Profile_Get('MODE'):
         ed_glob.DEBUG = True
+
+    # Resolve resource locations
     ed_glob.CONFIG['CONFIG_DIR'] = util.ResolvConfigDir("")
     ed_glob.CONFIG['PIXMAPS_DIR'] = util.ResolvConfigDir("pixmaps")
     ed_glob.CONFIG['SYSPIX_DIR'] = util.ResolvConfigDir("pixmaps", True)
     ed_glob.CONFIG['PLUGIN_DIR'] = util.ResolvConfigDir("plugins")
-    ed_glob.CONFIG['THEME_DIR'] = util.ResolvConfigDir(os.path.join("pixmaps", \
+    ed_glob.CONFIG['THEME_DIR'] = util.ResolvConfigDir(os.path.join("pixmaps",
                                                                     "theme"))
     ed_glob.CONFIG['LANG_DIR'] = util.ResolvConfigDir("locale", True)
     ed_glob.CONFIG['STYLES_DIR'] = util.ResolvConfigDir("styles")
@@ -420,6 +432,7 @@ def InitConfig():
     if not util.HasConfigDir("cache"):
         util.MakeConfigDir("cache")
     ed_glob.CONFIG['CACHE_DIR'] = util.ResolvConfigDir("cache")
+
     return profile_updated
 
 #--------------------------------------------------------------------------#
@@ -430,10 +443,9 @@ def Main():
               an instance of Editra and starts the main loop.
 
     """
-    shortopts = "dhv"
-    longopts = ['debug', 'help', 'oldPath=', 'version']
     try:
-        opts, args = getopt.getopt(sys.argv[1:], shortopts, longopts)
+        opts, args = getopt.getopt(sys.argv[1:], "dhv", 
+                                   ['debug', 'help', 'oldPath=', 'version'])
     except getopt.GetoptError, msg:
         dev_tool.DEBUGP("[main][err] %s" % str(msg))
         opts = list()
@@ -445,6 +457,7 @@ def Main():
             oldpath = opts[0][1]
             os.chdir(oldpath)
             opts.pop(0)
+
         if True in [x[0] in ['-h', '--help'] for x in opts]:
             print ("Editra - %s - Developers Text Editor\n"
                    "Cody Precord (2005-2007)\n\n"
@@ -460,10 +473,12 @@ def Main():
                    "  --version  Print version number and exit\n"
                   ) % ed_glob.VERSION
             exit(0)
+
         if True in [x[0] in ['-v', '--version'] for x in opts]:
             print "%s - v%s - Developers Editor" % (ed_glob.PROG_NAME, \
                                                     ed_glob.VERSION)
             exit(0)
+
         if True in [x[0] in ['-d', '--debug'] for x in opts]:
             ed_glob.DEBUG = True
 
@@ -472,14 +487,10 @@ def Main():
 
     # 1. Create Application
     dev_tool.DEBUGP("[main_info] Initializing Application...")
-    if Profile_Get('MODE') == u"GUI_DEBUG":
-        editra_app = Editra(True)
-    else:
-        editra_app = Editra(False)
+    editra_app = Editra(Profile_Get('MODE') == u"GUI_DEBUG")
 
     # 2. Initialize the Language Settings
-    langid = ed_i18n.GetLangId(Profile_Get('LANG'))
-    the_locale = wx.Locale(langid)
+    the_locale = wx.Locale(ed_i18n.GetLangId(Profile_Get('LANG')))
     the_locale.AddCatalogLookupPathPrefix(ed_glob.CONFIG['LANG_DIR'])
     the_locale.AddCatalog(ed_glob.PROG_NAME)
     language = gettext.translation(ed_glob.PROG_NAME, 
@@ -499,24 +510,31 @@ def Main():
 
     # Splash a warning if version is not a final version
     if Profile_Get('APPSPLASH') and int(ed_glob.VERSION[0]) < 1:
-        splash_img = wx.ArtProvider.GetBitmap(str(ed_glob.ID_APP_SPLASH), 
-                                              wx.ART_OTHER)
+        import edimage
+        splash_img = edimage.getsplashwarnBitmap()
         splash = wx.SplashScreen(splash_img, wx.SPLASH_CENTRE_ON_PARENT | \
                                  wx.SPLASH_NO_TIMEOUT, 0, None, wx.ID_ANY)
         splash.Show()
-        wx.FutureCall(3000, splash.Destroy)
 
     frame = ed_main.MainWindow(None, wx.ID_ANY, Profile_Get('WSIZE'), 
                                ed_glob.PROG_NAME)
     editra_app.RegisterWindow(repr(frame), frame, True)
     editra_app.SetTopWindow(frame)
+
+    # Load Session Data
+    # But not if there are command line args for files to open
+    if Profile_Get('SAVE_SESSION', 'bool', False) and not len(args):
+        frame.GetNotebook().LoadSessionFiles()
+
     frame.Show(True)
     wx.PostEvent(frame, wx.ActivateEvent(wx.wxEVT_ACTIVATE, True))
 
+    if 'splash' in locals():
+        splash.Destroy()
+
     for arg in args:
         try:
-            if not os.path.isabs(arg):
-                arg = os.path.abspath(arg)
+            arg = os.path.abspath(arg)
             frame.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN, util.DecodeString(arg))
         except IndexError:
             dev_tool.DEBUGP("[main][err] IndexError on commandline args")
@@ -528,4 +546,3 @@ def Main():
 #-----------------------------------------------------------------------------#
 if __name__ == '__main__':
     Main()
-
