@@ -1,31 +1,19 @@
-############################################################################
-#    Copyright (C) 2007 by Cody Precord                                    #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: dev_tool.py                                                           #
+# Purpose: Provides logging and error tracking utilities                      #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
-""" Development Tools 
+""" Editra Development Tools 
 @author: Cody Precord
 @summary: Utility function for debugging the editor
 
 """
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: dev_tool.py 549 2007-09-28 07:55:35Z CodyPrecord $"
-__revision__ = "$Revision: 549 $"
+__svnid__ = "$Id: dev_tool.py 49427 2007-10-25 13:37:59Z CJP $"
+__revision__ = "$Revision: 49427 $"
 
 import os
 import sys
@@ -41,18 +29,28 @@ _ = wx.GetTranslation
 #-----------------------------------------------------------------------------#
 # General Debuging Helper Functions
 
-def DEBUGP(statement, mode="std", log_lvl="none"):
-    """Used to print Debug Statements
-    1. Modes of operation:
-       - std = stdout
-       - log = writes to log file
+def DEBUGP(statement, mode="std"):
+    """Used to print Debug Statements. Statements should be formated as 
+    follows:
+    @note: mode variable and message type information in message string are
+           not currently used but will be in the future for organizing the
+           debug levels.
+
+        1. Formatting
+            - [object/module name][msg_type] msg
+
+        2. Modes of operation:
+            - std = stdout
+            - log = writes to log file
     
-    2. Log Levels:
-       - none = used with stdout
-       - INFO = Basic Information
-       - WARN = Could be a potential problem
-       - ERROR = Serious problem has occured
-       
+        3. Message Type:
+            - [err]  : Notes an exception or error condition
+            - [warn] : Notes a error that is not severe
+            - [info] : General information message
+            - [evt]  : Some sort of event related message
+
+    @example: [ed_main][err] File failed to open
+
     """
     # Turn off normal debugging messages when not in Debug mode
     if mode == "std" and not ed_glob.DEBUG:
@@ -65,7 +63,7 @@ def DEBUGP(statement, mode="std", log_lvl="none"):
 
     # Format Statement
     statement = unicode(statement)
-    s_lst = statement.split(u"\n")
+    s_lst = [msg.strip() for msg in statement.split(u"\n") if len(msg.strip())]
     
     if mode == "std":
         for line in s_lst:
@@ -115,7 +113,7 @@ def EnvironmentInfo():
     ftypes = list()
     for key, val in Profile().iteritems():
         # Exclude "private" information
-        if key == 'MYPROFILE' or key.startswith('FILE'):
+        if key.startswith('FILE'):
             continue
         elif key == 'LAST_SESSION' or key == 'FHIST':
             for fname in val:
@@ -124,8 +122,8 @@ def EnvironmentInfo():
                     if ext not in ftypes:
                         ftypes.append(ext)
         else:
-            info.append(u"%s=%s" % (key, unicode(val)))
-    info.append(u"FTYPES=%s" % unicode(ftypes))
+            info.append(u"%s=%s" % (key, str(val)))
+    info.append(u"FTYPES=%s" % str(ftypes))
     info.append("#---- End Runtime Variables ----#")
 
     return u"\n".join(info)
@@ -141,6 +139,11 @@ def ExceptionHook(exctype, value, trace):
     # Ensure that error gets raised to console as well
     print ftrace
 
+    # If abort has been set and we get here again do a more forcefull shutdown
+    global ABORT
+    if ABORT:
+        exit()
+
     # Prevent multiple reporter dialogs from opening at once
     if not REPORTER_ACTIVE and not ABORT:
         ErrorDialog(ftrace)
@@ -311,7 +314,9 @@ class ErrorDialog(wx.Dialog):
             webbrowser.open(msg)
             self.Close()
         elif e_id == wx.ID_ABORT:
+            global ABORT
             ABORT = True
+            # Try a nice shutdown first time through
             wx.CallLater(500, wx.GetApp().OnExit, 
                          wx.MenuEvent(wx.wxEVT_MENU_OPEN, ed_glob.ID_EXIT),
                          True)
