@@ -1,44 +1,29 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: ed_cmdbar.py                                                          #
+# Purpose: Creates a small slit panel that holds small controls for searching #
+#          and other actions.                                                 #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
 # FILE: ed_cmdbar.py                                                       #
-# @author: Cody Precord                                                    #
+# AUTHOR: Cody Precord                                                     #
 # LANGUAGE: Python                                                         #
-# @summary:                                                                #
+# SUMMARY:                                                                 #
 #    This class creates a custom panel that can hide and show different    #
 # controls based an id value. The panel is generally between 24-32 pixels  #
 # in height but can grow to fit the controls inserted in it. The           #
 # the background is painted with a gradient using system defined colors.   #
 #                                                                          #
-# METHODS:
-#
-#
-#
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: ed_cmdbar.py 488 2007-09-19 12:14:15Z CodyPrecord $"
-__revision__ = "$Revision: 488 $"
+__svnid__ = "$Id: ed_cmdbar.py 49345 2007-10-23 07:41:40Z CJP $"
+__revision__ = "$Revision: 49345 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -49,7 +34,6 @@ import wx
 import util
 import ed_glob
 import ed_search
-import ed_event
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
@@ -118,8 +102,10 @@ ID_CMD_LBL = wx.NewId()
 #-----------------------------------------------------------------------------#
 
 class CommandBar(wx.Panel):
-    """Creates a panel that houses various different command
-    controls for the editor.
+    """The command bar is a slim panel that is used to hold various small
+    controls for searching jumping to line, ect...
+    @todo: make a plugin interface and a management system for showing and
+           hiding the various conrols
 
     """
     def __init__(self, parent, id_, size=(-1, 24), style=wx.TAB_TRAVERSAL):
@@ -132,25 +118,26 @@ class CommandBar(wx.Panel):
         # Attributes
         self._parent = parent
         self._installed = False
-        self._psizer = parent.GetSizer()
-        self._h_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        self._goto_sizer = wx.BoxSizer()
-        self._search_sizer = wx.BoxSizer()
-        self._cmd_sizer = wx.BoxSizer()
+        self._sizers = dict(psizer=parent.GetSizer(),
+                            h_sizer=wx.BoxSizer(wx.HORIZONTAL),
+                            goto=wx.BoxSizer(),
+                            search=wx.BoxSizer(),
+                            cmd=wx.BoxSizer())
 
         # Install Controls
         v_sizer = wx.BoxSizer(wx.VERTICAL)
-        self._h_sizer.Add((8, 8))
+        self._sizers['h_sizer'].Add((8, 8))
         bstyle = wx.BU_EXACTFIT
         if wx.Platform == '__WXGTK__':
-            bstyle = bstyle | wx.NO_BORDER
-        self.close_b = wx.BitmapButton(self, ID_CLOSE_BUTTON, GetXBitmap(), \
-                                      size=(14, 14), style=bstyle)
-        self._h_sizer.Add(self.close_b, 0, wx.ALIGN_CENTER_VERTICAL)
-        self._h_sizer.Add((12, 12))
+            bstyle = wx.NO_BORDER
+
+        self.close_b = wx.BitmapButton(self, ID_CLOSE_BUTTON, \
+                                       GetXBitmap(), style=bstyle)
+        self._sizers['h_sizer'].Add(self.close_b, 0, wx.ALIGN_CENTER_VERTICAL)
+        self._sizers['h_sizer'].Add((12, 12))
         v_sizer.Add((2, 2))
-        self._h_sizer.Add(v_sizer)
-        self.SetSizer(self._h_sizer)
+        self._sizers['h_sizer'].Add(v_sizer)
+        self.SetSizer(self._sizers['h_sizer'])
         self.SetAutoLayout(True)
 
         # Bind Events
@@ -164,8 +151,8 @@ class CommandBar(wx.Panel):
 
         """
         wx.Panel.Hide(self)
-        if self._psizer != None:
-            self._psizer.Layout()
+        if self._sizers['psizer'] != None:
+            self._sizers['psizer'].Layout()
         self._parent.SendSizeEvent()
         self._parent.nb.GetCurrentCtrl().SetFocus()
         return True
@@ -204,12 +191,17 @@ class CommandBar(wx.Panel):
         h_sizer.AddMany([(go_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
                          ((5, 5)), (v_sizer)])
         h_sizer.Layout()
-        self._goto_sizer = h_sizer
-        self._h_sizer.Add(h_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL)
-        self._h_sizer.Layout()
+        self._sizers['goto'] = h_sizer
+        self._sizers['h_sizer'].Add(h_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL)
+        self._sizers['h_sizer'].Layout()
         return linectrl
 
     def InstallCommandCtrl(self):
+        """Install the sizer containing the command executer control
+        into the bar.
+        @return: the command control instance
+
+        """
         h_sizer = wx.BoxSizer(wx.HORIZONTAL)
         v_sizer = wx.BoxSizer(wx.VERTICAL)
         v_sizer.Add((5, 5))
@@ -222,9 +214,9 @@ class CommandBar(wx.Panel):
         h_sizer.AddMany([(cmd_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
                          ((5, 5)), (v_sizer)])
         h_sizer.Layout()
-        self._cmd_sizer = h_sizer
-        self._h_sizer.Add(h_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL)
-        self._h_sizer.Layout()
+        self._sizers['cmd'] = h_sizer
+        self._sizers['h_sizer'].Add(h_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL)
+        self._sizers['h_sizer'].Layout()
         return cmdctrl
 
     def InstallSearchCtrl(self):
@@ -238,13 +230,13 @@ class CommandBar(wx.Panel):
         v_sizer = wx.BoxSizer(wx.VERTICAL)
         t_sizer = wx.BoxSizer(wx.VERTICAL)
 
-        v_sizer.Add((5, 5))
-        ssize = wx.Size(180, 20)
+        spacer = (6, 6)
         if wx.Platform == '__WXGTK__':
-            ssize.SetHeight(24)
+            spacer = (4, 4)
+        v_sizer.Add(spacer)
         search = ed_search.EdSearchCtrl(self, ID_SEARCH_CTRL, 
-                                         menulen=5, size=ssize)
-        v_sizer.Add(search)
+                                         menulen=5, size=(180, -1))
+        v_sizer.Add(search, 0, wx.ALIGN_CENTER_VERTICAL)
         v_sizer.Add((4, 4))
         f_lbl = wx.StaticText(self, ID_FIND_LBL, _("Find") + u": ")
         ctrl_sizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -261,27 +253,25 @@ class CommandBar(wx.Panel):
         match_case = wx.CheckBox(self, ID_MATCH_CASE, _("Match Case"))
         match_case.SetValue(search.IsMatchCase())
         if wx.Platform == '__WXMAC__':
-            f_lbl.SetFont(wx.SMALL_FONT)
-            match_case.SetFont(wx.SMALL_FONT)
-            nlbl.SetFont(wx.SMALL_FONT)
-            plbl.SetFont(wx.SMALL_FONT)
+            t_sizer.Add((5, 5))
+            for win in [f_lbl, match_case, nlbl, plbl]:
+                win.SetFont(wx.SMALL_FONT)
 
-        ctrl_sizer.AddMany([(10, 10), (next_btn, 0, wx.ALIGN_CENTER_VERTICAL), 
+        ctrl_sizer.AddMany([(10, 0), (next_btn, 0, wx.ALIGN_CENTER_VERTICAL), 
                             ((3, 3)), (nlbl, 0, wx.ALIGN_CENTER_VERTICAL),
-                            ((10, 10)), (pre_btn, 0, wx.ALIGN_CENTER_VERTICAL), 
+                            ((10, 0)), (pre_btn, 0, wx.ALIGN_CENTER_VERTICAL), 
                             ((3, 3)), (plbl, 0, wx.ALIGN_CENTER_VERTICAL),
-                            ((10, 10)), (match_case)])
+                            ((10, 0)), 
+                            (match_case, 0, wx.ALIGN_CENTER_VERTICAL)])
 
-        t_sizer.Add((7, 7))
-        t_sizer.Add(ctrl_sizer)
-        t_sizer.Add((4, 4))
+        t_sizer.Add(ctrl_sizer, 0, wx.ALIGN_CENTER_VERTICAL)
 
         h_sizer.AddMany([(f_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
-                         ((5, 5)), (v_sizer), 
-                         (ctrl_sizer, 0, wx.ALIGN_CENTER_VERTICAL)])
-        self._search_sizer = h_sizer
-        self._h_sizer.Add(h_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL)
-        self._h_sizer.Layout()
+                         ((5, 5)), (v_sizer, 0, wx.ALIGN_CENTER_VERTICAL), 
+                         (t_sizer, 0, wx.ALIGN_CENTER_VERTICAL)])
+        self._sizers['search'] = h_sizer
+        self._sizers['h_sizer'].Add(h_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL)
+        self._sizers['h_sizer'].Layout()
         return search
 
     def OnCheck(self, evt):
@@ -293,14 +283,13 @@ class CommandBar(wx.Panel):
         e_id = evt.GetId()
         if e_id == ID_MATCH_CASE:
             ctrl = self.FindWindowById(e_id)
-            flag_map = { ID_MATCH_CASE : wx.FR_MATCHCASE }
             if ctrl != None:
                 search = self.FindWindowById(ID_SEARCH_CTRL)
                 if search != None:
                     if ctrl.GetValue():
-                        search.SetSearchFlag(flag_map[e_id])
+                        search.SetSearchFlag(wx.FR_MATCHCASE)
                     else:
-                        search.ClearSearchFlag(flag_map[e_id])
+                        search.ClearSearchFlag(wx.FR_MATCHCASE)
         else:
             evt.Skip()
 
@@ -335,17 +324,14 @@ class CommandBar(wx.Panel):
         gc = wx.GraphicsContext.Create(dc)
         col1 = wx.SystemSettings_GetColour(wx.SYS_COLOUR_3DFACE)
         col2 = util.AdjustColour(col1, 50)
-        col1 = util.AdjustColour(col1, -50)
+        col1 = util.AdjustColour(col1, -60)
         grad = gc.CreateLinearGradientBrush(0, 1, 0, 29, col2, col1)
-        rect = self.GetRect()
+        rect = self.GetClientRect()
 
-        # Create the background path
-        path = gc.CreatePath()
-        path.AddRectangle(0, 0, rect.width - 0.5, rect.height - 0.5)
-
-        gc.SetPen(wx.Pen(util.AdjustColour(col1, -60), 1))
+        pen_col = tuple([min(190, x) for x in util.AdjustColour(col1, -60)])
+        gc.SetPen(gc.CreatePen(wx.Pen(pen_col, 1)))
         gc.SetBrush(grad)
-        gc.DrawPath(path)
+        gc.DrawRectangle(0, 1, rect.width - 0.5, rect.height - 0.5)
 
         evt.Skip()
 
@@ -356,10 +342,10 @@ class CommandBar(wx.Panel):
 
         """
         # Install self in parent
-        if not self._installed and self._psizer != None:
+        if not self._installed and self._sizers['psizer'] != None:
             self._installed = True
-            self._psizer.Add(self, 0, wx.EXPAND)
-            self._psizer.Layout()
+            self._sizers['psizer'].Add(self, 0, wx.EXPAND)
+            self._sizers['psizer'].Layout()
             self._parent.SendSizeEvent()
         wx.Panel.Show(self)
 
@@ -371,24 +357,20 @@ class CommandBar(wx.Panel):
                 ctrl = self.InstallCtrl(id_)
 
             # First Hide everything
-            for kid in self._search_sizer.GetChildren():
-                kid.Show(False)
-
-            for kid in self._goto_sizer.GetChildren():
-                kid.Show(False)
-
-            for kid in self._cmd_sizer.GetChildren():
+            for kid in (list(self._sizers['search'].GetChildren()) + 
+                        list(self._sizers['goto'].GetChildren()) +
+                        list(self._sizers['cmd'].GetChildren())):
                 kid.Show(False)
 
             if id_ == ID_SEARCH_CTRL:
-                for kid in self._search_sizer.GetChildren():
+                for kid in self._sizers['search'].GetChildren():
                     kid.Show(True)
-                self._search_sizer.Layout()
+                self._sizers['search'].Layout()
             elif id_ == ID_LINE_CTRL:
-                for kid in self._goto_sizer.GetChildren():
+                for kid in self._sizers['goto'].GetChildren():
                     kid.Show(True)
             elif id_ == ID_CMD_CTRL:
-                for kid in self._cmd_sizer.GetChildren():
+                for kid in self._sizers['cmd'].GetChildren():
                     kid.Show(True)
 
             self.GetSizer().Layout()
@@ -396,31 +378,6 @@ class CommandBar(wx.Panel):
                 ctrl.SetFocus()
                 ctrl.SelectAll()
 
-    def Uninstall(self):
-        """Uninstalls self from parent control
-        @postcondition: removes self from parent sizer
-
-        """
-        for item in self.GetChildren():
-            item.Destroy()
-        self._psizer.Remove(self)
-        self._psizer.Layout()
-        self._parent.SendSizeEvent()
-        self.Destroy()
-
-    def UninstallCtrl(self, id_):
-        """Hides the sizer object holding the control with the passed in id
-        @param obId: id of control to remove
-        @postcondition: control is removed from bar
-
-        """
-        ctrl = self.FindWindowById(id_)
-        if ctrl != None:
-            c_sizer = ctrl.GetContainingSizer()
-            sizer = self.GetSizer()
-            sizer.Hide(c_sizer, True)
-            sizer.Layout()
-
     def UpdateIcons(self):
         """Refresh icons to current theme settings
         @postcondition: all icons are updated
@@ -431,21 +388,22 @@ class CommandBar(wx.Panel):
             t_bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_DOWN), wx.ART_MENU)
             next.SetBitmapLabel(t_bmp)
             next.SetBitmapHover(t_bmp)
+            next.Update()
             next.Refresh()
+
         pre = self.FindWindowById(ID_SEARCH_PRE)
         if pre:
             t_bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_UP), wx.ART_MENU)
             pre.SetBitmapLabel(t_bmp)
             pre.SetBitmapHover(t_bmp)
+            pre.Update()
             pre.Refresh()
 
 #-----------------------------------------------------------------------------#
 
 class CommandExecuter(wx.SearchCtrl):
-    """Part of the Vi emulation, opens a minibuffer to execute
-    EX commands with.
-    @note: based on search ctrl so we get a more astetically pleasing control
-           on wxmac.
+    """Part of the Vi emulation, opens a minibuffer to execute EX commands.
+    @note: based on search ctrl so we get the nice roudned edges on wxmac.
     
     """
     RE_GO_BUFFER = re.compile('[0-9]*[nN]{1,1}')
@@ -490,19 +448,14 @@ class CommandExecuter(wx.SearchCtrl):
 
         """
         ext = self.GetTextExtent(self.GetValue())[0]
-        cw, ch = self.GetClientSizeTuple()
-        wdiff = cw - ext
-        if ext > cw * .85:
+        curr_w, curr_h = self.GetClientSizeTuple()
+        if ext > curr_w * .85:
             max_w = self.GetParent().GetClientSize().GetWidth() * .75
-            nwidth = ext * 1.15
-            if nwidth > max_w:
-                nwidth = max_w
-            self.SetClientSize((nwidth, ch))
-        elif ((cw > ext * 1.15) and cw > 150):
-            nwidth = ext * 1.15
-            if nwidth < 150:
-                nwidth = 150
-            self.SetClientSize((nwidth, ch))
+            nwidth = min(ext * 1.15, max_w)
+            self.SetClientSize((nwidth, curr_h))
+        elif ((curr_w > ext * 1.15) and curr_w > 150):
+            nwidth = max(ext * 1.15, 150)
+            self.SetClientSize((nwidth, curr_h))
         else:
             pass
 
@@ -529,10 +482,11 @@ class CommandExecuter(wx.SearchCtrl):
         """Push a command to the stack popping as necessary to
         keep stack size less than MAX.
         @param cmd: command string to push
+        @todo: redo this to be more like the code in my terminal project
 
         """
         self._cmdstack.insert(0, cmd)
-        if len(self._cmdstack) > 25: # TODO make this configurable
+        if len(self._cmdstack) > 25:
             self._cmdstack.pop()
 
     def EditCommand(self, cmd):
@@ -549,7 +503,7 @@ class CommandExecuter(wx.SearchCtrl):
         if os.path.exists(cmd):
             frame.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN, cmd)
         else:
-            frame.nb.OpenPage(util.GetPathName(cmd) ,util.GetFileName(cmd))
+            frame.nb.OpenPage(util.GetPathName(cmd), util.GetFileName(cmd))
 
     def ExecuteCommand(self, cmd_str):
         """Interprets and executes a command then hides the control
@@ -568,11 +522,11 @@ class CommandExecuter(wx.SearchCtrl):
                 self.GoBuffer(cmd[1:])
             elif cmd == 'wq':
                 self.Quit()
-        elif cmd.startswith(u'e'):
+        elif cmd.startswith(u'e '):
             self.EditCommand(cmd)
         elif self.RE_GO_WIN.match(cmd):
             self.GoWindow(cmd)
-        elif self.RE_GO_BUFFER.match(cmd):
+        elif re.match(self.RE_GO_BUFFER, cmd):
             self.GoBuffer(cmd)
         elif cmd.isdigit() or self.RE_NGO_LINE.match(cmd):
             ctrl = frame.nb.GetCurrentCtrl()
@@ -591,7 +545,7 @@ class CommandExecuter(wx.SearchCtrl):
             return
 
         self.CommandPush(cmd_str)
-        self._curidx = 0
+        self._histidx = -1
         self.GetParent().Hide()
 
     def GetHistCommand(self, pre=True):
@@ -601,7 +555,6 @@ class CommandExecuter(wx.SearchCtrl):
 
         """
         hist_l = len(self._cmdstack) - 1
-        curr_cmd = self.GetValue()
         if pre:
             self._histidx += 1
             if self._histidx >= hist_l + 1:
@@ -622,14 +575,20 @@ class CommandExecuter(wx.SearchCtrl):
         @param cmd: cmd string [0-9]*[nN]
 
         """
-        do = cmd[0:-1]
+        count = cmd[0:-1]
         cmd = cmd[-1]
-        if do.isdigit():
-            do = int(do)
+        if count.isdigit():
+            count = int(count)
         else:
-            do = 1
+            count = 1
+
         frame = self.GetTopLevelParent()
-        for x in xrange(do):
+        numpage = frame.nb.GetPageCount()
+        for x in xrange(min(count, numpage)):
+            cpage = frame.nb.GetPageIndex(frame.nb.GetCurrentPage())
+            if (cpage == 0 and cmd == 'N') or \
+               (cpage + 1 == numpage and cmd == 'n'):
+                break
             frame.nb.AdvanceSelection(cmd == 'n')
 
     def GoWindow(self, cmd):
@@ -637,24 +596,26 @@ class CommandExecuter(wx.SearchCtrl):
         @param cmd: cmd string [0-9]*n[wW]
 
         """
-        do = cmd[0:-1]
+        count = cmd[0:-1]
         cmd = cmd[-1]
-        if do.isdigit():
-            do = int(do)
+        if count.isdigit():
+            count = int(count)
         else:
-            do = 1
+            count = 1
         wins = wx.GetApp().GetMainWindows()
         pid = self.GetTopLevelParent().GetId()
         widx = 0
-        for win in xrange(len(wins)):
-            if pid == wins[win].GetId():
+        win = 0
+        for nwin in xrange(len(wins)):
+            if pid == wins[nwin].GetId():
                 widx = pid
+                win = nwin
                 break
 
         if cmd == 'W':
-            widx = win + do
+            widx = win + count
         else:
-            widx = win - do
+            widx = win - count
 
         if widx < 0:
             widx = 0
@@ -664,10 +625,11 @@ class CommandExecuter(wx.SearchCtrl):
         wins[widx].Raise()
         wx.CallAfter(wins[widx].nb.GetCurrentCtrl().SetFocus)
 
-    # TODO fix and simplify this
     def GetNextDir(self):
         """Get the next directory path from the current cmd path
         @note: used for tab completion of cd, completion is based off cwd
+        @todo: finish working on this by starting over
+        @note: not currently used
 
         """
         cmd = self.GetValue()
@@ -734,9 +696,8 @@ class CommandExecuter(wx.SearchCtrl):
         """
 
     def OnEnter(self, evt):
-        """Get the currently entered command string and
-        execute it.
-        @status: not implemented
+        """Get the currently entered command string and execute it.
+        @postcondition: ctrl is cleared and command is executed
         
         """
         cmd = self.GetValue()
@@ -801,14 +762,15 @@ class CommandExecuter(wx.SearchCtrl):
 
 class LineCtrl(wx.SearchCtrl):
     """A custom int control for providing a go To line control
-    for the Command Bar. The get_doc parameter needs to be of
-    type callable and needs to return the document object that
-    the action is to take place in.
+    for the Command Bar.
+    @note: The control is subclassed from SearchCtrl so that it gets
+           the nice rounded edges on wxMac.
 
     """
     def __init__(self, parent, id_, get_doc, size=wx.DefaultSize):
         """Initializes the LineCtrl control and its attributes.
-        @postcondition: gotoline control is initialized
+        @param get_doc: callback method for retreiving a reference to the
+                        current document.
 
         """
         wx.SearchCtrl.__init__(self, parent, id_, "", size=size,
@@ -842,6 +804,7 @@ class LineCtrl(wx.SearchCtrl):
         val = self.GetValue()
         if not val.isdigit():
             return
+
         val = int(val) - 1
         doc = self.GetDoc()
         lines = doc.GetLineCount()
@@ -850,8 +813,5 @@ class LineCtrl(wx.SearchCtrl):
         doc.GotoLine(val)
         doc.SetFocus()
         self.GetParent().Hide()
-        evt.Skip()
 
 #-----------------------------------------------------------------------------#
-
-
