@@ -1,27 +1,14 @@
-############################################################################
-#    Copyright (C) 2007 by Cody Precord                                    #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: ed_glob.py                                                            #
+# Purpose: Global IDs/objects used throughout Editra                          #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
 # FILE: ed_glob.py                                                         #
-#                                                                          #
 # @author: Cody Precord                                                    #
 #                                                                          #
 # @summary:                                                                #
@@ -30,14 +17,12 @@
 #   globally accessable access point for all common variables in the       #
 #   project.                                                               #
 #                                                                          #
-# METHODS:                                                                 #
-#    None                                                                  #
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 525 2007-09-26 07:50:18Z CodyPrecord $"
-__revision__ = "$Revision: 525 $"
+__svnid__ = "$Id: ed_glob.py 49579 2007-11-01 08:46:15Z CJP $"
+__revision__ = "$Revision: 49579 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'SB_ROWCOL', 'VERSION', 'PROG_NAME',
             'ID_NEW', 'ID_OPEN', 'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE',
@@ -64,7 +49,7 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'SB_ROWCOL', 'VERSION', 'PROG_NAME',
 
 #---- Project Info ----#
 AUTHOR = u'Cody Precord'
-VERSION = u'0.2.0'
+VERSION = u'0.2.15'
 PROG_NAME = u'Editra'
 HOME_PAGE = u"http://editra.org"
 CONTACT_MAIL = u"staff@editra.org"
@@ -119,7 +104,7 @@ ID_SELECTALL     = wx.ID_SELECTALL
 ID_LINE_EDIT     = wx.NewId()
 ID_BOOKMARK      = wx.NewId()
 ID_ADD_BM        = wx.ID_ADD
-ID_DEL_BM        = wx.ID_DELETE
+ID_DEL_BM        = wx.ID_REMOVE
 ID_DEL_ALL_BM    = wx.NewId()
 ID_LINE_AFTER    = wx.NewId()
 ID_LINE_BEFORE   = wx.NewId()
@@ -294,4 +279,4 @@ ID_2_PROF = {
 
 # Default Plugins
 DEFAULT_PLUGINS = ("generator.Html", "generator.LaTeX", "generator.Rtf",
-                   "iface.Shelf")
+                   "iface.Shelf", "ed_theme.TangoTheme")
