@@ -1,22 +1,10 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: ed_i18n.py                                                            #
+# Purpose: I18n utilities and services                                        #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -30,18 +18,12 @@
 # GetAvailLocales: Returns a list of canonical names of available locales  #
 # GetLocaleDict: Returns a dictionary consisting of canonical names for    #
 #                keys and language ids for values.                         #
-#
-#----------------------------------                                        #
-# CLASS: LangListCombo                                                     #
-#                                                                          #
-# METHODS:
-#
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_i18n.py 525 2007-09-26 07:50:18Z CodyPrecord $"
-__revision__ = "$Revision: 525 $"
+__svnid__ = "$Id: ed_i18n.py 49415 2007-10-25 05:06:57Z CJP $"
+__revision__ = "$Revision: 49415 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -81,7 +63,7 @@ def GetLocaleDict(loc_list, opt=OPT_NO_OP):
     the key. Supplying the Option OPT_DESCRIPT will return a dictionary
     of language id's with languages description as the key.
     @param loc_list: list of locals
-    @param opt: option for configuring return data
+    @keyword opt: option for configuring return data
     @return: dict of locales mapped to wx.LANGUAGE_*** values
 
     """
@@ -105,24 +87,24 @@ def GetLangId(lang_n):
     
     """
     lang_desc = GetLocaleDict(GetAvailLocales(), OPT_DESCRIPT)
-    if(lang_desc.has_key(lang_n)):
-        return lang_desc[lang_n]
-    else:
-        return wx.LANGUAGE_DEFAULT
+    return lang_desc.get(lang_n, wx.LANGUAGE_DEFAULT)
 
 #---- Language List Combo Box----#
 class LangListCombo(wx.combo.BitmapComboBox):
     """Combines a langlist and a BitmapComboBox"""
     def __init__(self, parent, id_, default=None):
-        """Initializes the combobox
-        @postcondition: combo control containing all available locales
-                        with their flags is returned.
+        """Creates a combobox with a list of all translations for the
+        editor as well as displaying the countries flag next to the item
+        in the list.
+
+        @param default: The default item to show in the combo box
 
         """
         self.default = default
         lang_ids = GetLocaleDict(GetAvailLocales()).values()
         if wx.LANGUAGE_DEFAULT not in lang_ids:
             lang_ids.append(wx.LANGUAGE_DEFAULT)
+
         lang_items = langlist.CreateLanguagesResourceLists(langlist.LC_ONLY, \
                                                                lang_ids)
         wx.combo.BitmapComboBox.__init__(self, parent, id_, 
@@ -131,5 +113,6 @@ class LangListCombo(wx.combo.BitmapComboBox):
         for lang_d in lang_items[1]:
             bit_m = lang_items[0].GetBitmap(lang_items[1].index(lang_d))
             self.Append(lang_d, bit_m)
+
         if default:
             self.SetValue(default)
