@@ -1,22 +1,10 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: ed_menu.py                                                            #
+# Purpose: Editra's Menubar and Menu related classes                          #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -24,18 +12,15 @@
 # AUTHOR: Cody Precord                                                     #
 # LANGUAGE: Python                                                         #
 # SUMMARY:                                                                 #
-#   Provides a more convenient menu class for the editor.                  #
+#   Provides a more convenient menu class for the editor. This is however  #
+# mostly just a temporary solution until the menu creation can be reworked.#
 #                                                                          #
-# METHODS:
-#
-#
-#
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_menu.py 541 2007-09-27 08:15:58Z CodyPrecord $"
-__revision__ = "$Revision: 541 $"
+__svnid__ = "$Id: ed_menu.py 49416 2007-10-25 06:06:13Z CJP $"
+__revision__ = "$Revision: 49416 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -48,7 +33,7 @@ _ = wx.GetTranslation
 
 #--------------------------------------------------------------------------#
 
-class ED_Menu(wx.Menu):
+class EdMenu(wx.Menu):
     """Overides the default wxMenu class to make it easier to
     customize and access items.
 
@@ -210,6 +195,8 @@ class ED_Menu(wx.Menu):
         finally:
             pass
 
+#-----------------------------------------------------------------------------#
+
 class EdMenuBar(wx.MenuBar):
     """Custom menubar to allow for easier access and updating
     of menu components.
@@ -222,12 +209,12 @@ class EdMenuBar(wx.MenuBar):
 
         """
         wx.MenuBar.__init__(self, style)
-        self._filehistorymenu = ED_Menu()
+        self._filehistorymenu = EdMenu()
         self._filemenu = self.GenFileMenu()
-        self._whitespaceformatmenu = ED_Menu()
-        self._lineformatmenu = ED_Menu()
+        self._whitespaceformatmenu = EdMenu()
+        self._lineformatmenu = EdMenu()
         self._editmenu = self.GenEditMenu()
-        self._vieweditmenu = ED_Menu()
+        self._vieweditmenu = EdMenu()
         self._viewmenu = self.GenViewMenu()
         self._formatmenu = self.GenFormatMenu()
         self._settingsmenu = self.GenSettingsMenu()
@@ -242,7 +229,7 @@ class EdMenuBar(wx.MenuBar):
         @return: the default file menu
 
         """
-        filemenu = ED_Menu()
+        filemenu = EdMenu()
         filehist = self._filehistorymenu
         filemenu.Append(ed_glob.ID_NEW, _("New Tab") + u"\tCtrl+N", 
                         _("Start a new file in a new tab"))
@@ -269,7 +256,7 @@ class EdMenuBar(wx.MenuBar):
         filemenu.Append(ed_glob.ID_SAVEALL, _("Save All"), \
                         _("Save all open pages")) 
         filemenu.AppendSeparator()
-        pmenu = ED_Menu()
+        pmenu = EdMenu()
         pmenu.Append(ed_glob.ID_SAVE_PROFILE, _("Save Profile"), 
                      _("Save Current Settings to a New Profile"))
         pmenu.Append(ed_glob.ID_LOAD_PROFILE, _("Load Profile"), 
@@ -294,7 +281,7 @@ class EdMenuBar(wx.MenuBar):
         @return: the default edit menu
 
         """
-        editmenu = ED_Menu()
+        editmenu = EdMenu()
         editmenu.Append(ed_glob.ID_UNDO, _("Undo") + "\tCtrl+Z", 
                         _("Undo Last Action"))
         editmenu.Append(ed_glob.ID_REDO, _("Redo") + "\tCtrl+Shift+Z", 
@@ -310,7 +297,7 @@ class EdMenuBar(wx.MenuBar):
         editmenu.Append(ed_glob.ID_SELECTALL, _("Select All") + "\tCtrl+A", 
                         _("Select All Text in Document"))
         editmenu.AppendSeparator()
-        linemenu = ED_Menu()
+        linemenu = EdMenu()
         linemenu.Append(ed_glob.ID_LINE_AFTER, _("New Line After") + "\tCtrl+L",
                          _("Add a new line after the current line"))
         linemenu.Append(ed_glob.ID_LINE_BEFORE, 
@@ -328,7 +315,7 @@ class EdMenuBar(wx.MenuBar):
                         _("Transpose the current line with the previous one"))
         editmenu.AppendMenu(ed_glob.ID_LINE_EDIT, _("Line Edit"), linemenu,
                             _("Commands that affect an entire line"))
-        bookmenu = ED_Menu()
+        bookmenu = EdMenu()
         bookmenu.Append(ed_glob.ID_ADD_BM, _("Add Bookmark") + u"\tCtrl+B",
                         _("Add a bookmark to the current line"))
         bookmenu.Append(ed_glob.ID_DEL_BM, _("Remove Bookmark") + \
@@ -356,7 +343,7 @@ class EdMenuBar(wx.MenuBar):
         @return: the default view menu
 
         """
-        viewmenu = ED_Menu()
+        viewmenu = EdMenu()
         viewmenu.Append(ed_glob.ID_ZOOM_OUT, _("Zoom Out") + "\tCtrl+-", 
                         _("Zoom Out"))
         viewmenu.Append(ed_glob.ID_ZOOM_IN, _("Zoom In") + "\tCtrl++", 
@@ -395,7 +382,7 @@ class EdMenuBar(wx.MenuBar):
         @return: the default format menu
 
         """
-        formatmenu = ED_Menu()
+        formatmenu = EdMenu()
         formatmenu.Append(ed_glob.ID_FONT, _("Font"), _("Change Font Settings"))
         formatmenu.AppendSeparator()
         formatmenu.Append(ed_glob.ID_COMMENT, _("Comment Lines") + u"\tCtrl+1", 
@@ -445,7 +432,7 @@ class EdMenuBar(wx.MenuBar):
         @return: the default settings menu
 
         """
-        settingsmenu = ED_Menu()
+        settingsmenu = EdMenu()
         settingsmenu.Append(ed_glob.ID_AUTOCOMP, _("Auto-Completion"),
                             _("Use Auto Completion when available"), wx.ITEM_CHECK)
         settingsmenu.Append(ed_glob.ID_AUTOINDENT, _("Auto-Indent"),
@@ -466,7 +453,7 @@ class EdMenuBar(wx.MenuBar):
         @return: default tools menu
 
         """
-        toolsmenu = ED_Menu()
+        toolsmenu = EdMenu()
         toolsmenu.Append(ed_glob.ID_COMMAND, _("Editor Command") + u'\tCtrl+E',
                          _("Goto command buffer"))
         toolsmenu.Append(ed_glob.ID_KWHELPER, _("Keyword Helper") + u'\tCtrl+K', 
@@ -477,11 +464,13 @@ class EdMenuBar(wx.MenuBar):
         toolsmenu.Append(ed_glob.ID_STYLE_EDIT, _("Style Editor"), 
                          _("Edit the way syntax is highlighted"))
         toolsmenu.AppendSeparator()
-#         toolsmenu.Append(ed_glob.ID_MACRO_START, _("Record Macro"),
+#         macro = EdMenu()
+#         macro.Append(ed_glob.ID_MACRO_START, _("Record Macro"),
 #                          _("Start macro recording"))
-#         toolsmenu.Append(ed_glob.ID_MACRO_STOP, _("Stop Recording"),
+#         macro.Append(ed_glob.ID_MACRO_STOP, _("Stop Recording"),
 #                          _("Stop macro recording"))
-#         toolsmenu.Append(ed_glob.ID_MACRO_PLAY, "Play Macro", "Play Macro")
+#         macro.Append(ed_glob.ID_MACRO_PLAY, "Play Macro", "Play Macro")
+#         toolsmenu.AppendMenu(wx.NewId(), _("Macros"), macro, _("Macro Tools"))
         self.Append(toolsmenu, _("Tools"))
         return toolsmenu
 
@@ -490,7 +479,7 @@ class EdMenuBar(wx.MenuBar):
         @return: default help menu
 
         """
-        helpmenu = ED_Menu()
+        helpmenu = EdMenu()
         helpmenu.Append(ed_glob.ID_ABOUT, _("&About") + u"...", \
                         _("About") + u"...")
         helpmenu.Append(ed_glob.ID_HOMEPAGE, _("Project Homepage"), 
