@@ -1,58 +1,40 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: ed_pages.py                                                           #
+# Purpose: The main editor notebook                                           #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
 # FILE: ed_pages.py                                                        #
+# AUTHOR: Cody Precord                                                     #
 # LANGUAGE: Python                                                         #
 #                                                                          #
 # SUMMARY:                                                                 #
-# This file contains the definition of the class to handle the tabbed text #
-# controls and all functions relating to the subpanel of the MainWindow    #
-# class implimented in MainWindow.py. It will also manage and create the   #
-# editra controls for the MainWindow.                                      #
+# This file defines the notebook for containing the text controls for      #
+# for editing text in Editra. The note book is a custom sublclass of       #
+# FlatNotebook that allow for automatic page images and drag and dropping  #
+# of tabs between open editor windows. The notebook is also primarly in    #
+# charge of opening files that are requested by the user and setting up the#
+# text control to use them. For more information on the text controls used #
+# in the notebook see ed_stc.py                                            #
 #                                                                          #
-# METHODS:                                                                 #
-# - EdPages: Main instance of class. tracks page numbers                   #
-# - NewPage: Creates a new empty page w/text control                       #
-# - OpenPage: Opens a new page with an existing file                       #
-# - GoCurrentPage: Sets focus to currentyl selected page                   #
-# - OnPageChanging:                                                        #
-# - OnPageChanged: Captures page change and switches context to the        #
-#                  new page                                                #
-# - ClosePage: Closes a page in the notebook                               #
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 529 2007-09-26 09:49:01Z CodyPrecord $"
-__revision__ = "$Revision: 529 $"
+__svnid__ = "$Id: ed_pages.py 49415 2007-10-25 05:06:57Z CJP $"
+__revision__ = "$Revision: 49415 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
 import glob
-import re
 import wx
 import ed_glob
-from profiler import Profile_Get, Profile_Set
+from profiler import Profile_Get
 import ed_stc
 import syntax.synglob as synglob
 import ed_search
@@ -96,7 +78,7 @@ class EdPages(FNB.FlatNotebook):
         self._index = dict()          # image list index
 
         # Set Additional Style Parameters
-        self.SetNonActiveTabTextColour(wx.ColourRGB(long("666666", 16)))
+        self.SetNonActiveTabTextColour(wx.Colour(102, 102, 102))
         ed_icon = ed_glob.CONFIG['SYSPIX_DIR'] + u"editra.png"
         self.SetNavigatorIcon(wx.Bitmap(ed_icon, wx.BITMAP_TYPE_PNG))
 
@@ -121,13 +103,38 @@ class EdPages(FNB.FlatNotebook):
     #---- End Init ----#
 
     #---- Function Definitions ----#
-    def AddPage(self, control, title):
-        """Adds a page to the notebook
-        @param control: control panel to add to notebook
-        @param title: page title string
+    def _NeedOpen(self, path):
+        """Check if a file needs to be opened. If the file is already open in
+        the notebook a dialog will be opened to ask if the user wants to reopen
+        the file again. If the file is not open and exists or the user chooses 
+        to reopen the file again the function will return True else it will 
+        return False.
+        @param path: file to check for
 
         """
-        FNB.FlatNotebook.AddPage(self, control, title)
+        result = wx.ID_YES
+        if self.HasFileOpen(path):
+            mdlg = wx.MessageDialog(self,
+                                    _("File is already open in an existing "
+                                      "page.\nDo you wish to open it again?"),
+                                    _("Open File") + u"?", 
+                                    wx.YES_NO | wx.NO_DEFAULT | \
+                                    wx.ICON_INFORMATION)
+            result = mdlg.ShowModal()
+            mdlg.Destroy()
+            if result == wx.ID_NO:
+                for page in xrange(self.GetPageCount()):
+                    ctrl = self.GetPage(page)
+                    if path == ctrl.GetFileName():
+                        self.SetSelection(page)
+                        self.ChangePage(page)
+                        break
+        elif os.path.exists(path) and not os.path.isfile(path):
+            result = wx.ID_NO
+        else:
+            pass
+
+        return result == wx.ID_YES
 
     def GetCurrentCtrl(self):
         """Returns the control of the currently selected
@@ -161,9 +168,10 @@ class EdPages(FNB.FlatNotebook):
         """
         files = Profile_Get('LAST_SESSION')
         if files is not None:
-            for file in files:
-                if os.path.exists(file):
-                    self.OpenPage(os.path.dirname(file), os.path.basename(file))
+            for fname in files:
+                if os.path.exists(fname) and os.access(fname, os.R_OK):
+                    self.OpenPage(os.path.dirname(fname), 
+                                  os.path.basename(fname))
 
         if self.GetPageCount() == 0:
             self.NewPage()
@@ -173,19 +181,13 @@ class EdPages(FNB.FlatNotebook):
         @postcondition: a new page with an untitled document is opened
 
         """
+        self.GetTopLevelParent().Freeze()
         self.pg_num += 1
-        self.control = ed_stc.EDSTC(self, wx.ID_ANY)
+        self.control = ed_stc.EditraStc(self, wx.ID_ANY)
         self.LOG("[nb_evt] Page Creation ID: %d" % self.control.GetId())
         self.AddPage(self.control, u"Untitled - %d" % self.pg_num)
         self.SetPageImage(self.GetSelection(), str(self.control.GetLangId()))
-
-    def OpenPageType(self, page, title):
-        """A Generic Page open Function to allow pages to contain
-        any type of widget.
-        @status: currently incomplete
-
-        """
-        self.AddPage(page, title)
+        self.GetTopLevelParent().Thaw()
 
     def OpenPage(self, path, filename):
         """Open a File Inside of a New Page
@@ -195,40 +197,22 @@ class EdPages(FNB.FlatNotebook):
         """
         path2file = os.path.join(path, filename)
 
-        # If file is non-existant or not a file give up
-        if os.path.exists(path2file) and (not os.path.isfile(path2file)):
+        # Check if file needs to be opened
+        if not self._NeedOpen(path2file):
             return
 
-        # Check if file is open already and ask if it should be opened again
-        if self.HasFileOpen(path2file):
-            mdlg = wx.MessageDialog(self,
-                                    _("File is already open in an existing "
-                                      "page.\nDo you wish to open it again?"),
-                                    _("Open File") + u"?", 
-                                    wx.YES_NO | wx.NO_DEFAULT | \
-                                    wx.ICON_INFORMATION)
-            result = mdlg.ShowModal()
-            mdlg.Destroy()
-            if result == wx.ID_NO:
-                for page in xrange(self.GetPageCount()):
-                    ctrl = self.GetPage(page)
-                    if path2file == os.path.join(ctrl.dirname, ctrl.filename):
-                        self.SetSelection(page)
-                        self.ChangePage(page)
-                        break
-                return
-
         # Create new control to place text on if necessary
+        self.GetTopLevelParent().Freeze()
         new_pg = True
         if self.GetPageCount():
             if self.control.GetModify() or self.control.GetLength() or \
-               self.control.filename != u'':
-                control = ed_stc.EDSTC(self, wx.ID_ANY)
+               self.control.GetFileName() != u'':
+                control = ed_stc.EditraStc(self, wx.ID_ANY)
                 control.Hide()
             else:
                 new_pg = False
         else:
-            control = ed_stc.EDSTC(self, wx.ID_ANY)
+            control = ed_stc.EditraStc(self, wx.ID_ANY)
             control.Hide()
 
         # Open file and get contents
@@ -241,6 +225,7 @@ class EdPages(FNB.FlatNotebook):
             except (UnicodeDecodeError, IOError, OSError), msg:
                 self.LOG(("[ed_pages][err] Failed to open file %s\n"
                           "[ed_pages][err] %s") % (path2file, msg))
+
                 # File could not be opened/read give up
                 err = wx.MessageDialog(self, _("Editra could not properly "
                                                "open %s\n") \
@@ -251,25 +236,26 @@ class EdPages(FNB.FlatNotebook):
 
                 if new_pg:
                     control.Destroy()
+
+                self.GetTopLevelParent().Thaw()
                 return
 
         # Put control into page an place page in notebook
         if new_pg:
             control.Show()
             self.control = control
-        self.control.SetText(in_txt, enc)
+
         # Pass directory and file name info to control object to save reference
-        self.control.dirname, self.control.filename = path, filename
+        self.control.SetText(in_txt, enc)
+        self.control.SetFileName(path2file)
+        self.control.SetModTime(util.GetFileModTime(path2file))
         self.frame.AddFileToHistory(path2file)
-        self.control.modtime = util.GetFileModTime(path2file)
         if new_pg:
-            self.AddPage(self.control, self.control.filename)
-        else:
-            self.frame.SetTitle("%s - file://%s%s%s" % (self.control.filename, 
-                                                        self.control.dirname, 
-                                                        util.GetPathChar(), 
-                                                        self.control.filename))
-        self.SetPageText(self.GetSelection(), self.control.filename)
+            self.AddPage(self.control, filename)
+
+        self.frame.SetTitle("%s - file://%s" % (filename, 
+                                                self.control.GetFileName()))
+        self.SetPageText(self.GetSelection(), filename)
         self.LOG("[nb_evt] Opened Page: ID = %d" % self.GetSelection())
 
         # Setup Document
@@ -285,6 +271,7 @@ class EdPages(FNB.FlatNotebook):
 
         # Refocus on selected page
         self.GoCurrentPage()
+        self.GetTopLevelParent().Thaw()
 
     def GoCurrentPage(self):
         """Move Focus to Currently Selected Page.
@@ -320,25 +307,17 @@ class EdPages(FNB.FlatNotebook):
                  notebook.
 
         """
-        children = self.GetChildren()
-        controls = list()
-        for child in children:
-            if hasattr(child, '__name__') and \
-               child.__name__ == u"EditraTextCtrl":
-                controls.append(child)
-        return controls
+        return [self.GetPage(page) for page in xrange(self.GetPageCount())]
 
     def HasFileOpen(self, fpath):
         """Checks if one of the currently active buffers has
         the named file in it.
         @param fpath: full path of file to check
-        @return: whether file is currently open or not
-        @rtype: boolean
+        @return: bool indicating whether file is currently open or not
 
         """
-        ctrls = self.GetTextControls()
-        for ctrl in ctrls:
-            if fpath == os.path.join(ctrl.dirname, ctrl.filename):
+        for ctrl in self.GetTextControls():
+            if fpath == ctrl.GetFileName():
                 return True
         return False
 
@@ -402,61 +381,16 @@ class EdPages(FNB.FlatNotebook):
         """
         if wx.GetApp().IsActive() and \
            Profile_Get('CHECKMOD') and self.GetPageCount():
-            cfile = os.path.join(self.control.dirname, self.control.filename)
+            cfile = self.control.GetFileName()
             lmod = util.GetFileModTime(cfile)
-            if self.control.modtime and not lmod and not os.path.exists(cfile):
-                def PromptToReSave(cfile):
-                    """Show a dialog prompting to resave the current file
-                    @param cfile: the file in question
-
-                    """
-                    mdlg = wx.MessageDialog(self.frame,
-                                            _("%s has been deleted since its "
-                                              "last save point.\n\nWould you "
-                                              "like to save it again?") % cfile,
-                                            _("Resave File?"), 
-                                            wx.YES_NO | wx.ICON_INFORMATION)
-                    mdlg.CenterOnParent()
-                    result = mdlg.ShowModal()
-                    mdlg.Destroy()
-                    if result == wx.ID_YES:
-                        self.control.SaveFile(cfile)
-                    else:
-                        self.control.modtime = 0
-                wx.CallAfter(PromptToReSave, cfile)
-
-            elif self.control.modtime < lmod:
-                def AskToReload(cfile):
-                    """Show a dialog asking if the file should be reloaded
-                    @param cfile: the file to prompt for a reload of
-
-                    """
-                    mdlg = wx.MessageDialog(self.frame, 
-                                            _("%s has been modified by another "
-                                              "application.\n\nWould you like "
-                                              "to Reload it?") % cfile, 
-                                              _("Reload File?"),
-                                              wx.YES_NO | wx.ICON_INFORMATION)
-                    mdlg.CenterOnParent()
-                    result = mdlg.ShowModal()
-                    mdlg.Destroy()
-                    if result == wx.ID_YES:
-                        ret, rmsg = self.control.ReloadFile()
-                        if not ret:
-                            mdlg = wx.MessageDialog(self.frame, 
-                                                    _("Failed to reload %s:\n"
-                                                      "Error: %s") % \
-                                                      (cfile, rmsg),
-                                                    _("Error"),
-                                                    wx.OK | wx.ICON_ERROR)
-                            mdlg.ShowModal()
-                            mdlg.Destroy()
-                    else:
-                        self.control.modtime = util.GetFileModTime(cfile)
-                wx.CallAfter(AskToReload, cfile)
+            if self.control.GetModTime() and \
+               not lmod and not os.path.exists(cfile):
+                wx.CallAfter(PromptToReSave, self, cfile)
+            elif self.control.GetModTime() < lmod:
+                wx.CallAfter(AskToReload, self, cfile)
             else:
-                evt.Skip()
-                                          
+                return False
+                        
     def OnLeftUp(self, evt):
         """Traps clicks sent to page close buttons and 
         redirects the action to the ClosePage function
@@ -486,30 +420,23 @@ class EdPages(FNB.FlatNotebook):
         @type evt: flatnotebook.EVT_FLATNOTEBOOK_PAGE_CHANGING
 
         """
-        self.LOG("[nb_evt] Page Changed to %d" % evt.GetSelection())
         evt.Skip()
+        self.LOG("[nb_evt] Page Changed to %d" % evt.GetSelection())
 
     def ChangePage(self, pgid):
         """Change the page and focus to the the given page id
         @param pgid: Page number to change to
-        @todo: generalize this to avoid expecting an edstc
 
         """
-        window = self.GetPage(pgid) #returns current stc
+        window = self.GetPage(pgid) # returns current stc
         window.SetFocus()
         self.control = window
+        fname = self.control.GetFileName()
 
-        if self.control.filename == "":
-            self.control.filename = self.GetPageText(pgid)
+        if fname == "":
+            fname = self.GetPageText(pgid)
 
-        self.frame.SetTitle("%s - file://%s%s%s" % (self.control.filename,
-                                                    self.control.dirname,
-                                                    util.GetPathChar(),
-                                                    self.control.filename))
-
-        matchstrn = re.compile('Untitled*')
-        if matchstrn.match(self.control.filename):
-            self.control.filename = ""
+        self.frame.SetTitle("%s - file://%s" % (util.GetFileName(fname), fname))
 
     def OnPageChanged(self, evt):
         """Actions to do after a page change
@@ -517,14 +444,11 @@ class EdPages(FNB.FlatNotebook):
         @type evt: wx.lib.flatnotebook.EVT_FLATNOTEBOOK_PAGE_CHANGED
 
         """
-        current = evt.GetSelection()
-        self.ChangePage(current)
+        self.ChangePage(evt.GetSelection())
         self.LOG(("[nb_evt] Control Changing from Page: %d to Page: %d\n"
-                 "[nb_info] It has file named: %s\n"
-                 "[nb_info] In DIR: %s") % (evt.GetOldSelection(), 
-                                            evt.GetSelection(), 
-                                            self.control.filename, 
-                                            self.control.dirname))
+                  "[nb_info] It has file named: %s" % (evt.GetOldSelection(), 
+                                                       evt.GetSelection(), 
+                                                       self.control.GetFileName())))
         self.frame.UpdateToolBar()
         evt.Skip()
 
@@ -563,18 +487,14 @@ class EdPages(FNB.FlatNotebook):
             
     def ClosePage(self):
         """Closes Currently Selected Page
-        @postcondtion: currently selected page is closed
+        @postcondition: currently selected page is closed
 
         """
         self.GoCurrentPage()
         pg_num = self.GetSelection()
         result = wx.ID_OK
-        try:
-            act = self.control.GetModify()
-        except AttributeError:
-            act = False
 
-        if act:
+        if self.control.GetModify():
             result = self.frame.ModifySave()
             if result != wx.ID_CANCEL:
                 self.DeletePage(pg_num)
@@ -614,11 +534,11 @@ class EdPages(FNB.FlatNotebook):
 
     def UpdatePageImage(self):
         """Updates the page tab image
-        @postcondtion: page image is updated to reflect any changes in ctrl
+        @postcondition: page image is updated to reflect any changes in ctrl
 
         """
         pg_num = self.GetSelection()
-        ftype = self.control.filename.split(".")
+        ftype = util.GetExtension(self.control.GetFileName())
         ftype = ftype[-1].upper()
         self.LOG("[nb_info] Updating Page Image: Page %d" % pg_num)
         self.SetPageImage(pg_num, str(self.control.GetLangId()))
@@ -651,3 +571,55 @@ class EdPages(FNB.FlatNotebook):
             control.Configure()
 
 #---- End Function Definitions ----#
+
+#-----------------------------------------------------------------------------#
+
+#---- Utility Function Definitions ----#
+def PromptToReSave(win, cfile):
+    """Show a dialog prompting to resave the current file
+    @param win: Window to prompt dialog on top of
+    @param cfile: the file in question
+
+    """
+    mdlg = wx.MessageDialog(win.frame,
+                            _("%s has been deleted since its "
+                              "last save point.\n\nWould you "
+                              "like to save it again?") % cfile,
+                            _("Resave File?"), 
+                            wx.YES_NO | wx.ICON_INFORMATION)
+    mdlg.CenterOnParent()
+    result = mdlg.ShowModal()
+    mdlg.Destroy()
+    if result == wx.ID_YES:
+        win.control.SaveFile(cfile)
+    else:
+        win.control.SetModTime(0)
+
+def AskToReload(win, cfile):
+    """Show a dialog asking if the file should be reloaded
+    @param win: Window to prompt dialog on top of
+    @param cfile: the file to prompt for a reload of
+
+    """
+    mdlg = wx.MessageDialog(win.frame, 
+                            _("%s has been modified by another "
+                              "application.\n\nWould you like "
+                              "to Reload it?") % cfile, 
+                              _("Reload File?"),
+                              wx.YES_NO | wx.ICON_INFORMATION)
+    mdlg.CenterOnParent()
+    result = mdlg.ShowModal()
+    mdlg.Destroy()
+    if result == wx.ID_YES:
+        ret, rmsg = win.control.ReloadFile()
+        if not ret:
+            mdlg = wx.MessageDialog(win.frame, 
+                                    _("Failed to reload %s:\n"
+                                      "Error: %s") % \
+                                      (cfile, rmsg),
+                                    _("Error"),
+                                    wx.OK | wx.ICON_ERROR)
+            mdlg.ShowModal()
+            mdlg.Destroy()
+    else:
+        win.control.SetModTime(util.GetFileModTime(cfile))
