@@ -1,22 +1,11 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: ed_style.py                                                           #
+# Purpose: Editra's style management system. Implements the interpretation of #
+#          Editra Style Sheets to the StyledTextCtrl.                         #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -24,27 +13,18 @@
 # AUTHOR: Cody Precord                                                     #
 # LANGUAGE: Python                                                         #
 # SUMMARY:                                                                 #
-# Provides classes/functions to manage the document styling.               #
+# Provides a system for managing styles in the text control by parsing and #
+# managing data from Editra Style Sheets and translating it to be usable   #
+# with Editra's StyledTextCtrl. By default style sheets are only loaded    #
+# and parsed once per program execution to maximize performance and file   #
+# loading times.                                                           #
 #                                                                          #
-# CLASS: StyleItem                                                         #
-# METHODS:                                                                 #
-# -SetFore,SetBack,SetFace,SetSize: Set values of named attributes         #
-# -SetAttrFromString: Convert a style string to a StyleItem                #
-#                                                                          #
-# CLASS: StyleMgr                                                          #
-# METHODS:                                                                 #
-# -DefaultStyleDictionary: Returns the Default Styles                      #
-# -GetFontDictionary: Does a font lookup and returns a dictonary of fonts  #
-# -GetStyleByName: Looksup and returns a style string by named key.        #
-# -HasNamedStyle: Returns true if a named style key has been defined.      #
-# -LoadStyleSheet: Loads a custom style sheet.                             #
-# -MergeFonts: Merges the font dictonary into the style items.             #
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_style.py 551 2007-09-28 07:58:06Z CodyPrecord $"
-__revision__ = "$Revision: 551 $"
+__svnid__ = "$Id: ed_style.py 49535 2007-10-30 12:38:01Z CJP $"
+__revision__ = "$Revision: 49535 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -52,8 +32,7 @@ import os
 import re
 import wx
 import util
-from profiler import Profile_Get as _PGET
-from profiler import Profile_Set as _PSET
+from profiler import Profile_Get, Profile_Set
 
 # Globals
 STY_ATTRIBUTES     = u"face fore back size"
@@ -72,17 +51,17 @@ class StyleItem(object):
                        face=wx.EmptyString, size=wx.EmptyString):
         """Initiliazes the Style Object.
 
-        @param fore: Specifies the forground color (hex string)
-        @param face: Specifies the font face (string face name)
-        @param back: Specifies the background color (hex string)
-        @param size: Specifies font point size (int/formatted string)
+        @keyword fore: Specifies the forground color (hex string)
+        @keyword face: Specifies the font face (string face name)
+        @keyword back: Specifies the background color (hex string)
+        @keyword size: Specifies font point size (int/formatted string)
 
         SPECIFICATION:
           DATA FORMATS:
             #123456       = hex color code
             #123456,bold  = hex color code + extra style
             Monaco        = Font Face Name
-            %(primary)s      = Format string to be swapped at runtime
+            %(primary)s   = Format string to be swapped at runtime
             10            = A font point size
             %(size)s      = Format string to be swapped at runtime
         """
@@ -132,40 +111,28 @@ class StyleItem(object):
         @return: style items background attribute
 
         """
-        if hasattr(self, 'back'):
-            return self.back
-        else:
-            return wx.EmptyString
+        return getattr(self, 'back', wx.EmptyString)
 
     def GetFace(self):
         """Returns the value of the face attribute
         @return: style items font face attribute
 
         """
-        if hasattr(self, 'face'):
-            return self.face
-        else:
-            return wx.EmptyString
+        return getattr(self, 'face', wx.EmptyString)
 
     def GetFore(self):
         """Returns the value of the fore attribute
         @return: style items foreground attribute
 
         """
-        if hasattr(self, 'fore'):
-            return self.fore
-        else:
-            return wx.EmptyString
+        return getattr(self, 'fore', wx.EmptyString)
 
     def GetSize(self):
         """Returns the value of the size attribute as a string
         @return: style items font size attribute
 
         """
-        if hasattr(self, 'size'):
-            return self.size
-        else:
-            return wx.EmptyString
+        return getattr(self, 'size', wx.EmptyString)
 
     #---- Set Functions ----#
     def SetAttrFromStr(self, style_str):
@@ -177,9 +144,8 @@ class StyleItem(object):
         @type style_str: string
 
         """
-        atoms = style_str.split(u',')
         last_set = wx.EmptyString
-        for atom in atoms:
+        for atom in style_str.split(u','):
             attrib = atom.split(u':')
             if len(attrib) == 2 and attrib[0] in STY_ATTRIBUTES:
                 last_set = attrib[0]
@@ -189,10 +155,8 @@ class StyleItem(object):
                 setattr(self, last_set, u",".join([l_val, attrib[0]]))
             else:
                 pass
-        if last_set != wx.EmptyString:
-            return True
-        else:
-            return False
+
+        return last_set != wx.EmptyString
 
     def SetBack(self, back, ex=wx.EmptyString):
         """Sets the Background Value
@@ -207,7 +171,7 @@ class StyleItem(object):
 
     def SetFace(self, face, ex=wx.EmptyString):
         """Sets the Face Value
-        @param back: font name string
+        @param face: font name string
         @keyword ex: extra attribute (i.e bold, italic, underline)
 
         """
@@ -218,7 +182,7 @@ class StyleItem(object):
 
     def SetFore(self, fore, ex=wx.EmptyString):
         """Sets the Foreground Value
-        @param back: hex color string
+        @param fore: hex color string
         @keyword ex: extra attribute (i.e bold, italic, underline)
 
         """
@@ -229,8 +193,8 @@ class StyleItem(object):
 
     def SetSize(self, size, ex=wx.EmptyString):
         """Sets the Font Size Value
-        @param back: font point size
-        @type back: string or int
+        @param size: font point size
+        @type size: string or int
         @keyword ex: extra attribute (i.e bold, italic, underline)
 
         """
@@ -262,8 +226,7 @@ class StyleItem(object):
                              u"size" : self.GetSize()
                            }
                 for key in attr_map:
-                    if attr_map[key] != wx.EmptyString and \
-                      u"," not in attr_map[key]:
+                    if len(attr_map[key]) and u"," not in attr_map[key]:
                         setattr(self, key, u",".join([attr_map[key], ex_attr]))
                         break
             else:
@@ -293,7 +256,7 @@ class StyleMgr(object):
     modifying styles during run time.
 
     """
-    styles         = dict()
+    STYLES         = dict()         # Cache for loaded style set(s)
     FONT_PRIMARY   = u"primary"
     FONT_SECONDARY = u"secondary"
     FONT_SIZE      = u"size"
@@ -306,6 +269,7 @@ class StyleMgr(object):
 
         """
         object.__init__(self)
+
         # Attributes
         self.fonts = self.GetFontDictionary()
         self.style_set = custom
@@ -317,60 +281,6 @@ class StyleMgr(object):
         else:
             self.LOG("[styles][err] Failed to import styles from %s" % custom)
 
-    def DefaultStyleDictionary(self):
-        """This is the default style values that are used for styling
-        documents. Its used as a fallback for undefined values in a 
-        style sheet.
-        @note: used as a fallback in case loading style sheet fails
-        @note: incomplete style sheets are merged against this set to ensure
-               a full set of definitions is avaiable
-
-        """
-        def_dict = \
-            {'brace_good' : StyleItem("#FFFFFF", "#0000FF,bold"),
-             'brace_bad'  : StyleItem(back="#FF0000,bold"),
-             'calltip'    : StyleItem("#404040", "#FFFFB8"),
-             'ctrl_char'  : StyleItem(),
-             'line_num'   : StyleItem(back="#C0C0C0", face="%(secondary)s", \
-                                      size="%(size3)d"),
-             'array_style': StyleItem("#EE8B02,bold", face="%(secondary)s"),
-             'btick_style': StyleItem("#8959F6,bold", size="%(size)d"),
-             'default_style': StyleItem("#000000", "#F6F6F6", \
-                                        "%(primary)s", "%(size)d"),
-             'char_style' : StyleItem("#FF3AFF"),
-             'class_style' : StyleItem("#2E8B57,bold"),
-             'class2_style' : StyleItem("#2E8B57,bold"),
-             'comment_style' : StyleItem("#838383"),
-             'directive_style' : StyleItem("#0000FF,bold", 
-                                           face="%(secondary)s"),
-             'dockey_style' : StyleItem("#0000FF"),
-             'error_style' : StyleItem("#DD0101,bold", face="%(secondary)s"),
-             'funct_style' : StyleItem("#008B8B,italic"),
-             'global_style' : StyleItem("#007F7F,bold", face="%(secondary)s"), 
-             'here_style' : StyleItem("#CA61CA,bold", face="%(secondary)s"),
-             'ideol_style' : StyleItem("#E0C0E0", face="%(secondary)s"),
-             'keyword_style' : StyleItem("#A52B2B,bold"),
-             'keyword2_style' : StyleItem("#2E8B57,bold"),
-             'keyword3_style' : StyleItem("#008B8B,bold"),
-             'keyword4_style' : StyleItem("#9D2424"),
-             'marker_style' : StyleItem("#FFFFFF", "#000000"),
-             'folder_style' : StyleItem("#FFFFFF", "#000000"),
-             'number_style' : StyleItem("#DD0101"),
-             'number2_style' : StyleItem("#DD0101,bold"),
-             'operator_style' : StyleItem("#000000", face="%(primary)s,bold"),
-             'pre_style' : StyleItem("#AB39F2,bold"),               
-             'pre2_style' : StyleItem("#AB39F2,bold", "#FFFFFF"),
-             'regex_style' : StyleItem("#008B8B"),
-             'scalar_style' : StyleItem("#AB37F2,bold", face="%(secondary)s"),
-             'scalar2_style' : StyleItem("#AB37F2", face="%(secondary)s"),
-             'string_style' : StyleItem("#FF3AFF,bold"),
-             'stringeol_style' : StyleItem("#000000,bold", "#EEC0EE,eol", \
-                                           "%(secondary)s"),
-             'unknown_style' : StyleItem("#FFFFFF,bold", "#DD0101,eol", \
-                                        "%(secondary)s")
-             }
-        return def_dict
-
     def BlankStyleDictionary(self):
         """Returns a dictionary of unset style items based on the
         tags defined in the current dictionary.
@@ -378,9 +288,10 @@ class StyleMgr(object):
                  as keys.
 
         """
-        sty_dict = self.DefaultStyleDictionary()
-        for key in sty_dict:
-            sty_dict[key] = StyleItem(face="%(primary)s", size="%(size)d")
+        sty_dict = dict()
+        for key in self.GetStyleSet().keys():
+            sty_dict[key] = StyleItem("#000000", "#FFFFFF", 
+                                      "%(primary)s", "%(size)d")
         return sty_dict
 
     def GetFontDictionary(self, default=True):
@@ -393,20 +304,21 @@ class StyleMgr(object):
         """
         if hasattr(self, 'fonts') and not default:
             return self.fonts
-        font = _PGET('FONT1', 'font', None)
+
+        font = Profile_Get('FONT1', 'font', None)
         if font is not None:
             mfont = font
         else:
             mfont = wx.Font(10, wx.FONTFAMILY_MODERN, wx.FONTSTYLE_NORMAL, 
                             wx.FONTWEIGHT_NORMAL)
-            _PSET('FONT1', mfont, 'font')
+            Profile_Set('FONT1', mfont, 'font')
         primary = mfont.GetFaceName()
 
-        font = _PGET('FONT2', 'font', None)
+        font = Profile_Get('FONT2', 'font', None)
         if font is None:
             font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.FONTSTYLE_NORMAL, 
                             wx.FONTWEIGHT_NORMAL)
-            _PSET('FONT2', font, 'font')
+            Profile_Set('FONT2', font, 'font')
         secondary = font.GetFaceName()
         faces = { 
                   self.FONT_PRIMARY   : primary,
@@ -424,8 +336,8 @@ class StyleMgr(object):
         @rtype: wx.Font
 
         """
-        if hasattr(self, "styles") and self.styles.has_key("default_style"):
-            style_item = self.styles['default_style']
+        if self.HasNamedStyle('default_style'):
+            style_item = self.GetItemByName('default_style')
             face = style_item.GetFace()
             if face[0] == u"%":
                 face = face % self.fonts
@@ -447,16 +359,11 @@ class StyleMgr(object):
         @rtype: wx.Colour or string
 
         """
-        if self.HasNamedStyle(u'default_style'):
-            fore = self.styles[u'default_style'].GetFore()
-            if fore == wx.EmptyString:
-                fore = u"#000000"
-            if not as_hex:
-                fore = wx.ColourRGB(int(fore[1:], 16))
-        else:
+        fore = self.GetItemByName('default_style').GetFore()
+        if fore == wx.EmptyString:
             fore = u"#000000"
-            if not as_hex:
-                fore = wx.NamedColor("black")
+        if not as_hex:
+            fore = wx.ColourRGB(int(fore[1:], 16))
         return fore
 
     def GetDefaultBackColour(self, as_hex=False):
@@ -469,16 +376,11 @@ class StyleMgr(object):
         @rtype: wx.Colour or string 
 
         """
-        if self.HasNamedStyle(u'default_style'):
-            back = self.styles[u'default_style'].GetBack()
-            if back == wx.EmptyString:
-                back = u"#FFFFFF"
-            if not as_hex:
-                back = wx.ColourRGB(int(back[1:], 16))
-        else:
+        back = self.GetItemByName('default_style').GetBack()
+        if back == wx.EmptyString:
             back = u"#FFFFFF"
-            if not as_hex:
-                back = wx.NamedColor("white")
+        if not as_hex:
+            back = wx.ColourRGB(int(back[1:], 16))
         return back
 
     def GetItemByName(self, name):
@@ -489,13 +391,13 @@ class StyleMgr(object):
 
         """
         if self.HasNamedStyle(name):
-            if u"%" in unicode(self.styles[name]):
-                val = unicode(self.styles[name]) % self.fonts
+            if u"%" in unicode(self.STYLES[self.style_set][name]):
+                val = unicode(self.STYLES[self.style_set][name]) % self.fonts
                 item = StyleItem()
                 item.SetAttrFromStr(val)
                 return item
             else:
-                return self.styles[name]
+                return self.STYLES[self.style_set][name]
         else:
             return StyleItem()
 
@@ -522,30 +424,18 @@ class StyleMgr(object):
 
         """
         if self.HasNamedStyle(name):
-            try:
-                if u"%" in unicode(self.styles[name]):
-                    style = unicode(self.styles[name]) % self.fonts
-                else:
-                    style = unicode(self.styles[name])
-            except KeyError, msg:
-                self.LOG("[styles][err] Bad Format Value %s in def of %s" % \
-                         (str(msg), name))
-                style = wx.EmptyString
-            return style
+            return str(self.GetItemByName(name))
         else:
             return wx.EmptyString
 
     def GetStyleSet(self):
-        """Returns the current set of styles or the
-        default set if there is no current set.
+        """Returns the current set of styles or the default set if 
+        there is no current set.
         @return: current style set dictionary
         @rtype: dict
 
         """
-        if hasattr(self, "styles"):
-            return self.styles
-        else:
-            return self.DefaultStyleDictionary()
+        return self.STYLES.get(self.style_set, DefaultStyleDictionary())
 
     def HasNamedStyle(self, name):
         """Checks if a style has been set/loaded or not
@@ -553,12 +443,7 @@ class StyleMgr(object):
         @return: whether item is in style set or not
 
         """
-        if not hasattr(self, 'styles'):
-            return False
-        elif self.styles.has_key(name):
-            return True
-        else:
-            return False
+        return self.GetStyleSet().has_key(name)
 
     def LoadStyleSheet(self, style_sheet, force=False):
         """Loads a custom style sheet and returns True on success
@@ -569,52 +454,25 @@ class StyleMgr(object):
         @rtype: bool
 
         """
-        if isinstance(style_sheet, basestring) and os.path.exists(style_sheet) and \
-           ((force or not len(self.styles)) or style_sheet != self.style_set):
+        if isinstance(style_sheet, basestring) and \
+           os.path.exists(style_sheet) and \
+           ((force or not self.STYLES.has_key(style_sheet)) or \
+             style_sheet != self.style_set):
             reader = util.GetFileReader(style_sheet)
             if reader == -1:
-                self.LOG("[styles][err] Failed to open style sheet: %s" % \
-                                                                    style_sheet)
+                self.LOG("[styles][err] Failed to open style sheet: %s" % style_sheet)
                 return False
-            ret_val = self.SetStyles(self.ParseStyleData(reader.read()))
+            ret_val = self.SetStyles(style_sheet, self.ParseStyleData(reader.read()))
             reader.close()
             return ret_val
-        elif not len(self.styles):
-            self.LOG("[styles] The style sheet %s does not exists" % \
-                                                                    style_sheet)
-            self.SetStyles(self.DefaultStyleDictionary())
+        elif not self.STYLES.has_key(style_sheet):
+            self.LOG("[styles] Style sheet %s does not exists" % style_sheet)
+            self.SetStyles('default', DefaultStyleDictionary())
             return False
         else:
             self.LOG("[styles][info] Using cached style data")
             return True
 
-    def MergeFonts(self, style_dict, font_dict):
-        """Does any string substitution that the style dictionary
-        may need to have fonts and their sizes set.
-        @param style_dict: dictionary of L{StyleItems}
-        @param font_dict: dictionary of font data
-        @return: style dictionary with all font format strings substituded in
-
-        """
-        for style in style_dict:
-            st_str = str(style_dict[style])
-            if u'%' in st_str:
-                style_dict[style].SetAttrFromStr(st_str % font_dict)
-        return style_dict
-
-    def MergeStyles(self, styles1, styles2):
-        """Merges the styles from styles2 into styles1 overwriting
-        any duplicate values already set in styles1 with the new
-        data from styles2.
-        @param styles1: dictionary of StyleItems recieve merge
-        @param styles2: dictionary of StyleItems to merge from
-        @return: style1 with all values from styles2 merged into it
-
-        """
-        for style in styles2:
-            styles1[style] = styles2[style]
-        return styles1
-
     def PackStyleSet(self, style_set):
         """Checks the difference of each item in the style set as
         compared to the default_style tag and packs any unset value
@@ -651,18 +509,12 @@ class StyleMgr(object):
 
         """
         # Compact data into a contiguous string
-        style_data = style_data.replace(u"\n", u"")
+        style_data = style_data.replace(u"\r\n", u"").replace(u"\n", u"")
         style_data = style_data.replace(u"\t", u"")
 
-        # Build style data tree
-        styles = style_data.split(u'}')
-        del style_data
-        style_tree = list()
-
+        ## Build style data tree
         # Tree Level 1 split tag from data
-        for style in styles:
-            style_tree.append(style.split(u"{"))
-
+        style_tree = [style.split(u"{") for style in style_data.split(u'}')]
         if len(style_tree) and style_tree[-1][0] == wx.EmptyString:
             style_tree.pop()
 
@@ -670,9 +522,9 @@ class StyleMgr(object):
         tmp = style_tree
         for style in tmp:
             if len(style) != 2:
-                self.LOG("[styles] [syntax error] There was an error parsing "
+                self.LOG("[styles][error] There was an error parsing "
                          "the syntax data from " + self.style_set)
-                self.LOG("[styles] [syntax error] You are missing a { or } " +
+                self.LOG("[styles][error] You are missing a { or } " +
                         "in Def: " + style[0].split()[0])
                 if strict:
                     raise SyntaxError, \
@@ -682,21 +534,12 @@ class StyleMgr(object):
 
         # Tree Level 2 Build small trees of tag and style attributes
         # Tree Level 3 Branch tree into TAG => Attr => Value String
-        i = j = 0
-        while i < len(style_tree):
-            tmp = tmp2 = list()
-            # Level 2 Break into attributes
-            tmp = style_tree[i][1].strip().split(u";")
-            while j < len(tmp):
-                # Level 3 Attribute to values
-                tmp2.append(tmp[j].strip().split(u":"))
-                j += 1
-            j = 0
+        for branch in style_tree:
+            tmp2 = [leaf.strip().split(u":") 
+                    for leaf in branch[1].strip().split(u";")]
             if len(tmp2) and tmp2[-1][0] == wx.EmptyString:
                 tmp2.pop()
-            style_tree[i][1] = tmp2
-            del tmp2
-            i += 1
+            branch[1] = tmp2
 
         # Check for L2/L3 Syntax errors and build a clean dictionary
         # of Tags => Valid Attributes
@@ -707,7 +550,7 @@ class StyleMgr(object):
             for leaf in branch[1]:
                 leaf[0] = leaf[0].strip() # Remove any remaining whitespace
                 if len(leaf) != 2:
-                    self.LOG("[styles] [syntax_error] Missing a : or ; in the "
+                    self.LOG("[styles][error] Missing a : or ; in the "
                              "declaration of %s" % tag)
                     if strict:
                         raise SyntaxError, "Missing : or ; in def: %s" % tag
@@ -729,21 +572,17 @@ class StyleMgr(object):
         # Validate leaf values and format into stylestring
         for style_def in style_dict:
             if not style_def[0][0].isalpha():
-                self.LOG("[styles] [syntax_error] The style def %s is not a "
+                self.LOG("[styles][syntax_error] The style def %s is not a "
                          "valid name" % style_def[0])
                 if strict:
                     raise SyntaxError, "%s is an invalid name" % style_def[0]
             else:
                 style_str = wx.EmptyString
                 for attrib in style_dict[style_def]:
-                    values = attrib[1].split(u" ")
-                    tval = list()
-                    for val in values:
-                        if val != wx.EmptyString:
-                            tval.append(val)
-                    values = tval
+                    values = [ val for val in attrib[1].split(u" ") 
+                               if val != wx.EmptyString ]
                     if len(values) > 2:
-                        self.LOG("[styles] [syntax_warning] Only one extra " +
+                        self.LOG("[styles][warning] Only one extra " +
                                  "attribute can be set per style. See " +
                                  style_def + " => " + attrib[0])
                         if strict:
@@ -757,8 +596,8 @@ class StyleMgr(object):
                             v1ok = True
                     elif len(values) and attrib[0] in "face size": 
                         # TODO these regular expressions need work
-                        match1 = re.compile("\%\([a-zA-Z0-9]*\)")
-                        match2 = re.compile("[a-zA-Z0-9]*")
+                        match1 = re.compile("\%\([a-zA-Z0-9]+\)")
+                        match2 = re.compile("[a-zA-Z0-9]+")
                         if match1.match(values[0]) or match2.match(values[0]):
                             v1ok = True
                         else:
@@ -769,7 +608,7 @@ class StyleMgr(object):
                     if len(values) == 2 and values[1] in STY_EX_ATTRIBUTES:
                         v2ok = True
                     elif len(values) == 2:
-                        self.LOG("[styles] [syntax_warning] Unknown extra " + \
+                        self.LOG("[styles][warning] Unknown extra " + \
                                  "attribute '" + values[1] + \
                                  "' in attribute: " + attrib[0])
 
@@ -777,23 +616,21 @@ class StyleMgr(object):
                         value = u",".join(values)
                     elif v1ok:
                         value = values[0]
-                    else:
-                        value = wx.EmptyString
-                    
-                    if value != wx.EmptyString:
-                        value = u":".join([attrib[0], value])
-                        style_str = u",".join([style_str, value])
                     else:
                         continue
+                    
+                    style_str = u",".join([style_str, 
+                                           u":".join([attrib[0], value])])
+
                 if style_str != wx.EmptyString:
-                    style_str = style_str.strip(u",")
-                    style_dict[style_def] = style_str
+                    style_dict[style_def] = style_str.strip(u",")
 
         # Build a StyleItem Dictionary
         for key in style_dict:
             new_item = StyleItem()
             new_item.SetAttrFromStr(style_dict[key])
             style_dict[key] = new_item
+
         return style_dict
 
     def SetGlobalFont(self, font_tag, fontface, size=-1):
@@ -831,10 +668,11 @@ class StyleMgr(object):
         @param value: style item to set tag to
 
         """
-        self.styles[style_tag] = value
+        self.STYLES[self.style_set][style_tag] = value
 
-    def SetStyles(self, style_dict, nomerge=False):
+    def SetStyles(self, name, style_dict, nomerge=False):
         """Sets the managers style data and returns True on success.
+        @param name: name to store dictionary in cache under
         @param style_dict: dictionary of style items to use as managers style
                            set.
         @keyword nomerge: merge against default set or not
@@ -842,27 +680,105 @@ class StyleMgr(object):
 
         """
         if nomerge:
-            self.styles = self.PackStyleSet(style_dict)
+            self.style_set = name
+            self.STYLES[name] = self.PackStyleSet(style_dict)
             return True
 
         # Merge the given style set with the default set to fill in any
         # unset attributes/tags
         if isinstance(style_dict, dict):
             # Check for bad data
-            for style in style_dict:
-                try:
-                    style_dict[style].GetFore()
-                except AttributeError:
-                    self.LOG("[styles] [error] Invalid data " \
-                             "in style dictionary")
+            for style in style_dict.values():
+                if not isinstance(style, StyleItem):
+                    self.LOG("[styles][error] Invalid data in style dictionary")
                     return False
 
-            if not hasattr(self, "styles"):
-                self.styles = self.DefaultStyleDictionary()
-            self.styles = self.MergeStyles(self.styles, style_dict)
-            self.styles = self.PackStyleSet(self.styles)
+            self.style_set = name
+            tmp = MergeStyles(DefaultStyleDictionary(), style_dict)
+            self.STYLES[name] = self.PackStyleSet(tmp)
             return True
         else:
-            self.LOG("[styles] [error] SetStyles expects a " \
+            self.LOG("[styles][error] SetStyles expects a " \
                      "dictionary of StyleItems")
             return False
+
+#-----------------------------------------------------------------------------#
+# Utility Functions
+def DefaultStyleDictionary():
+    """This is the default style values that are used for styling
+    documents. Its used as a fallback for undefined values in a 
+    style sheet.
+    @note: incomplete style sheets are merged against this set to ensure
+           a full set of definitions is avaiable
+
+    """
+    def_dict = \
+        {'brace_good' : StyleItem("#FFFFFF", "#0000FF,bold"),
+         'brace_bad'  : StyleItem(back="#FF0000,bold"),
+         'calltip'    : StyleItem("#404040", "#FFFFB8"),
+         'ctrl_char'  : StyleItem(),
+         'line_num'   : StyleItem(back="#C0C0C0", face="%(secondary)s", \
+                                  size="%(size3)d"),
+         'array_style': StyleItem("#EE8B02,bold", face="%(secondary)s"),
+         'btick_style': StyleItem("#8959F6,bold", size="%(size)d"),
+         'default_style': StyleItem("#000000", "#F6F6F6", \
+                                    "%(primary)s", "%(size)d"),
+         'char_style' : StyleItem("#FF3AFF"),
+         'class_style' : StyleItem("#2E8B57,bold"),
+         'class2_style' : StyleItem("#2E8B57,bold"),
+         'comment_style' : StyleItem("#838383"),
+         'decor_style' : StyleItem("#BA0EEA italic", face="%(secondary)s"),
+         'directive_style' : StyleItem("#0000FF,bold", face="%(secondary)s"),
+         'dockey_style' : StyleItem("#0000FF"),
+         'error_style' : StyleItem("#DD0101,bold", face="%(secondary)s"),
+         'funct_style' : StyleItem("#008B8B,italic"),
+         'global_style' : StyleItem("#007F7F,bold", face="%(secondary)s"), 
+         'here_style' : StyleItem("#CA61CA,bold", face="%(secondary)s"),
+         'ideol_style' : StyleItem("#E0C0E0", face="%(secondary)s"),
+         'keyword_style' : StyleItem("#A52B2B,bold"),
+         'keyword2_style' : StyleItem("#2E8B57,bold"),
+         'keyword3_style' : StyleItem("#008B8B,bold"),
+         'keyword4_style' : StyleItem("#9D2424"),
+         'marker_style' : StyleItem("#FFFFFF", "#000000"),
+         'folder_style' : StyleItem("#FFFFFF", "#000000"),
+         'number_style' : StyleItem("#DD0101"),
+         'number2_style' : StyleItem("#DD0101,bold"),
+         'operator_style' : StyleItem("#000000", face="%(primary)s,bold"),
+         'pre_style' : StyleItem("#AB39F2,bold"),               
+         'pre2_style' : StyleItem("#AB39F2,bold", "#FFFFFF"),
+         'regex_style' : StyleItem("#008B8B"),
+         'scalar_style' : StyleItem("#AB37F2,bold", face="%(secondary)s"),
+         'scalar2_style' : StyleItem("#AB37F2", face="%(secondary)s"),
+         'string_style' : StyleItem("#FF3AFF,bold"),
+         'stringeol_style' : StyleItem("#000000,bold", "#EEC0EE,eol", \
+                                       "%(secondary)s"),
+         'unknown_style' : StyleItem("#FFFFFF,bold", "#DD0101,eol")
+         }
+    return def_dict
+
+def MergeFonts(style_dict, font_dict):
+    """Does any string substitution that the style dictionary
+    may need to have fonts and their sizes set.
+    @param style_dict: dictionary of L{StyleItem}
+    @param font_dict: dictionary of font data
+    @return: style dictionary with all font format strings substituded in
+
+    """
+    for style in style_dict:
+        st_str = str(style_dict[style])
+        if u'%' in st_str:
+            style_dict[style].SetAttrFromStr(st_str % font_dict)
+    return style_dict
+
+def MergeStyles(styles1, styles2):
+    """Merges the styles from styles2 into styles1 overwriting
+    any duplicate values already set in styles1 with the new
+    data from styles2.
+    @param styles1: dictionary of StyleItems recieve merge
+    @param styles2: dictionary of StyleItems to merge from
+    @return: style1 with all values from styles2 merged into it
+
+    """
+    for style in styles2:
+        styles1[style] = styles2[style]
+    return styles1
