@@ -5,7 +5,7 @@
 # Author:      Robin Dunn
 #
 # Created:     15-May-2001
-# RCS-ID:      $Id: listctrl.py 399 2007-08-31 13:54:10Z CodyPrecord $
+# RCS-ID:      $Id: listctrl.py 49533 2007-10-30 11:49:28Z CJP $
 # Copyright:   (c) 2001 by Total Control Software
 # Licence:     wxWindows license
 #----------------------------------------------------------------------------
@@ -650,7 +650,7 @@ class TextEditMixin:
 FILENAME: CheckListCtrlMixin.py
 AUTHOR:   Bruce Who (bruce.who.hk at gmail.com)
 DATE:     2006-02-09
-$Revision: 399 $
+$Revision: 49533 $
 DESCRIPTION:
     This script provide a mixin for ListCtrl which add a checkbox in the first
     column of each row. It is inspired by limodou's CheckList.py(which can be
@@ -672,113 +672,6 @@ HISTORY:
 1.1     - Initial version
 """
 
-from wx import ImageFromStream, BitmapFromImage
-import cStringIO, zlib
-
-def getUncheckData():
-    return zlib.decompress(
-"x\xda\xeb\x0c\xf0s\xe7\xe5\x92\xe2b``\xe0\xf5\xf4p\t\x02\xd2\x02 \xcc\xc1\
-\x06$\xe5?\xffO\x04R,\xc5N\x9e!\x1c@P\xc3\x91\xd2\x01\xe4\xbb{\xba8\x86X\xf4\
-&\xa7\xa4$\xa5-`1\x08\\2\xbb\xb1\xb1\x91\xf5\xd8\x84o\xeb\xff\xfaw\x1d[.=[2\
-\x90'\x01\x08v\xec]\xd3\xa3qvU`l\x81\xd9\xd18\t\xd3\x84+\x0cll[\xa6t\xcc9\
-\xd4\xc1\xda\xc3<O\x9a1\xc3\x88\xc3j\xfa\x86_\xee@#\x19<]\xfd\\\xd69%4\x01\
-\x00\xdc\x80-\x05" )
-
-def getUncheckBitmap():
-    return BitmapFromImage(getUncheckImage())
-
-def getUncheckImage():
-    stream = cStringIO.StringIO(getUncheckData())
-    return ImageFromStream(stream)
-
-def getCheckData():
-    return zlib.decompress(
-'x\xda\xeb\x0c\xf0s\xe7\xe5\x92\xe2b``\xe0\xf5\xf4p\t\x02\xd2\x02 \xcc\xc1\
-\x06$\xe5?\xffO\x04R,\xc5N\x9e!\x1c@P\xc3\x91\xd2\x01\xe47{\xba8\x86X\xf4&\
-\xa7\xa4$\xa5-`1\x08\\2\xbb\xb1\xb1\x91\xf5\xd8\x84o\xeb\xff\xfaw\x1d[.=[2\
-\x90\'\x01\x08v\xec\\2C\xe3\xec+\xc3\xbd\x05fG\xe3\x14n1\xcc5\xad\x8a8\x1a\
-\xb9\xa1\xeb\xd1\x853-\xaa\xc76\xecb\xb8i\x16c&\\\xc2\xb8\xe9Xvbx\xa1T\xc3U\
-\xd6p\'\xbd\x85\x19\xff\xbe\xbf\xd7\xe7R\xcb`\xd8\xa5\xf8\x83\xe1^\xc4\x0e\
-\xa1"\xce\xc3n\x93x\x14\xd8\x16\xb0(\x15q)\x8b\x19\xf0U\xe4\xb10\x08V\xa8\
-\x99\xf3\xdd\xde\xad\x06t\x0e\x83\xa7\xab\x9f\xcb:\xa7\x84&\x00\xe0HE\xab' )
-
-def getCheckBitmap():
-    return BitmapFromImage(getCheckImage())
-
-def getCheckImage():
-    stream = cStringIO.StringIO(getCheckData())
-    return ImageFromStream(stream)
-
-# Mac OSX style checkbox
-def getMacCheckData():
-    return zlib.decompress(
-'x\xda\x01\xe8\x02\x17\xfd\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\
-\x10\x00\x00\x00\x10\x08\x06\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\
-\x08\x08\x08\x08|\x08d\x88\x00\x00\x02\x9fIDAT8\x8d\x95\x93\xcbkTw\x14\xc7?\
-\xbf;w&\x99\xfb{\xdc<t\xa3\xab )\xc1\x10C"\xad\x16\xd4D\x91\xd8P\xd4H\r\xc5W\
-\xacX[*A\x88\xa4\xbaQ\\\x88\xa0A\xf1\x0f(\xd5\xd8@J\xe9\xc6\x95\x90H\x11E\
-\xbb\x11\xe2\xa3.|l\x0c\xf8\nM\x9a\xce$b\xee\x9d\x99{\\\x8cd\xba\xac\x8b\xef\
-\xea\x9c\xf39\xe7{8\x07\xe5\xa5\xf8X544\x08 CCC\xf2\xd1\xc5\x83\x83\x83\x02H\
-{{\xbb(/\xc5b\xa0\xb3\xb3S\x80\xff%\xa5\x94\x0c\x0f\x0f\x8b\xf2R(\xe5\xa5\
-\xd8\xdf\xb7O>i[\xcf\xb6-\x1d\x18\xad\xf1\xd4\x87L\x11\x94R \x82\x00\x87\x0e\
-\x1e\xe0\xfa\xf8\x18k\xd6m$\xa3\x8a\xdc\xbe\xf3\xa7\xf2\x01~\x19\xff\x8b+_\
-\xeedf6G~\xee-\x00\xcaS$I\x82\x88\x00p\xfb\xd6M\xae\x8f\x8fQ[WG\xff\x91\x01\
-\xbe9z\x1a\x00\x1f\xa0}U\x13:\x08\x88\xa2\x98(\x8e\x11\x01\xa5T\xb9;\xc2\xc2\
-B\xc4\xc5\xf3\xe7\x008\xf4C?a\x18\xd2\xda\xdc\xc8\xbdW\x13x\x005\xce\x11\x17\
-\x8b\xdc\xb8\xf1\x07\xbbwn\xa7w\xdb\x17\xbc~\xf5\x92\xb8P I\x12FG\x86\x99z\
-\xf3\x9a\xe6\x96Utl\xea\xa2$B\xads\x00e@\xa85\xef\x16"V\x7f\xba\x86\xfa%K\
-\xc9\xe7s\\8w\x06\x11x\xfe|\x92\xdf\x7f\x1d\xc1\xf7}\xfa\x07\x8e\x11E\x05fsy\
-L6[\x01\x04:\xcb\xdf\xb39^\xbc\x99\xa1\xb7\xef;\xd2\x99\x0c\x0f\xefOp\xf9\
-\xd2\xcf\\<\x7f\x96b\xb1H\xc7\xe6n\nd\x98|9\xc5\xd4\xf4\xbf8g+\x00\x9d\xcdb\
-\x8d\xc6X\xcb\x8a\x15\x8d\xf4\xee9\x00\xc0\xd5\xdfFx\xfc\xe8\x01\xb5\xf5K\
-\xd8\xb1\xab\x0f\xa35\xa1s\x84\xceb\x82\xa0\xb2Dc\r\xd6X\xaa\xaa2\xa4<\xc5W_\
-\xef\xe5\xe1\xc4]\x1e=\x98\x00\xe0\xdb\xc3\x03,_\xb6\x8cR)\x81DH\xc7i\x8c\
-\xd5\x95\t\x9c58g\xb1\xceb\x9c\xc3\x85\x8e\xe3\xa7\xce\x10h\xcd\xea\xcf>\xa7\
-\xab{+A`\x08\xc3\x1a\x02k\xa8q!\xd6\x9a\xca\x04\xe9\xaa*\xb46d\xb3\xd5(\xa5H\
-\xa5<\x8c\xb1\xfcx\xe24\xcd-\xad\x845\x0eI\x04\x91\x04\x94G\x14\x17\xa8\xae\
-\xfe\x8f\x85\xb7\xf39\xea\xea\xea1Z\xa3\xbc\xf2\xe5\xa1\x14\xfb\x0f~O)\x11J\
-\xc5"\xbe\x97\xa2$\x82$%\xde\xc51s\xf9\x99\n`!7\xcd\xd3gO\xe8\xda\xb2\x81\
-\xb4\x07\x8a\xb2\x92\x0f\x1e\x13X\xf4\x1b\x03c\xd7n\x11\xcd\xfdS\x01\xacm[\
-\xc9\xd5\xd1\x9f\x18:y\x94\xf9\xf9yDd\xf1\x0fD\x84$)#|\xdf\xc7ZKSS\x13===\
-\x00\xbc\x07\xc7\xfc\xfc\x8c\xc6Nx\x85\x00\x00\x00\x00IEND\xaeB`\x82\x07kSx'\
- )
-
-def getMacCheckBitmap():
-    return BitmapFromImage(getMacCheckImage())
-
-def getMacCheckImage():
-    stream = cStringIO.StringIO(getMacCheckData())
-    return ImageFromStream(stream)
-
-#----------------------------------------------------------------------
-def getMacUncheckData():
-    return zlib.decompress(
-'x\xda\x01\xc1\x01>\xfe\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\
-\x00\x00\x00\x10\x08\x06\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\
-\x08\x08\x08|\x08d\x88\x00\x00\x01xIDAT8\x8d\xa5\x92O\x8a"1\x14\x87\xbf\xfc\
-\xb1\xcaP\x14\xb8\x90Z\xba\x13\xea\x1c\x9e\xc0\xa3\xd8\xdds\x86\x99\xb9\x82\
-\xbb\x99\xbe\x8c\x88\xc7P\\\x89(\x88$\xa5If\xd1T\xaa\xab\x05g\xd1\x0f\x02I\
-\xc8\xef{\xbf\xf7\xf2\x84\x90\x8a\xef\x84\xfc\x96\x1a\xd0\xed\xe6\xc7\xdbk<\
-\x9f\xcf\x18c\xd0\xfa\xe3:\xc6\xd8{\xec\xbd\xe7z\xbdRU\x15?\x7f\xfd\x16\t\
-\xf0\xfe\xf7O\x1c\x8f\xc7\xccf3\x94z^\x92\xf7\x9e\xd5jEUUq\xf1\xf2*$\xc0\xf1\
-xd:\x9d\xd24\r\xd6Z\x9cs8\xe7\xb0\xd6>\xac\xa6i\x98L&Xk\xbb\x12N\xa7\x13J)\
-\xee\xf7\xfb\xd3\xecmIB\x08\x8c1\x1d`4\x1a\x11B\xc0{\x9f\x1e|\x15J)\x891&H\
-\x08\xa1\x03\x94e\xf9\x00\x10B\xf4\x9a\xd8\nB\x088\xe7(\x8a\xa2\x03H)\xb1\
-\xd6\xf6,~\x16J)\t!\xa4{\xe7\x1cy\x9ew\x80\xa2(\xc8\xf3\x9c\xc1`\xf0\x00\x10\
-B\xa4\xec\xed\xd9{\x9f\xbeZ\x03\x18c0\xc6\xa0\x94"\xc6\x98Jh\xa3u\xf0\x19\
-\xd0s\xa0\xb5&\xcb2\xb4\xd6\xbd9h{\xa2\xb5\xe6v\xbb\xa1\x94"\x84\x801\xa6\
-\x0fPJ\x91e\x19\xc3\xe10u\xfc\xab\xed,\xcb\xd2Y)\xd5\x07\xec\xf7\xfb\x1e\xf5\
-Y\xb4\t\x0e\x87\xc3Gy\x00\xdb\xed\x96\xcdf\xf3_q\xebf\xbd^\xb3\xdb\xed:\x07u\
-]\xb3\\.Y,\x16\\.\x9740\xed,\xa4\xa1\xd1\x9a\xb2,\xa9\xeb\x9a\xf9|\x0e\xc0?\
-\x07\\\xc1\xc6\xab\x1f\x1bB\x00\x00\x00\x00IEND\xaeB`\x82\xb96\xcb-' )
-
-def getMacUncheckBitmap():
-    return BitmapFromImage(getMacUncheckImage())
-
-def getMacUncheckImage():
-    stream = cStringIO.StringIO(getMacUncheckData())
-    return ImageFromStream(stream)
-
 class CheckListCtrlMixin:
     """
     This is a mixin for ListCtrl which add a checkbox in the first
@@ -799,17 +692,13 @@ class CheckListCtrlMixin:
     """
     def __init__(self, check_image=None, uncheck_image=None):
         self.__imagelist_ = wx.ImageList(16, 16)
+
         if not check_image:
-#             check_image, uncheck_image = self.__CreateDefaultBitmaps()
-            if wx.Platform == '__WXMAC__':
-                check_image = getMacCheckBitmap()
-            else:
-                check_image = getCheckBitmap()
+            check_image = self.__CreateBitmap(wx.CONTROL_CHECKED)
+
         if not uncheck_image:
-            if wx.Platform == '__WXMAC__':
-                uncheck_image = getMacUncheckBitmap()
-            else:
-                uncheck_image = getUncheckBitmap()
+            uncheck_image = self.__CreateBitmap()
+
         self.uncheck_image = self.__imagelist_.Add(uncheck_image)
         self.check_image = self.__imagelist_.Add(check_image)
         self.SetImageList(self.__imagelist_, wx.IMAGE_LIST_SMALL)
@@ -820,18 +709,17 @@ class CheckListCtrlMixin:
         # override the default methods of ListCtrl/ListView
         self.InsertStringItem = self.__InsertStringItem_
 
-    def __CreateDefaultBitmaps(self):
-        dc = wx.MemoryDC(wx.EmptyBitmap(16, 16))
-        # Draw Boxes
-        wx.RendererNative.Get().DrawCheckBox(self, dc, wx.Rect(0, 0, 16, 16), 
-                                       wx.CONTROL_CHECKED)
-        cbmp = dc.GetAsBitmap()
-        dc.SelectObject(wx.EmptyBitmap(16, 16))
-        wx.RendererNative.Get().DrawCheckBox(self, dc, wx.Rect(0, 0, 16, 16), 
-                                       wx.CONTROL_CHECKABLE)
-        ucbmp = dc.GetAsBitmap()
+    def __CreateBitmap(self, flag=0):
+        """Create a bitmap of the platforms native checkbox. The flag
+        is used to determine the checkboxes state (see wx.CONTROL_*)
 
-        return cbmp, ucbmp
+        """
+        bmp = wx.EmptyBitmap(16, 16)
+        dc = wx.MemoryDC(bmp)
+        dc.Clear()
+        wx.RendererNative.Get().DrawCheckBox(self, dc, (0, 0, 16, 16), flag)
+        dc.SelectObject(wx.NullBitmap)
+        return bmp
 
     # NOTE: if you use InsertItem, InsertImageItem or InsertImageStringItem,
     #       you must set the image yourself.
