@@ -1,22 +1,10 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: iface.py                                                              #
+# Purpose: Plugin interface definitions                                       #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -29,14 +17,14 @@
 #
 # Intefaces:
 #   * ShelfI: Interface into the L{Shelf}
-#
+#   * MainWindowI: Interface into L{ed_main.MainWindow}
 #
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: iface.py 550 2007-09-28 07:56:13Z CodyPrecord $"
-__revision__ = "$Revision: 550 $"
+__svnid__ = "$Id: iface.py 49291 2007-10-21 12:59:57Z CJP $"
+__revision__ = "$Revision: 49291 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -47,13 +35,58 @@ from extern import flatnotebook as FNB
 from profiler import Profile_Get
 import ed_menu
 import ed_glob
-import util
 
 #--------------------------------------------------------------------------#
 PGNUM_PAT = re.compile(' - [0-9]+')
+_ = wx.GetTranslation
 
 #--------------------------------------------------------------------------#
 
+class MainWindowI(plugin.Interface):
+    """The MainWindow Interface is intended as a simple general purpose
+    interface for adding functionality to the main window. It does little
+    managing of how object the implementing it is handled, most is left up to
+    the plugin. Some examples of plugins using this interface are the
+    FileBrowser and Calculator plugins.
+
+    """
+    def PlugIt(self, window):
+        """This method is called once and only once per window when it is 
+        created. It should typically be used to register menu entries, 
+        bind event handlers and other similar actions.
+
+        @param window: The parent window of the plugin
+        @postcondition: The plugins controls are installed in the L{MainWindow}
+
+        """
+        raise NotImplementedError
+
+    def GetMenuHandlers(self):
+        """Get menu event handlers/id pairs. This function should return a
+        list of tuples containing menu ids and their handlers. The handlers
+        should be not be a member of this class but a member of the ui component
+        that they handler acts upon.
+        
+        
+        @return: list [(ID_FOO, foo.OnFoo), (ID_BAR, bar.OnBar)]
+
+        """
+        pass
+
+    def GetUIHandlers(self):
+        """Get update ui event handlers/id pairs. This function should return a
+        list of tuples containing object ids and their handlers. The handlers
+        should be not be a member of this class but a member of the ui component
+        that they handler acts upon.
+        
+        
+        @return: list [(ID_FOO, foo.OnFoo), (ID_BAR, bar.OnBar)]
+
+        """
+        pass
+
+#-----------------------------------------------------------------------------#
+
 class ShelfI(plugin.Interface):
     """Interface into the L{Shelf}. All plugins wanting to be
     placed on the L{Shelf} should implement this interface.
@@ -97,13 +130,14 @@ class ShelfI(plugin.Interface):
 
         """
 
+#-----------------------------------------------------------------------------#
+SHELF_NAME = u'Shelf'
 class Shelf(plugin.Plugin):
     """Plugin that creates a notebook for holding the various Shelf items
     implemented by L{ShelfI}.
 
     """
     observers = plugin.ExtensionPoint(ShelfI)
-    __name__ = u"Shelf"
 
     def __init__(self, pmgr):
         """Create the Shelf
@@ -117,10 +151,10 @@ class Shelf(plugin.Plugin):
 
     def _GetMenu(self):
         """Return the menu of this object
-        @return: ed_menu.ED_Menu()
+        @return: ed_menu.EdMenu()
 
         """
-        menu = ed_menu.ED_Menu()
+        menu = ed_menu.EdMenu()
         menu.Append(ed_glob.ID_SHOW_SHELF, _("Show Shelf") + "\tCtrl+Alt+S", 
                     _("Show the Shelf"))
         menu.AppendSeparator()
@@ -136,7 +170,6 @@ class Shelf(plugin.Plugin):
                 self._log("[shelf][err] %s" % str(msg))
         menu_items.sort()
 
-        genmenu = ed_menu.ED_Menu()
         combo = 0
         for item in menu_items:
             combo += 1
@@ -152,19 +185,21 @@ class Shelf(plugin.Plugin):
         # First check if the parent has an instance already
         self._parent = parent
         mgr = parent.GetFrameManager()
-        if mgr.GetPane(self.__name__).IsOk():
+        if mgr.GetPane(SHELF_NAME).IsOk():
             return
 
-        self._shelf = FNB.FlatNotebook(parent, style=FNB.FNB_FF2 | \
-                                                     FNB.FNB_X_ON_TAB |\
-                                                     FNB.FNB_NODRAG)
-        mgr.AddPane(self._shelf, wx.aui.AuiPaneInfo().Name(self.__name__).\
+        self._shelf = FNB.FlatNotebook(parent, 
+                                       style=FNB.FNB_FF2 | \
+                                             FNB.FNB_X_ON_TAB | \
+                                             FNB.FNB_BACKGROUND_GRADIENT | \
+                                             FNB.FNB_NODRAG)
+        mgr.AddPane(self._shelf, wx.aui.AuiPaneInfo().Name(SHELF_NAME).\
                             Caption("Shelf").Bottom().Layer(0).\
                             CloseButton(True).MaximizeButton(False).\
                             BestSize(wx.Size(500,250)))
 
         # Hide the pane and let the perspective manager take care of it
-        mgr.GetPane(self.__name__).Hide()
+        mgr.GetPane(SHELF_NAME).Hide()
         mgr.Update()
 
         # Install Menu and bind event handler
@@ -175,7 +210,8 @@ class Shelf(plugin.Plugin):
             mitem = view.FindItemByPosition(pos)
             if mitem.GetId() == ed_glob.ID_PERSPECTIVES:
                 break
-        view.InsertMenu(pos + 1, ed_glob.ID_SHELF, self.__name__, 
+
+        view.InsertMenu(pos + 1, ed_glob.ID_SHELF, SHELF_NAME, 
                         menu, _("Put an item on the Shelf"))
         for item in menu.GetMenuItems():
             if item.IsSeparator():
@@ -195,8 +231,9 @@ class Shelf(plugin.Plugin):
         """
         if not hasattr(self._parent, 'GetFrameManager'):
             return
+
         mgr = self._parent.GetFrameManager()
-        pane = mgr.GetPane(self.__name__)
+        pane = mgr.GetPane(SHELF_NAME)
         if not pane.IsShown():
             pane.Show()
             mgr.Update()
@@ -210,6 +247,7 @@ class Shelf(plugin.Plugin):
         count = 0
         if self._shelf is None:
             return count
+
         for page in xrange(self._shelf.GetPageCount()):
             if item_name == re.sub(PGNUM_PAT, u'', 
                                   self._shelf.GetPageText(page), 1):
@@ -235,6 +273,7 @@ class Shelf(plugin.Plugin):
         rval = list()
         if self._shelf is None:
             return rval
+
         for page in xrange(self._shelf.GetPageCount()):
             rval.append(re.sub(PGNUM_PAT, u'', 
                         self._shelf.GetPageText(page), 1))
@@ -247,8 +286,9 @@ class Shelf(plugin.Plugin):
         """
         if not hasattr(self._parent, 'GetFrameManager'):
             return
+
         mgr = self._parent.GetFrameManager()
-        pane = mgr.GetPane(self.__name__)
+        pane = mgr.GetPane(SHELF_NAME)
         if pane.IsOk():
             pane.Hide()
             mgr.Update()
@@ -260,8 +300,9 @@ class Shelf(plugin.Plugin):
         """
         if not hasattr(self._parent, 'GetFrameManager'):
             return
+
         mgr = self._parent.GetFrameManager()
-        pane = mgr.GetPane(self.__name__)
+        pane = mgr.GetPane(SHELF_NAME)
         if pane.IsOk():
             return pane.IsShown()
         else:
@@ -277,8 +318,15 @@ class Shelf(plugin.Plugin):
         if e_id == ed_glob.ID_SHOW_SHELF:
             if self.IsShown():
                 self.Hide()
+                self._parent.GetNotebook().GetCurrentCtrl().SetFocus()
             else:
                 self.EnsureShelfVisible()
+                mgr = self._parent.GetFrameManager()
+                pane = mgr.GetPane(SHELF_NAME)
+                if pane is not None:
+                    page = pane.window.GetCurrentPage()
+                    if hasattr(page, 'SetFocus'):
+                        page.SetFocus()
         else:
             self.PutItemOnShelf(evt.GetId())
 
@@ -295,21 +343,23 @@ class Shelf(plugin.Plugin):
         @param shelfid: id of the ShelfItem to open
 
         """
-        found = False
+        item = None
         for shelfi in self.observers:
             if shelfi.GetId() == shelfid:
-                found = True
+                item = shelfi
                 break
-        if not found:
+
+        if item is None:
             return
-        name = shelfi.GetName()
+
+        name = item.GetName()
         if self.ItemIsOnShelf(name) and \
-            not shelfi.AllowMultiple() or \
+            not item.AllowMultiple() or \
             self._shelf is None:
             return
         else:
             self.EnsureShelfVisible()
-            self._shelf.AddPage(shelfi.CreateItem(self._shelf), 
+            self._shelf.AddPage(item.CreateItem(self._shelf), 
                                 u"%s - %d" % (name, self._open.get(name, 0)))
             self._open[name] = self._open.get(name, 0) + 1
 
@@ -321,6 +371,7 @@ class Shelf(plugin.Plugin):
         """
         if self._shelf is None:
             return False
+
         for page in xrange(self._shelf.GetPageCount()):
             if item_name in self._shelf.GetPageText(page):
                 return True
@@ -336,4 +387,5 @@ class Shelf(plugin.Plugin):
             itemid = self.GetItemId(item)
             if itemid:
                 self.PutItemOnShelf(itemid)
+
 #--------------------------------------------------------------------------#
