@@ -1,22 +1,10 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: perspectives.py                                                       #
+# Purpose: Editra's view management service                                   #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -25,18 +13,14 @@
 # LANGUAGE: Python                                                         #
 # SUMMARY:                                                                 #
 #    Provides a perspective management class for saving and loading custom #
-# perspectives in the MainWindow. 
-#
-# METHODS:
-#
-#
-#
+# perspectives in the MainWindow.                                          #
+#                                                                          #
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: perspective.py 422 2007-09-06 13:00:15Z CodyPrecord $"
-__revision__ = "$Revision: 422 $"
+__cvsid__ = "$Id: perspective.py 49400 2007-10-24 14:22:22Z CJP $"
+__revision__ = "$Revision: 49400 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -44,6 +28,7 @@ import os
 import wx
 import util
 import ed_menu
+from profiler import Profile_Get
 
 #--------------------------------------------------------------------------#
 # Globals
@@ -78,7 +63,7 @@ class PerspectiveManager(object):
         self._base = os.path.join(base, DATA_FILE)  # Path to config
         self._viewset = dict()                      # Set of Views
         self.LoadPerspectives()
-        self._menu = ed_menu.ED_Menu()              # Control menu
+        self._menu = ed_menu.EdMenu()              # Control menu
         self._currview = None                       # Currently used view
 
         # Setup Menu
@@ -89,6 +74,14 @@ class PerspectiveManager(object):
         for name in self._viewset:
             self.AddPerspectiveMenuEntry(name)
 
+        # Restore the managed windows previous position and alpha
+        # preferences if they are available.
+        self._window.SetTransparent(Profile_Get('ALPHA', default=255))
+        if Profile_Get('SET_WPOS') and Profile_Get('WPOS', "size_tuple", False):
+            self._window.SetPosition(Profile_Get('WPOS'))
+        else:
+            self._window.CenterOnParent()
+
         # Event Handlers
         self._window.Bind(wx.EVT_MENU, self.OnPerspectiveMenu)
 
@@ -283,7 +276,7 @@ class PerspectiveManager(object):
 
     def SetPerspectiveById(self, per_id):
         """Sets the perspective using the given control id
-        @param perId: id of requested perspective
+        @param per_id: id of requested perspective
         @return: whether perspective was set or not
         @rtype: bool
 
