@@ -1,42 +1,27 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: plugdlg.py                                                            #
+# Purpose: User interface into the PluginManager, also provides interface for #
+#          downloading and installing plugins.                                #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
 # FILE:	plugdlg.py                                                         #
-# @author: Cody Precord                                                    #
+# AUTHOR: Cody Precord                                                     #
 # LANGUAGE: Python                                                         #
-# @summary:                                                                #
+# SUMMARY:                                                                 #
 #     Provides a dialog for downloading, installing and configuring        #
 # plugins for Editra.                                                      #
 #                                                                          #
-# METHODS:                                                                 #
-#
-#
-#
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: plugdlg.py 516 2007-09-24 08:29:23Z CodyPrecord $"
-__revision__ = "$Revision: 516 $"
+__cvsid__ = "$Id: plugdlg.py 49578 2007-11-01 08:10:04Z CJP $"
+__revision__ = "$Revision: 49578 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -60,7 +45,6 @@ CONFIG_PG = 0
 DOWNLOAD_PG = 1
 INSTALL_PG = 2
 PY_VER = str(sys.version_info[0]) + str(sys.version_info[1])
-BASE_URL = "http://editra.org/"
 PLUGIN_REPO = "http://editra.org/plugins.php?list=True&py=" + PY_VER
 
 _ = wx.GetTranslation
@@ -71,24 +55,29 @@ def MakeThemeTool(tool_id):
     """Makes a themed bitmap for the tool book of the plugin dialog.
     @param tool_id: An art identifier id
     @return: 32x32 bitmap
-    @todo: figure out cause of black artifacts on wxmac
+    @todo: why does drawing a bitmap overlay on gtk not draw on transparent area
 
     """
     osize = Profile_Get('ICON_SZ', 'size_tuple', (24, 24))
     Profile_Set('ICON_SZ', (32, 32))
     base = wx.ArtProvider.GetBitmap(str(tool_id), wx.ART_TOOLBAR)
     Profile_Set('ICON_SZ', osize)
+    if not base.IsOk() or base.GetSize() != (32, 32):
+        base = wx.ArtProvider.GetBitmap(wx.ART_WARNING, 
+                                        wx.ART_TOOLBAR, 
+                                        size=(32, 32))
+
     over = wx.ArtProvider.GetBitmap(str(ed_glob.ID_PLUGMGR), wx.ART_MENU)
-    if base.IsOk() and over.IsOk():
+    if over.IsOk():
         # Draw overlay onto button
         mdc = wx.MemoryDC()
         mdc.SelectObject(base)
         mdc.SetBrush(wx.TRANSPARENT_BRUSH)
         mdc.SetPen(wx.TRANSPARENT_PEN)
-        mdc.DrawBitmap(over, 15, 15, True)
-        return mdc.GetAsBitmap()
-    else:
-        return wx.ArtProvider.GetBitmap(wx.ART_WARNING, size=(32, 32))
+        mdc.DrawBitmap(over, 15, 15, False)
+        mdc.SelectObject(wx.NullBitmap)
+
+    return base
     
 #--------------------------------------------------------------------------#
 
@@ -111,15 +100,14 @@ class PluginDialog(wx.Frame):
             self.SetExtraStyle(wx.FRAME_EX_METAL)
 
         # Attributes
-        self._sizer = wx.BoxSizer(wx.VERTICAL)
-        self._sb = DownloadStatusBar(self)
-        self.SetStatusBar(self._sb)
+        sizer = wx.BoxSizer(wx.VERTICAL)
+        self.SetStatusBar(DownloadStatusBar(self))
         self._nb = PluginPages(self)
         
         # Layout Dialog
-        self._sizer.Add(self._nb, 1, wx.EXPAND)
+        sizer.Add(self._nb, 1, wx.EXPAND)
         self._title = title
-        self.SetSizer(self._sizer)
+        self.SetSizer(sizer)
         self.SetAutoLayout(True)
 
         # Event Handlers
@@ -159,9 +147,9 @@ class PluginDialog(wx.Frame):
 
         """
         if busy:
-            self._sb.StartBusy()
+            self.GetStatusBar().StartBusy()
         else:
-            self._sb.StopBusy()
+            self.GetStatusBar().StopBusy()
 
 #--------------------------------------------------------------------------#
 
@@ -173,7 +161,7 @@ class DownloadStatusBar(wx.StatusBar):
         @param parent: Frame this status bar belongs to
 
         """
-        wx.StatusBar.__init__(self, parent)
+        wx.StatusBar.__init__(self, parent, style=wx.SB_FLAT)
   
         # Attributes
         self._changed = False
@@ -240,7 +228,7 @@ class DownloadStatusBar(wx.StatusBar):
         """
         rect = self.GetFieldRect(1)
         self.prog.SetPosition((rect.x + 2, rect.y + 2))
-        self.prog.SetSize((rect.width - 4, rect.height - 4))
+        self.prog.SetSize((rect.width - 8, rect.height - 4))
         self._changed = False
 
     def StartBusy(self):
@@ -267,9 +255,9 @@ class PluginPages(wx.Toolbook):
     One for installing, and one for configuration.
 
     """
-    def __init__(self, parent, id_=wx.ID_ANY, style=wx.TB_TOP):
+    def __init__(self, parent, style=wx.TB_TOP):
         """Creates the Toolbook"""
-        wx.Toolbook.__init__(self, parent, id=id_, style=style)
+        wx.Toolbook.__init__(self, parent, wx.ID_ANY, style=style)
 
         # Create Pages
         self._imglst = wx.ImageList(32, 32)
@@ -323,8 +311,8 @@ class PluginPages(wx.Toolbook):
                         " | " + self.GetPageText(cur_pg))
         if cur_pg == CONFIG_PG:
             self._config.PopulateCtrl()
-            self.GetParent().SetStatusText(_("Changes will take affect once the"
-                                             " program has been restarted"), 0)
+            parent.SetStatusText(_("Changes will take affect once the"
+                                   " program has been restarted"), 0)
         elif cur_pg == DOWNLOAD_PG:
             self._download.UpdateList()
         elif cur_pg == INSTALL_PG:
@@ -334,21 +322,25 @@ class PluginPages(wx.Toolbook):
 
         evt.Skip()
 
+#-----------------------------------------------------------------------------#
+
 class ConfigPanel(wx.Panel):
     """Creates a panel for configuring plugins."""
-    def __init__(self, parent, id_=wx.ID_ANY, style=wx.NO_BORDER):
+    def __init__(self, parent, style=wx.NO_BORDER):
         """Build config panel"""
-        wx.Panel.__init__(self, parent, id_, style=style)
+        wx.Panel.__init__(self, parent, style=style)
+
+        # Attrtibutes
         self._list = PluginListCtrl(self)
-        self._sizer = wx.BoxSizer(wx.VERTICAL)
         
         # Layout Panel
-        self._sizer.Add(wx.StaticText(self, wx.ID_ANY, 
-                       _("To enable a plugin check the box next to its label")),
-                        0, wx.ALIGN_CENTER_HORIZONTAL)
-        self._sizer.Add(wx.Size(10, 10))
-        self._sizer.Add(self._list, 1, wx.EXPAND)
-        self.SetSizer(self._sizer)
+        sizer = wx.BoxSizer(wx.VERTICAL)
+        sizer.Add(wx.StaticText(self, wx.ID_ANY, 
+                   _("To enable a plugin check the box next to its label")),
+                   0, wx.ALIGN_CENTER_HORIZONTAL)
+        sizer.Add((10, 10))
+        sizer.Add(self._list, 1, wx.EXPAND)
+        self.SetSizer(sizer)
 
         # Event handlers
         self.Bind(ed_event.EVT_NOTIFY, self.OnNotify)
@@ -418,18 +410,10 @@ class ConfigPanel(wx.Panel):
             mod = sys.modules.get(item)
             pin = PluginData()
             pin.SetName(item)
-            try:
-                pin.SetDescription(str(mod.__doc__))
-            except (NameError, TypeError):
-                pin.SetDescription(_("No Description Available"))
-            try:
-                pin.SetAuthor(str(mod.__author__))
-            except (NameError, TypeError):
-                pin.SetAuthor(_("Unknown"))
-            try:
-                pin.SetVersion(str(mod.__version__))
-            except (NameError, TypeError):
-                pin.SetVersion(_("Unknown"))
+            pin.SetDescription(getattr(mod, '__doc__', 
+                                       _("No Description Available")))
+            pin.SetAuthor(getattr(mod, '__author__', _("Unknown")))
+            pin.SetVersion(str(getattr(mod, '__version__', _("Unknown"))))
 
             self._list.InsertPluginItem(pin)
             self._list.Thaw()
@@ -441,12 +425,14 @@ class ConfigPanel(wx.Panel):
 
         if self._list.GetItemCount():
             self._list.SetColumnWidth(0, wx.LIST_AUTOSIZE)
-            self._list.SetColumnWidth(1, wx.LIST_AUTOSIZE)
+            self._list.SetColumnWidth(1, self.GetTextExtent("0" * 35)[0])
             self._list.SetColumnWidth(2, wx.LIST_AUTOSIZE)
-            self._list.SetColumnWidth(3, wx.LIST_AUTOSIZE)
+            self._list.SetColumnWidth(3, wx.LIST_AUTOSIZE_USEHEADER)
             self._list.SendSizeEvent()
         return self._list.GetItemCount()
 
+#-----------------------------------------------------------------------------#
+
 class DownloadPanel(wx.Panel):
     """Creates a panel with controls for downloading plugins."""
     ID_DOWNLOAD = wx.NewId()
@@ -455,12 +441,11 @@ class DownloadPanel(wx.Panel):
     re.VERBOSE | re.IGNORECASE
     ).match
 
-    def __init__(self, parent, pid=wx.ID_ANY, style=wx.NO_BORDER):
+    def __init__(self, parent, style=wx.NO_BORDER):
         """Initializes the panel"""
-        wx.Panel.__init__(self, parent, pid, style=style)
+        wx.Panel.__init__(self, parent, style=style)
 
         # Attributes
-        self._sizer = wx.BoxSizer(wx.VERTICAL)
         self._p_list = dict()           # list of available plugins/meta
         self._dl_list = dict()          # List of download urls
         self._eggcount = 0              # Number of plugins to download
@@ -470,58 +455,23 @@ class DownloadPanel(wx.Panel):
         self._downlb.Disable()
 
         # Layout Panel
-        self._sizer.Add(wx.StaticText(self, wx.ID_ANY,
-                       _("Select the desired plugins and then Click Download")),
-                        0, wx.ALIGN_CENTER)
-        self._sizer.Add(self._list, 1, wx.EXPAND)
-        self._sizer.Add(wx.Size(5, 5))
+        sizer = wx.BoxSizer(wx.VERTICAL)
+        sizer.Add(wx.StaticText(self, wx.ID_ANY,
+                  _("Select the desired plugins and then Click Download")),
+                  0, wx.ALIGN_CENTER)
+        sizer.Add(self._list, 1, wx.EXPAND)
+        sizer.Add((5, 5))
         bsizer = wx.BoxSizer(wx.HORIZONTAL)
         bsizer.Add(self._downlb, 0, wx.ALIGN_RIGHT)
-        bsizer.Add(wx.Size(5, 5))
-        self._sizer.Add(bsizer, 0, wx.ALIGN_RIGHT)
-        self._sizer.Add(wx.Size(5, 5))
-        self.SetSizer(self._sizer)
+        bsizer.Add((5, 5))
+        sizer.Add(bsizer, 0, wx.ALIGN_RIGHT)
+        sizer.Add((5, 5))
+        self.SetSizer(sizer)
 
         # Event Handlers
         self.Bind(wx.EVT_BUTTON, self.OnButton)
         self.Bind(ed_event.EVT_NOTIFY, self.OnNotify)
 
-    def _DownloadPlugin(self, *args):
-        """Downloads the plugin at the given url.
-        @note: *args is really a string that has been exploded
-        @return: name, completed, egg data
-        @rtype: tuple
-
-        """
-        url = "".join(args)
-        egg = None
-        try:
-            h_file = urllib.urlopen(url)
-            egg = h_file.read()
-            h_file.close()
-        finally:
-            return (url.split("/")[-1], True, egg)
-
-    # The obtained meta data must be served as a file that is formated
-    # as follows. Each meta data item must be on a single line with
-    # each set of meta data for different plugins separated by three
-    # hash marks '###'.
-    def _GetPluginListData(self, url=PLUGIN_REPO):
-        """Gets the list of plugins and their related meta data
-        as a string and returns it.
-        @return: list of data of available plugins from website
-        @todo: possibly process this on a separate thread to keep the 
-               gui responsive when switching to this panel.
-        
-        """
-        text = u''
-        try:
-            h_file = urllib.urlopen(url)
-            text = h_file.read()
-            h_file.close()
-        finally:
-            return text.split("###")
-
     def _ResultCatcher(self, delayedResult):
         """Catches the results from the download worker threads"""
         frame = self.GetGrandParent()
@@ -550,9 +500,10 @@ class DownloadPanel(wx.Panel):
                 self._p_list = self.FormatPluginList(result)
                 self.PopulateList()
                 frame.SetStatusText(_("Select plugins to download"), 0)
-                wx.CallAfter(frame.Busy, False)
         except Exception, msg:
+            util.Log("[plugdlg][err] Download failed " + str(msg))
             frame.SetStatusText(_("Unable to retrieve plugin list"), 0)
+        wx.CallAfter(frame.Busy, False)
 
     def FormatPluginList(self, data):
         """Formats a list of plugin data served by the server into
@@ -568,21 +519,25 @@ class DownloadPanel(wx.Panel):
 
         for meta in plugins:
             data = meta.split("\n")
+
             if len(data) < 4:
                 continue
+
             tmpdat = PluginData()
             for attr in data:
                 tmp = attr.split("=")
                 if len(tmp) != 2:
                     continue
+
                 set_map = {'author' : tmpdat.SetAuthor,
                            'version' : tmpdat.SetVersion,
                            'name' : tmpdat.SetName,
-                           'url' : tmpdat.SetUrl,
-                           'description' : tmpdat.SetDescription}
+                           'description' : tmpdat.SetDescription,
+                           'url' : tmpdat.SetUrl}
                 funct = set_map.get(tmp[0].lower(), None)
                 if funct:
                     funct(tmp[1].strip())
+
             if tmpdat.GetName() != u'':
                 p_list[tmpdat.GetName()] = tmpdat
 
@@ -590,13 +545,13 @@ class DownloadPanel(wx.Panel):
         config_pg = self.GetParent().GetPage(CONFIG_PG)
         to_clean = list()
         for pin in p_list:
-            ver = p_list[pin].GetVersion()
-            pin_id = p_list[pin].GetName() + ver
             cfg_id = config_pg.GetItemIdentifier(pin.lower())
-            if cfg_id is not None and cfg_id[1] >= ver:
+            if cfg_id is not None and cfg_id[1] >= p_list[pin].GetVersion():
                 to_clean.append(pin)
+
         for item in to_clean:
             del p_list[item]
+
         return p_list
 
     def GetDownloadedData(self):
@@ -630,16 +585,15 @@ class DownloadPanel(wx.Panel):
             urls = list()
             for item in self._dl_list:
                 if self._dl_list[item] and item in self._p_list:
-                    urls.append(BASE_URL + self._p_list[item].GetUrl())
+                    urls.append(self._p_list[item].GetUrl())
             self._eggcount = len(urls)
-            
+
             # Start a separate thread to download each selection
             for egg in range(len(urls)):
                 self.GetGrandParent().SetStatusText(_("Downloading") + "...", 0)
                 self.GetGrandParent().Busy(True)
-                delayedresult.startWorker(self._ResultCatcher, 
-                                          self._DownloadPlugin,
-                                          wargs = (urls[egg]), jobID = egg)
+                delayedresult.startWorker(self._ResultCatcher, _DownloadPlugin,
+                                          wargs=(urls[egg]), jobID=egg)
         else:
             evt.Skip()
 
@@ -653,9 +607,9 @@ class DownloadPanel(wx.Panel):
         index = evt.GetId()
         flag = evt.GetValue()
         pin = self._list.GetItemText(index)
+        self._dl_list[pin] = flag
         if flag:
             self._downlb.Enable()
-            self._dl_list[pin] = flag
         else:
             for item in self._dl_list:
                 if self._dl_list[item]:
@@ -663,6 +617,7 @@ class DownloadPanel(wx.Panel):
                     break
             else:
                 self._downlb.Disable()
+
             if self._dl_list.has_key(pin):
                 del self._dl_list[pin]
 
@@ -684,7 +639,7 @@ class DownloadPanel(wx.Panel):
 
         if self._list.GetItemCount():
             self._list.SetColumnWidth(0, wx.LIST_AUTOSIZE)
-            self._list.SetColumnWidth(1, wx.LIST_AUTOSIZE)
+            self._list.SetColumnWidth(1, self.GetTextExtent("0" * 35)[0])
             self._list.SetColumnWidth(2, wx.LIST_AUTOSIZE)
             self._list.SetColumnWidth(3, wx.LIST_AUTOSIZE)
             self._list.SendSizeEvent()
@@ -718,10 +673,54 @@ class DownloadPanel(wx.Panel):
         frame =  self.GetGrandParent()
         frame.SetStatusText(_("Retrieving Plugin List") + "...", 0)
         frame.Busy(True)
-        delayedresult.startWorker(self._UpdateCatcher,
-                                  self._GetPluginListData,
+        delayedresult.startWorker(self._UpdateCatcher, _GetPluginListData,
                                   wkwargs={'url' : url}, jobID='update')
 
+#-----------------------------------------------------------------------------#
+# Download utility functions
+
+# The obtained meta data must be served as a file that is formated
+# as follows. Each meta data item must be on a single line with
+# each set of meta data for different plugins separated by three
+# hash marks '###'.
+def _GetPluginListData(url=PLUGIN_REPO):
+    """Gets the list of plugins and their related meta data
+    as a string and returns it.
+    @return: list of data of available plugins from website
+    
+    """
+    text = u''
+    try:
+        try:
+            h_file = urllib.urlopen(url)
+            text = h_file.read()
+            h_file.close()
+        except (IOError, OSError), msg:
+            util.Log("[plugdlg][err] %s" % str(msg))
+    finally:
+        return text.split("###")
+
+def _DownloadPlugin(*args):
+    """Downloads the plugin at the given url.
+    @note: *args is really a string that has been exploded
+    @return: name, completed, egg data
+    @rtype: tuple
+
+    """
+    url = "".join(args)
+    egg = None
+    try:
+        try:
+            h_file = urllib.urlopen(url)
+            egg = h_file.read()
+            h_file.close()
+        except (IOError, OSError), msg:
+            util.Log("[plugdlg][err] %s" % str(msg))
+    finally:
+        return (url.split("/")[-1], True, egg)
+
+#-----------------------------------------------------------------------------#
+
 class InstallPanel(wx.Panel):
     """Creates a panel for installing plugins."""
     ID_INSTALL = wx.NewId()
@@ -729,12 +728,11 @@ class InstallPanel(wx.Panel):
     ID_SYS = wx.NewId()
     ID_REMOVE_ITEM = wx.NewId()
 
-    def __init__(self, parent, id_=wx.ID_ANY, style=wx.NO_BORDER):
+    def __init__(self, parent, style=wx.NO_BORDER):
         """Initializes the panel"""
-        wx.Panel.__init__(self, parent, id_, style=style)
+        wx.Panel.__init__(self, parent, style=style)
 
         # Attributes
-        self._sizer = wx.BoxSizer(wx.VERTICAL)
         lbl = wx.StaticText(self, wx.ID_ANY,
                             _("Click on Install to install the plugins "
                               "in the list"))
@@ -755,24 +753,23 @@ class InstallPanel(wx.Panel):
         toolt = wx.ToolTip(_("Install the plugins for all users\n"
                              " **requires administrative privileges**"))
         self._syscb.SetToolTip(toolt)
-        if not util.CanWrite(ed_glob.CONFIG['SYS_PLUGIN_DIR']):
+        if not os.access(ed_glob.CONFIG['SYS_PLUGIN_DIR'], os.R_OK | os.W_OK):
             self._syscb.Disable()
 
         # Layout Panel
-        self._sizer.Add(lbl, 0, wx.ALIGN_CENTER)
-        self._sizer.Add(self._install, 1, wx.EXPAND)
-        self._sizer.Add(wx.Size(5, 5))
+        sizer = wx.BoxSizer(wx.VERTICAL)
+        sizer.AddMany([(lbl, 0, wx.ALIGN_CENTER), 
+                       (self._install, 1, wx.EXPAND),
+                       ((5, 5))])
         bsizer = wx.BoxSizer(wx.HORIZONTAL)
-        bsizer.Add(wx.Size(5, 5))
-        bsizer.Add(self._usercb, 0, wx.ALIGN_LEFT)
-        bsizer.Add(wx.Size(5, 5))
-        bsizer.Add(self._syscb, 0, wx.ALIGN_LEFT)
+        bsizer.AddMany([((5, 5)), (self._usercb, 0, wx.ALIGN_LEFT),
+                        ((5, 5)), (self._syscb, 0, wx.ALIGN_LEFT)])
         bsizer.AddStretchSpacer()
         bsizer.Add(self._instb, 0, wx.ALIGN_RIGHT)
-        bsizer.Add(wx.Size(5, 5))
-        self._sizer.Add(bsizer, 0, wx.EXPAND)
-        self._sizer.Add(wx.Size(5, 5))
-        self.SetSizer(self._sizer)
+        bsizer.Add((5, 5))
+        sizer.Add(bsizer, 0, wx.EXPAND)
+        sizer.Add((5, 5))
+        self.SetSizer(sizer)
         self.SendSizeEvent()
 
         # Event Handlers
@@ -809,7 +806,7 @@ class InstallPanel(wx.Panel):
                 writer = file(inst_loc + egg_name, "wb")
                 writer.write(egg)
                 writer.close()
-            except IOError:
+            except (IOError, OSError):
                 continue
             else:
                 # If successfully installed remove from list
@@ -830,6 +827,9 @@ class InstallPanel(wx.Panel):
             result = dlg.ShowModal()
             dlg.Destroy()
             if result == wx.ID_YES:
+                # Note: need to do this because Setselection doesn't fire a
+                #       page change.
+                wx.GetApp().GetPluginManager().ReInit()
                 self.GetParent().SetSelection(CONFIG_PG)
             self._instb.Disable()
         else:
@@ -863,8 +863,7 @@ class InstallPanel(wx.Panel):
         @type evt: wx.EVT_BUTTON
 
         """
-        e_id = evt.GetId()
-        if e_id == self.ID_INSTALL:
+        if evt.GetId() == self.ID_INSTALL:
             self._Install()
         else:
             evt.Skip()
@@ -883,15 +882,10 @@ class InstallPanel(wx.Panel):
         if e_id == self.ID_USER:
             if not s_cb.IsEnabled():
                 u_cb.SetValue(True)
-            elif val:
-                s_cb.SetValue(False)
             else:
-                s_cb.SetValue(True)
+                s_cb.SetValue(not val)
         elif e_id == self.ID_SYS:
-            if val:
-                u_cb.SetValue(False)
-            else:
-                u_cb.SetValue(True)
+            u_cb.SetValue(not val)
         else:
             pass
         evt.Skip()
@@ -900,15 +894,15 @@ class InstallPanel(wx.Panel):
         """Get Drop files and place paths in control
         @status: should also check entry points in addition to filetype
         @param files: list of file paths
-        @postcondtion: all non egg files are filtered only placing
-                       the eggs in the list.
+        @postcondition: all non egg files are filtered only placing
+                        the eggs in the list.
         """
         # Filter out any files that are not eggs
-        good = list()
-        for fname in files:
-            if fname.split(u'.')[-1] == u'egg':
-                good.append(fname)
-        self._install.AppendItems(good)
+        good = [ fname for fname in files if fname.split(u'.')[-1] == u'egg' ]
+        for item in good:
+            if self._install.FindString(item) == wx.NOT_FOUND:
+                self._install.Append(item)
+
         if self._install.GetCount():
             self._instb.Enable()
 
@@ -923,6 +917,10 @@ class InstallPanel(wx.Panel):
             item = self._install.GetSelection()
             if item != wx.NOT_FOUND:
                 self._install.Delete(item)
+
+            if not self._install.GetCount():
+                self._instb.Disable()
+
         evt.Skip()
 
 #--------------------------------------------------------------------------#
@@ -982,30 +980,29 @@ class PluginListCtrl(wx.ListCtrl,
         """Does a smart add to the list that will insert the given
         a PluginData item alphabetically into the table based on
         the name value.
-        @postcondition: plugin is inserted alphabetically into list
+        @param pi_data: PluginData object
+        @keyword check: Should the checkbox be checked
 
         """
-        items = self.GetItemCount()
-        names = list()
-        for item in range(items):
-            names.append(self.GetItem(item).GetText())
-        before = u''
-        for name in names:
-            if pi_data.GetName() > name:
-                before = name
+        pname = pi_data.GetName()
+        for item in xrange(self.GetItemCount()):
+            if pname < self.GetItemText(item):
+                self.InsertStringItem(item, pi_data.GetName().strip())
+                self.SetStringItem(item, 1, pi_data.GetDescription().strip())
+                self.SetStringItem(item, 2, re.sub(r"\<+.*\>", '', 
+                                                   pi_data.GetAuthor().strip()))
+                self.SetStringItem(item, 3, pi_data.GetVersion().strip())
+                self.CheckItem(item, check)
                 break
-        if before not in names:
-            index = 0
         else:
-            index = names.index(before) - 1
-        if index == -1:
-            index = 0
-        self.InsertStringItem(index, pi_data.GetName())
-        self.SetStringItem(index, 1, pi_data.GetDescription())
-        self.SetStringItem(index, 2, pi_data.GetAuthor())
-        self.SetStringItem(index, 3, pi_data.GetVersion())
-        self.CheckItem(index, check)
+            self.Append((pi_data.GetName().strip(), 
+                         pi_data.GetDescription().strip(), 
+                         re.sub(r"\<+.*\>", '', pi_data.GetAuthor().strip()), 
+                         pi_data.GetVersion().strip()))
 
+            self.CheckItem(self.GetItemCount()-1, check)
+
+#-----------------------------------------------------------------------------#
 class PluginData(plugin.PluginData):
     """Plugin Metadata storage class used to store data
     about plugins and where to download them from
@@ -1014,6 +1011,11 @@ class PluginData(plugin.PluginData):
     """
     def __init__(self, name=u'', descript=u'', author=u'', \
                  ver=u'', url=u''):
+        """Extends PluginData to include information about url
+        to get it from.
+        @param url: url to download plugin from
+
+        """
         plugin.PluginData.__init__(self, name, descript, author, ver)
         self._url = url
 
