@@ -1,24 +1,12 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: plugin.py                                                             #
+# Purpose: Plugin system architecture                                         #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 #
-# Some of the code in this document is directly derived from trac
+# Some of the code in this document was derived from trac's plugin architecture
 #
 # Copyright (C) 2003-2006 Edgewall Software
 # All rights reserved.
@@ -73,16 +61,12 @@
 # activated plugin class members being held in memory is not likely to
 # be very large it seems like
 #
-# METHODS:
-#
-#
-#
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: plugin.py 525 2007-09-26 07:50:18Z CodyPrecord $"
-__revision__ = "$Revision: 525 $"
+__cvsid__ = "$Id: plugin.py 49576 2007-11-01 07:53:01Z CJP $"
+__revision__ = "$Revision: 49576 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -115,6 +99,8 @@ class Interface(object):
     """
     pass
 
+#-----------------------------------------------------------------------------#
+
 class ExtensionPoint(property):
     """Declares what L{Interface} a plugin is extending"""
     def __init__(self, interface):
@@ -130,7 +116,7 @@ class ExtensionPoint(property):
         return '<ExtensionPoint %s>' % self.interface.__name__
 
     def Extensions(self, component):
-        """@return a list of plugins that declare to impliment the
+        """@return: a list of plugins that declare to impliment the
         given extension point.
 
         """
@@ -138,6 +124,8 @@ class ExtensionPoint(property):
         extensions = PluginMeta._registry.get(self.interface, [])
         return filter(None, [component[cls] for cls in extensions])
 
+#-----------------------------------------------------------------------------#
+
 class PluginMeta(type):
     """Acts as the registration point for plugin entrypoint objects.
     It makes sure that only a single instance of any particular entry
@@ -147,7 +135,7 @@ class PluginMeta(type):
     _plugins = list()
     _registry = dict()
     def __new__(mcs, name, bases, d):
-        """@return a new metaclass object"""
+        """@return: a new metaclass object"""
         d['_implements'] = _implements[:]
         del _implements[:]
         new_obj = type.__new__(mcs, name, bases, d)
@@ -166,6 +154,8 @@ class PluginMeta(type):
                 PluginMeta._registry.setdefault(interface, []).append(new_obj)
         return new_obj
 
+#-----------------------------------------------------------------------------#
+
 class Plugin(object):
     """Base class for all plugin type objects"""
     __metaclass__ = PluginMeta
@@ -191,6 +181,8 @@ class Plugin(object):
             self.pluginmgr = pluginmgr
         return self
 
+#-----------------------------------------------------------------------------#
+
 class PluginData(object):
     """A storage class for representing data about a Plugin
     @see: L{Plugin}
@@ -274,6 +266,8 @@ class PluginData(object):
                 ver = u''
         self._version = ver
 
+#-----------------------------------------------------------------------------#
+
 def Implements(*interfaces):
     """Used by L{Plugin}s to declare the interface that they
     implment/extend.
@@ -289,7 +283,7 @@ class PluginManager(object):
     also provides an interface into loading and unloading plugins.
     @status: Allows for dynamic loading of plugins but they can not
              be called/used until the editor has been restarted.
-    @todo: complete functions for allowing dynamic loading and unloading of
+    @todo: Complete functions for allowing dynamic loading and unloading of
            of plugins. As well as allowing loaded but inactive plugins to be
            initiated without needing to restart the editor.
 
@@ -361,6 +355,8 @@ class PluginManager(object):
 
         """
         if pkg_resources != None:
+            path = [ pname.decode(sys.getfilesystemencoding()) 
+                     for pname in path ]
             env = pkg_resources.Environment(path)
         else:
             self.LOG("[pluginmgr][warn] setup tools is not installed")
@@ -383,8 +379,8 @@ class PluginManager(object):
     def EnablePlugin(self, plugin):
         """Enables a named plugin.
         @precondition: plugin must be managed by this manager instance
-        @postcondtion: plugin is added to activate list for activation on
-                       next program start.
+        @postcondition: plugin is added to activate list for activation on
+                        next program start.
 
         """
         self._config[plugin] = True
@@ -422,7 +418,7 @@ class PluginManager(object):
         """Initializes the plugins that are contained in the given
         enviroment. After calling this the list of available plugins
         can be obtained by calling GetAvailPlugins.
-        @note: plugins must emit the L{ENTRY_POINT} defined in this file
+        @note: plugins must emit the ENTRY_POINT defined in this file
         @postcondition: all plugins in the environment are initialized
 
         """
@@ -436,8 +432,9 @@ class PluginManager(object):
                 try:
                     entry_point = egg.get_entry_info(ENTRYPOINT, name)
                     cls = entry_point.load()
-                except ImportError, msg:
-                    self.LOG("[pluginmgr][err] %s" % str(msg))
+                except Exception, msg:
+                    self.LOG("[pluginmgr][err] Couldn't Load %s: %s" % \
+                                                          (str(name), str(msg)))
                 else:
                     try:
                         self._plugins[cls] = cls(self)
