@@ -1,38 +1,27 @@
-##############################################################################
-#    Copyright (C) 2007 Cody Precord                                         #
-#    cprecord@editra.org                                                     #
-#                                                                            #
-#    Editra is free software; you can redistribute it and#or modify          #
-#    it under the terms of the GNU General Public License as published by    #
-#    the Free Software Foundation; either version 2 of the License, or       #
-#    (at your option) any later version.                                     #
-#                                                                            #
-#    Editra is distributed in the hope that it will be useful,               #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
-#    GNU General Public License for more details.                            #
-#                                                                            #
-#    You should have received a copy of the GNU General Public License       #
-#    along with this program; if not, write to the                           #
-#    Free Software Foundation, Inc.,                                         #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.               #
-##############################################################################
+###############################################################################
+# Name: prefdlg.py                                                            #
+# Purpose: UI for configuring User Profile                                    #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #----------------------------------------------------------------------------#
-# FILE: prefdlg.py
-# LANGUAGE: Python							   
-#
-# SUMMARY:
-#     The classes and functions contained in this file are used for creating
-#     the preference dialog.
-#
+# FILE: prefdlg.py                                                           #
+# LANGUAGE: Python							                                 #
+#                                                                            #
+# SUMMARY:                                                                   #
+#   The classes and functions contained in this file are used for creating   #
+#  the preference dialog that allows for dynamically configuring most of the #
+#  options and setting of the program by setting values in the Profile.      #
+#                                                                            #
 #----------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 546 2007-09-27 11:36:02Z CodyPrecord $"
-__revision__ = "$Revision: 546 $"
+__svnid__ = "$Id: prefdlg.py 49575 2007-11-01 07:50:27Z CJP $"
+__revision__ = "$Revision: 49575 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -60,18 +49,9 @@ ID_LATE_BOX     = wx.NewId()
 _ = wx.GetTranslation
 #----------------------------------------------------------------------------#
 # Class Globals
-# def ProfilePage(self):
-#     """Creates the profile editor page"""
-#     prof_panel = wx.Panel(self, wx.ID_ANY)
-#     border = wx.BoxSizer(wx.VERTICAL)
-#     # Add Profile Viewer to Panel
-#     plist = ProfileListCtrl(prof_panel)
-#     border.Add(plist, 1, wx.EXPAND)
-#     prof_panel.SetSizer(border)
 from wx import ImageFromStream, BitmapFromImage, EmptyIcon
 import cStringIO, zlib
 
-
 def getData():
     """Gets the data of the button background"""
     return zlib.decompress(
@@ -140,19 +120,17 @@ class PreferencesDialog(wx.Frame):
     """
     __name__ = u'PreferencesDialog'
 
-    def __init__(self, parent, id_=wx.ID_ANY, title=u'',
+    def __init__(self, parent, id_=wx.ID_ANY,
                  style=wx.DEFAULT_DIALOG_STYLE | wx.TAB_TRAVERSAL):
         """Initialises the preference dialog
         @param parent: The parent window of this window
         @param id_: The id of this window
-        @param title: The title of the dialog
 
         """
-        wx.Frame.__init__(self, parent, id_, title, style=style)
+        wx.Frame.__init__(self, parent, id_, _("Preferences - Editra"), style=style)
         util.SetWindowIcon(self)
 
         # Extra Styles
-        self.SetExtraStyle(wx.FRAME_EX_CONTEXTHELP)
         self.SetTransparent(Profile_Get('ALPHA', 'int', 255))
         if wx.Platform == '__WXMAC__' and Profile_Get('METAL', 'bool', False):
             self.SetExtraStyle(wx.DIALOG_EX_METAL)
@@ -160,18 +138,18 @@ class PreferencesDialog(wx.Frame):
         # Attributes
         self._tbook = PrefTools(self)
         sizer = wx.BoxSizer(wx.VERTICAL)
-        hsizer = wx.BoxSizer(wx.HORIZONTAL)
-
-        # Bind Events
-        self.Bind(wx.EVT_CLOSE, self.OnClose)
 
         # Layout
         sizer.Add(self._tbook, 1, wx.EXPAND)
-        sizer.Add(hsizer, 0, wx.ALIGN_BOTTOM)
         self.SetSizer(sizer)
         self.SetAutoLayout(True)
+        self.SetInitialSize()
         wx.GetApp().RegisterWindow(repr(self), self, True)
 
+        # Bind Events
+        self.Bind(wx.EVT_CLOSE, self.OnClose)
+        self.Bind(wx.EVT_SHOW, self.OnShow)
+
     def OnClose(self, evt):
         """Hanles the window closer event
         @param evt: Event that called this handler
@@ -180,6 +158,16 @@ class PreferencesDialog(wx.Frame):
         wx.GetApp().UnRegisterWindow(repr(self))
         evt.Skip()
 
+    def OnShow(self, evt):
+        """Hanles the window closer event
+        @param evt: Event that called this handler
+
+        """
+        self._tbook.OnPageChanged()
+        evt.Skip()
+
+#-----------------------------------------------------------------------------#
+
 class PrefTools(wx.Toolbook):
     """Main sections of the configuration pages
     @note: implements the top level book control for the prefdlg
@@ -204,8 +192,6 @@ class PrefTools(wx.Toolbook):
         """
         wx.Toolbook.__init__(self, parent, tbid, style=style)
 
-#         toolb = self.GetToolBar()
-#         toolb.SetWindowStyle(toolb.GetWindowStyle() | wx.TB_NODIVIDER)
         # Attributes
         self.LOG = wx.GetApp().GetLog()
         self._imglst = wx.ImageList(32, 32)
@@ -230,22 +216,23 @@ class PrefTools(wx.Toolbook):
         self.Bind(wx.EVT_TOOLBOOK_PAGE_CHANGED, self.OnPageChanged)
         self.Bind(wx.EVT_PAINT, self.OnPaint)
 
-    def OnPageChanged(self, evt):
+    def OnPageChanged(self, evt=None):
         """Resizes the dialog based on the pages size
         @todo: animate the resizing so its smoother
 
         """
         self.LOG("[prefdlg][toolbook][evt] page changed")
-        page = evt.GetSelection()
+        page = self.GetSelection()
         page = self.GetPage(page)
         page.SetInitialSize()
         parent = self.GetParent()
         psz = page.GetSize()
         tbh = self.GetToolBar().GetSize().GetHeight()
-        parent.SetClientSize((psz.GetWidth() + 10, psz.GetHeight() + tbh + 15))
+        parent.SetClientSize((psz.GetWidth(), psz.GetHeight() + tbh))
         parent.SendSizeEvent()
         parent.Layout()
-        evt.Skip()
+        if evt is not None:
+            evt.Skip()
 
     def OnPaint(self, evt):
         """Paint the toolbar's background
@@ -351,7 +338,7 @@ class GeneralPanel(PrefPanelBase):
 
     def _DoLayout(self):
         """Add the controls and do the layout
-        @note: Controls are layed out using L{wx.GridBagSizer}
+        @note: do not call this after __init__
 
         """
         # Startup Section
@@ -422,7 +409,8 @@ class GeneralPanel(PrefPanelBase):
                        (pos_cb, (9, 2), (1, 3)),
                        (chkmod_cb, (10, 2), (1, 2))])
         sizer.AddMany([(locale, (12, 1)),
-                       (lsizer, (12, 2), (1, 3))])
+                       (lsizer, (12, 2), (1, 3)),
+                       ((15, 15), (13, 0))])
         self.SetSizer(sizer)
 
     def OnCheck(self, evt):
@@ -464,7 +452,7 @@ class DocumentPanel(PrefPanelBase):
     """Creates a panel with controls for Editra's editing settings
     @summary: Conatains a L{wx.Notebook} that contains a number of pages
               with setting controls for how documents are handled by the
-              L{ed_stc.EDSTC} text control.
+              L{ed_stc.EditraStc} text control.
 
     """
     def __init__(self, parent):
@@ -481,7 +469,7 @@ class DocumentPanel(PrefPanelBase):
 
     def _DoLayout(self):
         """Do the layout of the panel
-        @note: Controls are layed out using L{wx.GridBagSizer}
+        @note: Do not call this after __init__
 
         """
         sizer = wx.GridBagSizer()
@@ -489,6 +477,7 @@ class DocumentPanel(PrefPanelBase):
         self._nb.AddPage(DocCodePanel(self._nb), _("Code"))
         self._nb.AddPage(DocSyntaxPanel(self._nb), _("Syntax Highlighting"))
         sizer.Add(self._nb, (1, 1))
+        sizer.Add((5, 5), (2, 2))
         self.SetSizer(sizer)
 
 class DocGenPanel(wx.Panel):
@@ -518,7 +507,7 @@ class DocGenPanel(wx.Panel):
 
     def _DoLayout(self):
         """Layout the controls
-        @note: Controls are layed out using L{wx.GridBagSizer}
+        @note: Do not call this after __init__
 
         """
         # Format Section
@@ -547,6 +536,8 @@ class DocGenPanel(wx.Panel):
         sws_cb.SetValue(Profile_Get('SHOW_WS'))
         ww_cb = wx.CheckBox(self, ed_glob.ID_WORD_WRAP, _("Word Wrap"))
         ww_cb.SetValue(Profile_Get('WRAP'))
+        if wx.Platform == '__WXMAC__':
+            ww_cb.SetToolTip(wx.ToolTip(_("Turn off for better performance")))
 
         # Font Options
         font_lbl = wx.StaticText(self, label=_("Primary Font") + u": ")
@@ -617,8 +608,7 @@ class DocGenPanel(wx.Panel):
                     ed_glob.ID_SHOW_WS, ed_glob.ID_WORD_WRAP,
                     ed_glob.ID_PREF_AALIAS]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
-            for mainw in wx.GetApp().GetMainWindows():
-                mainw.nb.UpdateTextControls()
+            wx.CallLater(25, DoUpdates)
         else:
             evt.Skip()
 
@@ -645,7 +635,7 @@ class DocCodePanel(wx.Panel):
 
     def _DoLayout(self):
         """Layout the page
-        @note: Controls are layed out using L{wx.GridBagSizer}
+        @note: Do not call this after __init__
 
         """
         # Visual Helpers Section
@@ -657,9 +647,12 @@ class DocCodePanel(wx.Panel):
         fold_cb.SetValue(Profile_Get('CODE_FOLD'))
         edge_cb = wx.CheckBox(self, ed_glob.ID_SHOW_EDGE, _("Edge Guide"))
         edge_cb.SetValue(Profile_Get('SHOW_EDGE'))
-        
+
+        edge_size = (-1, -1)
+        if wx.Platform == '__WXGTK__':
+            edge_size = (150, 15)
         edge_sl = wx.Slider(self, ed_glob.ID_PREF_EDGE, Profile_Get('EDGE'),
-                            0, 100, size=(-1, 15), style=wx.SL_HORIZONTAL | \
+                            0, 100, size=edge_size, style=wx.SL_HORIZONTAL | \
                             wx.SL_AUTOTICKS | wx.SL_LABELS)
         edge_sl.SetTickFreq(5, 1)
         if wx.Platform == '__WXMAC__':
@@ -702,9 +695,7 @@ class DocCodePanel(wx.Panel):
                     ed_glob.ID_AUTOCOMP, ed_glob.ID_AUTOINDENT,
                     ed_glob.ID_PREF_EDGE, ed_glob.ID_VI_MODE]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
-
-            for mainw in wx.GetApp().GetMainWindows():
-                mainw.nb.UpdateTextControls()
+            wx.CallLater(25, DoUpdates)
         else:
             evt.Skip()
 
@@ -752,12 +743,11 @@ class DocSyntaxPanel(wx.Panel):
 
     def _DoLayout(self):
         """Layout all the controls
-        @note: Controls are layed out using L{wx.GridBagSizer}
+        @note: Do not call this after __init__
 
         """
         sizer = wx.BoxSizer(wx.VERTICAL)
         
-
         # Syntax Settings
         syn_cb = wx.CheckBox(self, ed_glob.ID_SYNTAX, _("Syntax Highlighting"))
         syn_cb.SetValue(Profile_Get('SYNTAX'))
@@ -855,15 +845,16 @@ class AppearancePanel(PrefPanelBase):
 
     def _DoLayout(self):
         """Add and layout the widgets
-        @note: Controls are layed out using L{wx.GridBagSizer}
+        @note: Do not call this after __init__
 
         """
         # Icons Section
+        from ed_theme import BitmapProvider
+        icons = ['Default']
+        icons.extend(BitmapProvider(wx.GetApp().GetPluginManager()).GetThemes())
         tb_icont = wx.StaticText(self, wx.ID_ANY, _("Icon Theme") + u": ")
         tb_icon = ExChoice(self, ed_glob.ID_PREF_ICON,
-                            choices=util.GetResources(u"pixmaps" + \
-                                                      util.GetPathChar() + \
-                                                      u"theme"), 
+                            choices=icons, 
                             default=Profile_Get('ICONS', 'str').title())
         tb_isz_lbl = wx.StaticText(self, wx.ID_ANY, \
                                    _("Toolbar Icon Size") + u": ")
@@ -890,9 +881,12 @@ class AppearancePanel(PrefPanelBase):
         wp_cb.SetValue(Profile_Get('SET_WPOS'))
 
         # Misc
+        trans_size = (-1, -1)
+        if wx.Platform == '__WXGTK__':
+            trans_size = (200, 15)
         trans_lbl = wx.StaticText(self, wx.ID_ANY, _("Transparency") + u": ")
         trans = wx.Slider(self, ed_glob.ID_TRANSPARENCY, 
-                          Profile_Get('ALPHA'), 100, 255, 
+                          Profile_Get('ALPHA'), 100, 255, size=trans_size,
                           style=wx.SL_HORIZONTAL | wx.SL_AUTOTICKS | 
                                 wx.SL_LABELS)
         tsizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -923,7 +917,8 @@ class AppearancePanel(PrefPanelBase):
         sizer.Add((5, 5), (8, 0))
         sizer.Add(wx.StaticText(self, label=_("Misc") + u": "), (8, 1))
         sizer.AddMany([(tsizer, (8, 2), (1, 2)),
-                       (m_cb, (9, 2), (1, 2))])
+                       (m_cb, (9, 2), (1, 2)),
+                       ((15, 15), (10, 2))])
         self.SetSizer(sizer)
 
     def OnCheck(self, evt):
@@ -936,7 +931,6 @@ class AppearancePanel(PrefPanelBase):
         if e_id in [ed_glob.ID_PREF_WPOS, ed_glob.ID_PREF_WSIZE]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], val)
         elif e_id == ed_glob.ID_PREF_METAL:
-            windows = wx.GetApp().GetOpenWindows()
             Profile_Set(ed_glob.ID_2_PROF[e_id], val)
         else:
             evt.Skip()
@@ -953,11 +947,12 @@ class AppearancePanel(PrefPanelBase):
             if e_id == ed_glob.ID_PREF_ICONSZ:
                 val = (int(val), int(val))
             Profile_Set(ed_glob.ID_2_PROF[e_id], val)
+            wx.GetApp().ReloadArtProvider()
             for mainw in wx.GetApp().GetMainWindows():
                 toolbar = mainw.GetToolBar()
                 if toolbar is not None and \
                    (toolbar.GetToolTheme() != Profile_Get('ICONS')) \
-                   or (toolbar.GetToolSize() != Profile_Get('ICON_SZ')):
+                   or (toolbar.GetToolBitmapSize() != Profile_Get('ICON_SZ')):
                     toolbar.ReInit()
                 mainw.UpdateToolBar()
 
@@ -1014,7 +1009,7 @@ class UpdatePanel(PrefPanelBase):
 
     def _DoLayout(self):
         """Do the layout of the panel
-        @note: Controls are layed out using L{wx.GridBagSizer}
+        @note: Do not call this after __init__
 
         """
         # Status text and bar
@@ -1037,14 +1032,17 @@ class UpdatePanel(PrefPanelBase):
         dl_b.Disable()
 
         # Layout Controls
+        statsz = wx.BoxSizer(wx.HORIZONTAL)
+        statsz.AddMany([((15, 15), 0),
+                        (cur_sz, 0),
+                        ((20, 10), 1),
+                        (upd_bsz, 0),
+                        ((15, 15), 0)])
         sizer = wx.GridBagSizer()
-        sizer.Add((5, 5), (0, 0))
-        sizer.AddMany([(cur_sz, (1, 2), (1, 3), wx.ALIGN_RIGHT),
-                       (upd_bsz, (1, 6), (1, 3)),
-                       (e_update, (3, 3), (1, 5), wx.EXPAND),
-                       ((5, 5), (4, 0)),
-                       (check_b, (5, 4)), (dl_b, (5, 6)),
-                       ((5, 5), (6, 0))])
+        sizer.AddMany([(statsz, (1, 1), (2, 5), wx.EXPAND),
+                       (e_update, (4, 1), (1, 5), wx.EXPAND),
+                       (check_b, (6, 2), (1, 1)), (dl_b, (6, 4), (1, 1)),
+                       ((15, 15), (7, 2)), ((5, 5), (7, 7))])
         self.SetSizer(sizer)
 
     def OnButton(self, evt):
@@ -1096,6 +1094,7 @@ class UpdatePanel(PrefPanelBase):
         nbevt = wx.NotebookEvent(wx.wxEVT_COMMAND_TOOLBOOK_PAGE_CHANGED, 
                                  0, curr_pg, curr_pg)
         wx.PostEvent(self.GetParent(), nbevt)
+        self.Refresh()
 
 #----------------------------------------------------------------------------#
 # Custom controls for the Preference dialog
@@ -1206,8 +1205,8 @@ class ExtListCtrl(wx.ListCtrl,
             self.SetStringItem(index, self.EXT_COL, \
                                u'  %s' % u' '.join(self._extreg[key]))
             if not index % 2:
-                syscolor = wx.SystemSettings_GetColour(wx.SYS_COLOUR_3DLIGHT)
-                color = util.AdjustColour(syscolor, 75)
+                syscolor = wx.SystemSettings_GetColour(wx.SYS_COLOUR_HIGHLIGHT)
+                color = util.AdjustColour(syscolor, 45)
                 self.SetItemBackgroundColour(index, color)
 
         self.SetColumnWidth(self.FILE_COL, wx.LIST_AUTOSIZE)
@@ -1369,3 +1368,11 @@ class PyFontPicker(wx.Panel):
         self._button.SetToolTip(tip)
         tip = wx.ToolTip(tip.GetTip())
         wx.Panel.SetToolTip(self, tip)
+
+#-----------------------------------------------------------------------------#
+# Utility Functions
+
+def DoUpdates():
+    """Update all open text controls"""
+    for mainw in wx.GetApp().GetMainWindows():
+        mainw.nb.UpdateTextControls()
\ No newline at end of file
