@@ -1,22 +1,10 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: profiler.py                                                           #
+# Purpose: Editra's user profile services                                     #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -38,8 +26,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 545 2007-09-27 11:19:07Z CodyPrecord $"
-__revision__ = "$Revision: 545 $"
+__svnid__ = "$Id: profiler.py 49551 2007-10-31 12:01:14Z CJP $"
+__revision__ = "$Revision: 49551 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -71,7 +59,7 @@ _DEFAULTS = {
            'FHIST_LVL'  : 9,                # Filehistory length (9 is max)
            'FFILTER'    : 0,                # Last file filter used
            'GUIDES'     : True,             # Use Indentation guides
-           'ICONS'      : 'Nuovo',          # Icon Theme
+           'ICONS'      : 'Tango',          # Icon Theme
            'ICON_SZ'    : (24, 24),         # Toolbar Icon Size
            'LANG'       : 'Default',        # UI language
            'MODE'       : 'CODE',           # Overall editor mode
@@ -94,7 +82,7 @@ _DEFAULTS = {
            'TOOLBAR'    : True,             # Show Toolbar
            'USETABS'    : True,             # Use tabs instead of spaces
            'VI_EMU'     : False,            # Use Vi emulation mode 
-           'WRAP'       : True,             # Use Wordwrap
+           'WRAP'       : False,             # Use Wordwrap
            'WSIZE'      : (700, 450)        # Mainwindow size
           #FONT1 created at runtime by ed_styles as primary font           
           #FONT2 created at runtime by ed_styles as secondary font
@@ -177,7 +165,7 @@ class Profile(dict):
                 val = cPickle.load(fhandle)
                 fhandle.close()
             except (IOError, SystemError, OSError, 
-                    cPickle.UnpicklingError), msg:
+                    cPickle.UnpicklingError, EOFError), msg:
                 dev_tool.DEBUGP("[profile][err] %s" % str(msg))
             else:
                 if isinstance(val, dict):
@@ -215,38 +203,56 @@ class Profile(dict):
         if fmt is None:
             self.__setitem__(index, val)
         else:
-            tmp = _FromObject(val, fmt)
-            self.__setitem__(index, tmp)
+            self.__setitem__(index, _FromObject(val, fmt))
 
     def Write(self, path):
         """Write the dataset of this profile as a pickle
         @param path: path to where to write the pickle
-        @return: True on success/ False on failure
+        @return: True on success / False on failure
 
         """
         try:
+            self.Set('MYPROFILE', path)
             fhandle = open(path, 'wb')
             cPickle.dump(self, fhandle, cPickle.HIGHEST_PROTOCOL)
             fhandle.close()
+            UpdateProfileLoader()
         except (IOError, cPickle.PickleError), msg:
             dev_tool.DEBUGP("[profile][err] %s" % str(msg))
             return False
         else:
             return True
 
+    def Update(self, update=None):
+        """Update the profile using data from provided dictionary
+        or the default set if none is given.
+        @keyword update: dictionary of values to update from or None
+        @postcondition: All profile values from the update set are set
+                        in this profile. If update is None then the current
+                        set is only updated to include values from the
+                        DEFAULTS that are not currently present.
+
+        """
+        if update is None:
+            for key, val in _DEFAULTS.iteritems():
+                if not self.has_key(key):
+                    self.Set(key, val)            
+        else:
+            self.update(update)
+
     #---- End Public Members ----#
 
-# Profile convinience functions
+#-----------------------------------------------------------------------------#
+# Profile convenience functions
 def Profile_Del(item):
     """Removes an item from the profile
-    
-    @param item: items name
+    @param item: items key name
 
     """
     Profile().DeleteItem(item)
 
 def Profile_Get(index, fmt=None, default=None):
-    """Convinience for Profile().Get()
+    """Convenience for Profile().Get()
     @param index: profile index to retrieve
     @keyword fmt: format to get value as
     @keyword default: default value to return if not found
@@ -255,7 +261,7 @@ def Profile_Get(index, fmt=None, default=None):
     return Profile().Get(index, fmt, default)
 
 def Profile_Set(index, val, fmt=None):
-    """Convinience for Profile().Set()
+    """Convenience for Profile().Set()
     @param index: profile index to set
     @param val: value to set index to
     @keyword fmt: format to convert object from
@@ -268,10 +274,9 @@ def _FromObject(val, fmt):
     @param val: value to convert
     @param fmt: Format to convert to
     @type fmt: string
-    @todo: exception handling, 
 
     """
-    if fmt == u'font':
+    if fmt == u'font' and isinstance(val, wx.Font):
         return "%s,%s" % (val.GetFaceName(), val.GetPointSize())
     else:
         return val
@@ -331,6 +336,7 @@ def AddFileHistoryToProfile(file_history):
 
 def CalcVersionValue(ver_str="0.0.0"):
     """Calculates a version value from the provided dot-formated string
+    @keyword ver_str: Version string to calculate value of
 
     1) SPECIFICATION: Version value calculation AA.BBB.CCC
          - major values: < 1     (i.e 0.0.85 = 0.850)
@@ -338,9 +344,12 @@ def CalcVersionValue(ver_str="0.0.0"):
          - micro values: >= 1000 (i.e 1.1.85 = 1001.850)
 
     """
+    ver_str = ''.join([char for char in ver_str 
+                       if char.isdigit() or char == '.'])
     ver_lvl = ver_str.split(u".")
     if len(ver_lvl) < 3:
         return 0
+
     major = int(ver_lvl[0]) * 1000
     minor = int(ver_lvl[1])
     if len(ver_lvl[2]) <= 2:
@@ -349,16 +358,16 @@ def CalcVersionValue(ver_str="0.0.0"):
     return float(major) + float(minor) + micro
 
 def GetLoader():
-    """Finds the loader to use"""
+    """Finds the loader to use
+    @return: path to profile loader
+    @note: path may not exist, only returns the path to where the loader
+           should be.
+
+    """
     user_home = wx.GetHomeDir() + util.GetPathChar()
     rel_prof_path = ("." + PROG_NAME + util.GetPathChar() + 
                      "profiles" + util.GetPathChar() + ".loader2")
-
-    if os.path.exists(user_home + rel_prof_path):
-        loader = user_home + rel_prof_path
-    else:
-        loader = CONFIG['PROFILE_DIR'] + ".loader2"
-
+    loader = user_home + rel_prof_path
     return loader
 
 def GetProfileStr():
@@ -436,4 +445,3 @@ def UpdateProfileLoader():
     writer.write(u"\nVERSION\t" + VERSION)
     writer.close()
     return 0
-
