@@ -1,22 +1,10 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: style_editor.py                                                       #
+# Purpose: Syntax Highlighting configuration dialog                           #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -24,19 +12,17 @@
 # AUTHOR: Cody Precord                                                     #
 # LANGUAGE: Python                                                         #
 # SUMMARY:                                                                 #
-#    Provides an editor dialog for editing styles and generating style     #
-# sheets to use with editra's styled text controls.                        #
+#    Provides an editor dialog for graphically editing how the text is     #
+# presented in the editor when syntax highlighting is turned on. It does   #
+# this by taking the data from the controls and formating it into an Editra#
+# Style Sheet that the editor can load to configure the styles of the text.#
 #                                                                          #
-# METHODS:
-#
-#
-#
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: style_editor.py 551 2007-09-28 07:58:06Z CodyPrecord $"
-__revision__ = "$Revision: 551 $"
+__svnid__ = "$Id: style_editor.py 49458 2007-10-26 12:26:57Z CJP $"
+__revision__ = "$Revision: 49458 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -47,7 +33,7 @@ import wx.lib.colourselect as  csel
 import ed_glob
 from profiler import Profile_Get, Profile_Set
 import ed_stc
-from ed_style import StyleItem, StyleMgr
+from ed_style import StyleItem
 import ed_event
 import util
 import syntax.syntax as syntax
@@ -90,16 +76,15 @@ class StyleEditor(wx.Dialog):
 
         # Attributes
         self.LOG = wx.GetApp().GetLog()
-        self.preview = ed_stc.EDSTC(self, wx.ID_ANY, size=(-1, 200),
-                                    style=wx.SUNKEN_BORDER, use_dt=False)
-        self.styles_new = self.preview.GetStyleSet()
-        self.styles_orig = self.DuplicateStyleDict(self.styles_new)
-        self.settings_enabled = True
+        self.preview = ed_stc.EditraStc(self, wx.ID_ANY, size=(-1, 200),
+                                        style=wx.SUNKEN_BORDER, use_dt=False)
+        self.styles_orig = self.preview.GetStyleSet()
+        self.styles_new = DuplicateStyleDict(self.styles_orig)
+        self.preview.SetStyles('preview', self.styles_new, True)
         self.OpenPreviewFile('cpp')
 
         # Main Sizer
-        self.sizer = wx.BoxSizer(wx.VERTICAL)
-        self.sizer.Add((10, 10)) # Spacer
+        sizer = wx.BoxSizer(wx.VERTICAL)
 
         # Control Panel
         self.ctrl_pane = wx.Panel(self, wx.ID_ANY)
@@ -109,59 +94,56 @@ class StyleEditor(wx.Dialog):
 
         # Control Panel Left Column
         left_colum.AddMany([((10, 10), 0), 
-                            (self.StyleSheets(), 0, wx.ALIGN_LEFT),
+                            (self.__StyleSheets(), 0, wx.ALIGN_LEFT),
                             ((10, 10), 0), 
-                            (self.LexerChoice(), 0, wx.ALIGN_LEFT),
+                            (self.__LexerChoice(), 0, wx.ALIGN_LEFT),
                             ((10, 10), 0),
-                            (self.StyleTags(), 0, wx.ALIGN_LEFT),
+                            (self.__StyleTags(), 1, wx.ALIGN_LEFT|wx.EXPAND),
                             ((10, 10), 0)])
         ctrl_sizer.Add(left_colum, 0, wx.ALIGN_LEFT)
 
         # Divider
         ctrl_sizer.Add(wx.StaticLine(self.ctrl_pane, size=(-1, 2), 
-                                     style = wx.LI_VERTICAL), 
+                                     style=wx.LI_VERTICAL), 
                        0, wx.ALIGN_CENTER_HORIZONTAL | wx.EXPAND)
         ctrl_sizer.Add((5, 5), 0)
 
         # Control Panel Right Column
-        right_colum.Add(self.Settings(), 1, wx.ALIGN_LEFT | wx.EXPAND)
-        ctrl_sizer.Add(right_colum, 1, wx.ALIGN_RIGHT | wx.EXPAND)
-        ctrl_sizer.Add((5, 5), 0)
+        right_colum.Add(self.__Settings(), 1, wx.ALIGN_LEFT | wx.EXPAND)
+        ctrl_sizer.AddMany([(right_colum, 1, wx.ALIGN_RIGHT | wx.EXPAND),
+                            ((5, 5), 0)])
 
         # Finish Control Panel Setup
         self.ctrl_pane.SetSizer(ctrl_sizer)
-        self.sizer.Add(self.ctrl_pane, 0, wx.ALIGN_CENTER)
+        sizer.AddMany([((10, 10)), (self.ctrl_pane, 0, wx.ALIGN_CENTER)])
 
         # Preview Area
         pre_sizer = wx.BoxSizer(wx.HORIZONTAL)
         pre_sizer.AddMany([((10, 10), 0), 
                            (wx.StaticText(self, label=_("Preview") + u": "), 
                             0, wx.ALIGN_LEFT)])
-        self.sizer.AddMany([((10, 10), 0), (pre_sizer, 0, wx.ALIGN_LEFT),
-                            (self.preview, 0, wx.EXPAND | wx.BOTTOM)])
+        sizer.AddMany([((10, 10), 0), (pre_sizer, 0, wx.ALIGN_LEFT),
+                       (self.preview, 0, wx.EXPAND | wx.BOTTOM)])
 
         # Create Buttons
         b_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        cancel_b = wx.Button(self, wx.ID_CANCEL, _("Cancel"))
-        save_b = wx.Button(self, wx.ID_SAVE, _("Export"))
         ok_b = wx.Button(self, wx.ID_OK, _("Ok"))
         ok_b.SetDefault()
-        b_sizer.AddMany([cancel_b, save_b, ok_b])
-        self.sizer.Add(b_sizer, 0, wx.ALIGN_RIGHT | \
-                                   wx.ALIGN_CENTER_VERTICAL | wx.ALL, 5)
+        b_sizer.AddMany([(wx.Button(self, wx.ID_CANCEL, _("Cancel"))), 
+                         (wx.Button(self, wx.ID_SAVE, _("Export"))), (ok_b)])
+        sizer.Add(b_sizer, 0, wx.ALIGN_RIGHT |
+                  wx.ALIGN_CENTER_VERTICAL | wx.ALL, 5)
 
         # Finish the Layout
-        self.SetSizer(self.sizer)
+        self.SetSizer(sizer)
         self.SetAutoLayout(True)
-        self.sizer.Fit(self)
-        tags = self.FindWindowById(ID_STYLES)
-        tags.SetSize((left_colum.GetSize()[0]*.90, 100))
+        sizer.Fit(self)
         self.EnableSettings(False)
 
         # Event Handlers
-        self.Bind(wx.EVT_BUTTON, self.OnCancel, id = wx.ID_CANCEL)
-        self.Bind(wx.EVT_BUTTON, self.OnOk, id = wx.ID_OK)
-        self.Bind(wx.EVT_BUTTON, self.OnExport, id = wx.ID_SAVE)
+        self.Bind(wx.EVT_BUTTON, self.OnCancel, id=wx.ID_CANCEL)
+        self.Bind(wx.EVT_BUTTON, self.OnOk, id=wx.ID_OK)
+        self.Bind(wx.EVT_BUTTON, self.OnExport, id=wx.ID_SAVE)
         self.Bind(wx.EVT_CHOICE, self.OnChoice)
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
         self.Bind(wx.EVT_CLOSE, self.OnClose)
@@ -171,6 +153,168 @@ class StyleEditor(wx.Dialog):
         self.preview.Bind(wx.EVT_KEY_UP, self.OnTextRegion)
     #--- End Init ---#
 
+    def __LexerChoice(self):
+        """Returns a sizer object containing a choice control with all
+        available lexers listed in it.
+        @return: sizer item containing a choice control with all available
+                 syntax test files available
+
+        """
+        lex_sizer = wx.BoxSizer(wx.HORIZONTAL)
+        lexer_lbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, 
+                                  _("Syntax Files") + u": ")
+        lexer_lst = wx.Choice(self.ctrl_pane, ed_glob.ID_LEXER, 
+                              choices=syntax.GetLexerList())
+        lexer_lst.SetToolTip(wx.ToolTip(_("Set the preview file type")))
+        lexer_lst.SetStringSelection(u"CPP")
+        lex_sizer.AddMany([((10, 10)), (lexer_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
+                           ((5, 0)), (lexer_lst, 1, wx.ALIGN_CENTER_VERTICAL),
+                           ((10, 10))])
+        return lex_sizer
+
+    def __Settings(self):
+        """Returns a sizer object holding all the settings controls
+        @return: main panel of configuration controls
+        @todo: this needs to be reworked, it also doesn't look as nice on 
+               msw/gtk as it does on wxmac.
+
+        """
+        setting_sizer = wx.BoxSizer(wx.VERTICAL)
+        setting_top = wx.BoxSizer(wx.HORIZONTAL)
+
+        # Settings top
+        setting_sizer.Add((10, 10))
+        cbox_sizer = wx.StaticBoxSizer(wx.StaticBox(self.ctrl_pane, 
+                                          label=_("Color") + u":"), wx.VERTICAL)
+
+        # Foreground
+        fground_sizer = wx.BoxSizer(wx.HORIZONTAL)
+        fground_lbl = wx.StaticText(self.ctrl_pane, 
+                                    label=_("Foreground") + u": ")
+        fground_sel = ColourSetter(self.ctrl_pane, ID_FORE_COLOR, "#000000")
+        fground_sizer.AddMany([((5, 5)), 
+                               (fground_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
+                               ((2, 2), 1, wx.EXPAND),
+                               (fground_sel, 0, wx.ALIGN_CENTER_VERTICAL), 
+                               ((5, 5))])
+        cbox_sizer.AddMany([(fground_sizer, 0, wx.ALIGN_LEFT | wx.EXPAND),
+                            ((10, 10))])
+
+        # Background
+        bground_sizer = wx.BoxSizer(wx.HORIZONTAL)
+        bground_lbl = wx.StaticText(self.ctrl_pane, 
+                                    label=_("Background") + u": ")
+        bground_sel = ColourSetter(self.ctrl_pane, ID_BACK_COLOR, "#FFFFFF")
+        bground_sizer.AddMany([((5, 5)), 
+                               (bground_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
+                               ((2, 2), 1, wx.EXPAND),
+                               (bground_sel, 0, wx.ALIGN_CENTER_VERTICAL), 
+                               ((5, 5))])
+        cbox_sizer.Add(bground_sizer, 0, wx.ALIGN_LEFT | wx.EXPAND)
+        setting_top.AddMany([(cbox_sizer, 0, wx.ALIGN_TOP), ((10, 10))])
+
+        # Attrib Box
+        attrib_box = wx.StaticBox(self.ctrl_pane, label=_("Attributes") + u":")
+        abox_sizer = wx.StaticBoxSizer(attrib_box, wx.VERTICAL)
+
+        # Attributes
+        bold_cb = wx.CheckBox(self.ctrl_pane, ID_BOLD, _("bold"))
+        eol_cb = wx.CheckBox(self.ctrl_pane, ID_EOL, _("eol"))
+        ital_cb = wx.CheckBox(self.ctrl_pane, ID_ITALIC, _("italic"))
+        uline_cb = wx.CheckBox(self.ctrl_pane, ID_ULINE, _("underline"))
+        abox_sizer.AddMany([(bold_cb, 0, wx.ALIGN_CENTER_VERTICAL),
+                            (eol_cb, 0, wx.ALIGN_CENTER_VERTICAL),
+                            (ital_cb, 0, wx.ALIGN_CENTER_VERTICAL),
+                            (uline_cb, 0, wx.ALIGN_CENTER_VERTICAL)])
+        setting_top.Add(abox_sizer, 0, wx.ALIGN_TOP)
+
+        # Font
+        fh_sizer = wx.BoxSizer(wx.HORIZONTAL)
+        font_box = wx.StaticBox(self.ctrl_pane, label=_("Font Settings") + u":")
+        fbox_sizer = wx.StaticBoxSizer(font_box, wx.VERTICAL)
+
+        # Font Face Name
+        fsizer = wx.BoxSizer(wx.HORIZONTAL)
+        flbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, _("Font") + u": ")
+        fontenum = wx.FontEnumerator()
+        fontenum.EnumerateFacenames(fixedWidthOnly=True)
+        font_lst = ["%(primary)s", "%(secondary)s"]
+        font_lst.extend(sorted(fontenum.GetFacenames()))
+        fchoice = wx.Choice(self.ctrl_pane, ID_FONT, choices=font_lst)
+        fsizer.AddMany([((5, 5), 0), (flbl, 0, wx.ALIGN_CENTER_VERTICAL),
+                        (fchoice, 0, wx.ALIGN_CENTER_VERTICAL), ((5, 5))])
+        fbox_sizer.Add(fsizer, 0, wx.ALIGN_LEFT)
+
+        # Font Size
+        fsize_sizer = wx.BoxSizer(wx.HORIZONTAL)
+        fsize_lbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, _("Size") + u": ")
+        fsizes = ['%(size)d', '%(size2)d']
+        fsizes.extend([ str(x) for x in xrange(4, 21) ])
+        fs_choice = wx.Choice(self.ctrl_pane, ID_FONT_SIZE, choices=fsizes)
+        fsize_sizer.AddMany([((5, 5), 0), 
+                             (fsize_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
+                             (fs_choice, 1, wx.EXPAND | wx.ALIGN_RIGHT), 
+                             ((5, 5), 0)])
+        fbox_sizer.AddMany([((5, 5)), 
+                            (fsize_sizer, 0, wx.ALIGN_LEFT | wx.EXPAND)])
+        fh_sizer.AddMany([(fbox_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL),
+                          ((10, 10))])
+
+        # Build Section
+        setting_sizer.AddMany([(setting_top, 0, wx.ALIGN_CENTER_HORIZONTAL),
+                               ((10, 10), 1, wx.EXPAND),
+                               (fh_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL)])
+        return setting_sizer
+
+    def __StyleSheets(self):
+        """Returns a sizer item that contains a choice control with
+        all the available style sheets listed in it.
+        @return: sizer item holding all installed style sheets
+
+        """
+        ss_sizer = wx.BoxSizer(wx.HORIZONTAL)
+        ss_lbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY,
+                               _("Style Theme") + u": ")
+        ss_lst = util.GetResourceFiles(u'styles', get_all=True)
+        ss_choice = wx.Choice(self.ctrl_pane, ed_glob.ID_PREF_SYNTHEME,
+                              choices=sorted(ss_lst))
+        ss_choice.SetToolTip(wx.ToolTip(_("Base new theme of existing one")))
+        ss_choice.SetStringSelection(Profile_Get('SYNTHEME', 'str'))
+        ss_new = wx.CheckBox(self.ctrl_pane, wx.ID_NEW, _("New"))
+        ss_new.SetToolTip(wx.ToolTip(_("Start a blank new style")))
+        ss_sizer.AddMany([((10, 10)), (ss_lbl, 0, wx.ALIGN_CENTER_VERTICAL), 
+                          ((5, 0)),
+                          (ss_choice, 0, wx.ALIGN_CENTER_VERTICAL), ((10, 0)), 
+                          (ss_new, 0, wx.ALIGN_CENTER_VERTICAL), ((10, 10))])
+        return ss_sizer
+
+    def __StyleTags(self):
+        """Returns a sizer object containing a choice control with all
+        current style tags in it.
+        @return: sizer item containing list of all available style tags
+
+        """
+        style_sizer = wx.BoxSizer(wx.HORIZONTAL)
+        style_sizer2 = wx.BoxSizer(wx.VERTICAL)
+
+        style_lbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, 
+                                  _("Style Tags") + u": ")
+
+        style_tags = self.styles_orig.keys()
+        lsize = (-1, 100)
+        if wx.Platform == '__WXMAC__':
+            lsize = (-1, 120)
+
+        style_lst = wx.ListBox(self.ctrl_pane, ID_STYLES, size=lsize,
+                               choices=sorted(style_tags), style=wx.LB_SINGLE)
+        style_sizer2.AddMany([(style_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
+                             (style_lst, 1, wx.EXPAND)])
+        style_sizer.AddMany([((10, 10), 0), 
+                             (style_sizer2, 1, 
+                              wx.ALIGN_CENTER_HORIZONTAL | wx.EXPAND), 
+                             ((10, 10), 0)])
+        return style_sizer
+
     def DiffStyles(self):
         """Checks if the current style set is different from the
         original set. Used internally to check if a save prompt needs
@@ -184,35 +328,21 @@ class StyleEditor(wx.Dialog):
             if unicode(self.styles_orig[key]) != unicode(self.styles_new[key]):
                 diff = True
                 break
+
         result = wx.ID_NO
         if diff:
             dlg = wx.MessageDialog(self, 
                                     _("Some styles have been changed would "
                                       "you like to save before exiting?"),
                                    _("Save Styles"), 
-                                   style = wx.YES_NO | wx.YES_DEFAULT | \
-                                           wx.CANCEL | wx.ICON_INFORMATION)
+                                   style=wx.YES_NO | wx.YES_DEFAULT | \
+                                         wx.CANCEL | wx.ICON_INFORMATION)
             dlg.CenterOnParent()
             result = dlg.ShowModal()
             dlg.Destroy()
         return result
-
-    def DuplicateStyleDict(self, style_dict):
-        """Duplicates the style dictionary to make a true copy of
-        it, as simply assigning the dictionary to two different variables
-        only copies a reference leaving both variables pointing to the 
-        same object.
-        @param style_dict: dictionary of tags->StyleItems
-        @return: a copy of the given styleitem dictionary
-
-        """
-        new_dict = dict()
-        for tag in style_dict:
-            new_dict[tag] = StyleItem()
-            new_dict[tag].SetAttrFromStr(unicode(style_dict[tag]))
-        return new_dict
         
-    def EnableSettings(self, enable = True):
+    def EnableSettings(self, enable=True):
         """Enables/Disables all settings controls
         @keyword enable: whether to enable/disable settings controls
 
@@ -220,7 +350,6 @@ class StyleEditor(wx.Dialog):
         for sid in SETTINGS_IDS:
             ctrl = self.FindWindowById(sid)
             ctrl.Enable(enable)
-        self.settings_enabled = enable
 
     def ExportStyleSheet(self):
         """Writes the style sheet data out to a style sheet
@@ -249,44 +378,44 @@ class StyleEditor(wx.Dialog):
             sheet_path = dlg.GetPath()
             if u'ess' != sheet_path.split(u'.')[-1]:
                 sheet_path += u".ess"
-            dlg.Destroy()
-            writer = util.GetFileWriter(sheet_path)
+
             try:
+                writer = util.GetFileWriter(sheet_path)
                 writer.write(self.GenerateStyleSheet())
                 writer.close()
-                # Update Style Sheet Control
-                ss_lst = util.GetResourceFiles(u'styles', get_all=True)
-                ss_c = self.FindWindowById(ed_glob.ID_PREF_SYNTHEME)
-                sel = ss_c.GetStringSelection()
-                ss_c.SetItems(ss_lst)
-                ss_c.SetStringSelection(sel)
-                self.styles_orig = self.DuplicateStyleDict(self.styles_new)
-            except IOError, msg:
+            except (AttributeError, IOError), msg:
                 self.LOG('[style_editor][err] Failed to export style sheet')
-                self.LOG('[style_editor][sys error] %s' % msg)
+                self.LOG('[style_editor][err] %s' % str(msg))
             else:
+                # Update Style Sheet Control
+                sheet = os.path.basename(sheet_path).split(u'.')[0]
+                ss_c = self.FindWindowById(ed_glob.ID_PREF_SYNTHEME)
+                ss_c.SetItems(util.GetResourceFiles(u'styles', get_all=True))
+                ss_c.SetStringSelection(sheet)
+                self.styles_orig = self.styles_new
+                self.styles_new = DuplicateStyleDict(self.styles_orig)
+
                 if sheet_path.startswith(ed_glob.CONFIG['STYLES_DIR']) or \
                    sheet_path.startswith(ed_glob.CONFIG['SYS_STYLES_DIR']):
                     # Update editor windows to use new style sheet
-                    sheet = os.path.basename(sheet_path).split(u'.')[0]
                     Profile_Set('SYNTHEME', sheet)
                     for mainw in wx.GetApp().GetMainWindows():
                         mainw.nb.UpdateTextControls()
                         mainw.SetStatusText(_("Changed color scheme to %s") % \
                                             sheet, ed_glob.SB_INFO)
+        dlg.Destroy()
         return result
 
     def GenerateStyleSheet(self):
         """Generates a style sheet from the dialogs style data
-        @return: the dictionary of L{StyleItems} formated into a style sheet
-                 string
+        @return: The dictionary of L{StyleItem} in self.styles_new transformed
+                 into a string that is in Editra Style Sheet format.
 
         """
         sty_sheet = list()
         for tag in self.styles_new:
             sty_sheet.append(tag + u" {\n")
-            sdat = unicode(self.styles_new[tag])
-            sdat = sdat.split(u",")
+            sdat = unicode(self.styles_new[tag]).split(u",")
             stage1 = wx.EmptyString
             for atom in sdat:
                 if atom in "bold eol italic underline":
@@ -298,172 +427,13 @@ class StyleEditor(wx.Dialog):
             sty_sheet.append(u"\n}\n\n")
         return u"".join(sty_sheet)
 
-    def LexerChoice(self):
-        """Returns a sizer object containing a choice control with all
-        available lexers listed in it.
-        @return: sizer item containing a choice control with all available
-                 syntax test files available
-
-        """
-        lex_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        lexer_lbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, 
-                                  _("Syntax Files") + u": ")
-        lexer_lst = wx.Choice(self.ctrl_pane, ed_glob.ID_LEXER, 
-                              choices=syntax.GetLexerList())
-        tt = wx.ToolTip(_("Set the preview file type"))
-        lexer_lst.SetToolTip(tt)
-        lexer_lst.SetStringSelection(u"CPP")
-        lex_sizer.AddMany([((10, 10)), 
-                            (lexer_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
-                           ((5, 0)), (lexer_lst, 1, wx.ALIGN_CENTER_VERTICAL),
-                           ((10, 10))])
-        return lex_sizer
-
-    def Settings(self):
-        """Returns a sizer object holding all the settings controls
-        @return: main panel of configuration controls
-
-        """
-        setting_sizer = wx.BoxSizer(wx.VERTICAL)
-        setting_top = wx.BoxSizer(wx.HORIZONTAL)
-
-        # Settings top
-        setting_sizer.Add((10, 10))
-        color_box = wx.StaticBox(self.ctrl_pane, wx.ID_ANY, _("Color") + u":")
-        cbox_sizer = wx.StaticBoxSizer(color_box, wx.VERTICAL)
-        # Foreground
-        fground_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        fground_lbl = wx.StaticText(self.ctrl_pane, 
-                                    label=_("Foreground") + u": ")
-        fground_sel = ColourSetter(self.ctrl_pane, ID_FORE_COLOR, "#000000")
-        fground_sizer.AddMany([((5, 5)), 
-                               (fground_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
-                               ((2, 2), 1, wx.EXPAND),
-                               (fground_sel, 0, wx.ALIGN_CENTER_VERTICAL), 
-                               ((5, 5))])
-        cbox_sizer.Add(fground_sizer, 0, wx.ALIGN_LEFT | wx.EXPAND)
-        cbox_sizer.Add((10, 10))
-        # Background
-        bground_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        bground_lbl = wx.StaticText(self.ctrl_pane, 
-                                    label=_("Background") + u": ")
-        bground_sel = ColourSetter(self.ctrl_pane, ID_BACK_COLOR, "#FFFFFF")
-        bground_sizer.AddMany([((5, 5)), 
-                               (bground_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
-                               ((2, 2), 1, wx.EXPAND),
-                               (bground_sel, 0, wx.ALIGN_CENTER_VERTICAL), 
-                               ((5, 5))])
-        cbox_sizer.Add(bground_sizer, 0, wx.ALIGN_LEFT | wx.EXPAND)
-        setting_top.Add(cbox_sizer, 0, wx.ALIGN_TOP)
-        # Attrib Box
-        setting_top.Add((10, 10))
-        attrib_box = wx.StaticBox(self.ctrl_pane, label=_("Attributes") + u":")
-        abox_sizer = wx.StaticBoxSizer(attrib_box, wx.VERTICAL)
-        # Attributes
-        bold_cb = wx.CheckBox(self.ctrl_pane, ID_BOLD, _("bold"))
-        eol_cb = wx.CheckBox(self.ctrl_pane, ID_EOL, _("eol"))
-        ital_cb = wx.CheckBox(self.ctrl_pane, ID_ITALIC, _("italic"))
-        uline_cb = wx.CheckBox(self.ctrl_pane, ID_ULINE, _("underline"))
-        abox_sizer.AddMany([(bold_cb, 0, wx.ALIGN_CENTER_VERTICAL),
-                            (eol_cb, 0, wx.ALIGN_CENTER_VERTICAL),
-                            (ital_cb, 0, wx.ALIGN_CENTER_VERTICAL),
-                            (uline_cb, 0, wx.ALIGN_CENTER_VERTICAL)])
-        setting_top.Add(abox_sizer, 0, wx.ALIGN_TOP)
-
-        # Font
-        fh_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        font_box = wx.StaticBox(self.ctrl_pane, label=_("Font Settings") + u":")
-        fbox_sizer = wx.StaticBoxSizer(font_box, wx.VERTICAL)
-
-        # Font Face Name
-        fsizer = wx.BoxSizer(wx.HORIZONTAL)
-        flbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, _("Font") + u": ")
-        fontenum = wx.FontEnumerator()
-        fontenum.EnumerateFacenames(fixedWidthOnly=True)
-        f_lst = fontenum.GetFacenames()
-        f_lst.sort()
-        font_lst = ["%(primary)s", "%(secondary)s"]
-        font_lst.extend(f_lst)
-        fchoice = wx.Choice(self.ctrl_pane, ID_FONT, choices=font_lst)
-        fsizer.AddMany([((5, 5), 0), (flbl, 0, wx.ALIGN_CENTER_VERTICAL),
-                        (fchoice, 0, wx.ALIGN_CENTER_VERTICAL), ((5, 5))])
-        fbox_sizer.Add(fsizer, 0, wx.ALIGN_LEFT)
-
-        # Font Size
-        fsize_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        fsize_lbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, _("Size") + u": ")
-        fsizes = ['%(size)d', '%(size2)d']
-        fsizes.extend([ str(x) for x in xrange(4, 21)])
-        fs_choice = wx.Choice(self.ctrl_pane, ID_FONT_SIZE, 
-                              choices = fsizes)
-        fsize_sizer.AddMany([((5, 5), 0), (fsize_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
-                             (fs_choice, 1, wx.EXPAND | wx.ALIGN_RIGHT), 
-                             ((5, 5), 0)])
-        fbox_sizer.AddMany([((5, 5)), (fsize_sizer, 0, wx.ALIGN_LEFT | wx.EXPAND)])
-        fh_sizer.AddMany([(fbox_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL),
-                          ((10, 10))])
-
-        # Build Section
-        setting_sizer.AddMany([(setting_top, 0, wx.ALIGN_CENTER_HORIZONTAL),
-                               ((10, 10), 1, wx.EXPAND),
-                               (fh_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL)])
-        return setting_sizer
-
-    def StyleSheets(self):
-        """Returns a sizer item that contains a choice control with
-        all the available style sheets listed in it.
-        @return: sizer item holding all installed style sheets
-
-        """
-        ss_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        ss_lbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY,
-                               _("Style Theme") + u": ")
-        ss_lst = util.GetResourceFiles(u'styles', get_all=True)
-        ss_lst.sort()
-        ss_choice = wx.Choice(self.ctrl_pane, ed_glob.ID_PREF_SYNTHEME,
-                              choices=ss_lst)
-        ss_choice.SetToolTip(wx.ToolTip(_("Base new theme of existing one")))
-        ss_choice.SetStringSelection(Profile_Get('SYNTHEME', 'str'))
-        ss_new = wx.CheckBox(self.ctrl_pane, wx.ID_NEW, _("New"))
-        ss_new.SetToolTip(wx.ToolTip(_("Start a blank new style")))
-        ss_sizer.AddMany([((10, 10)), (ss_lbl, 0, wx.ALIGN_CENTER_VERTICAL), 
-                          ((5, 0)),
-                          (ss_choice, 0, wx.ALIGN_CENTER_VERTICAL), ((10, 0)), 
-                          (ss_new, 0, wx.ALIGN_CENTER_VERTICAL), ((10, 10))])
-        return ss_sizer
-
-    def StyleTags(self):
-        """Returns a sizer object containing a choice control with all
-        current style tags in it.
-        @return: sizer item containing list of all available style tags
-
-        """
-        style_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        style_sizer2 = wx.BoxSizer(wx.VERTICAL)
-        style_lbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, 
-                                  _("Style Tags") + u": ")
-        style_tags = self.styles_orig.keys()
-        style_tags.sort()
-        style_lst = wx.ListBox(self.ctrl_pane, ID_STYLES, size=(150, 100),
-                               choices=style_tags, style=wx.LB_SINGLE)
-        style_sizer2.AddMany([(style_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
-                             (style_lst, 0, wx.ALIGN_CENTER_VERTICAL)])
-        style_sizer.AddMany([((10, 10), 0), 
-                             (style_sizer2, 0, 
-                              wx.ALIGN_CENTER_HORIZONTAL | wx.EXPAND), 
-                             ((10, 10), 0)])
-        return style_sizer
-
     def OnCancel(self, evt):
         """Catches the cancel button clicks and checks if anything
         needs to be done before closing the window.
         @param evt: event that called this handler
 
         """
-        self.LOG('[style_editor] [cancel] Cancel Clicked Closing Window')
-        # HACK for some reason SetStyles isn't doing its job right now so
-        #      just set it directly for the time being.
-        StyleMgr.styles = self.styles_orig
+        self.LOG('[style_editor][cancel] Cancel Clicked Closing Window')
         evt.Skip()
 
     def OnCheck(self, evt):
@@ -479,9 +449,9 @@ class StyleEditor(wx.Dialog):
             choice.Enable(not val)
             if val:
                 self.preview.StyleDefault()
-                self.styles_new = self.preview.BlankStyleDictionary()
-                self.styles_orig = self.DuplicateStyleDict(self.styles_new)
-                self.preview.SetStyles(self.styles_new, nomerge=True)
+                self.styles_orig = self.preview.BlankStyleDictionary()
+                self.styles_new = DuplicateStyleDict(self.styles_orig)
+                self.preview.SetStyles('preview', self.styles_new, nomerge=True)
                 self.preview.DefineMarkers()
             else:
                 scheme = choice.GetStringSelection().lower()
@@ -505,7 +475,7 @@ class StyleEditor(wx.Dialog):
             # TODO Need to check for style changes before switching this
             self.preview.UpdateAllStyles(val)
             self.styles_new = self.preview.GetStyleSet()
-            self.styles_orig = self.DuplicateStyleDict(self.styles_new)
+            self.styles_orig = DuplicateStyleDict(self.styles_new)
             ctrl = self.FindWindowById(ID_STYLES)
             tag = ctrl.GetStringSelection()
             if tag != wx.EmptyString:
@@ -520,6 +490,7 @@ class StyleEditor(wx.Dialog):
         @param evt: event that called this handler
 
         """
+        self.LOG("[style_editor][evt] Dialog closing...")
         self.OnOk(evt)
 
     def OnColor(self, evt):
@@ -528,8 +499,7 @@ class StyleEditor(wx.Dialog):
 
         """
         # Update The Style data for current tag
-        e_id = evt.GetId()
-        self.UpdateStyleSet(e_id)
+        self.UpdateStyleSet(evt.GetId())
 
     def OnTextRegion(self, evt):
         """Processes clicks in the preview control and sets the style
@@ -541,22 +511,22 @@ class StyleEditor(wx.Dialog):
         style_id = self.preview.GetStyleAt(self.preview.GetCurrentPos())
         tag_lst = self.FindWindowById(ID_STYLES)
         data = self.preview.FindTagById(style_id)
-        if data != wx.EmptyString:
+        if data != wx.EmptyString and self.styles_new.has_key(data):
             tag_lst.SetStringSelection(data)
+            if wx.Platform == '__WXGTK__':
+                tag_lst.SetFirstItemStr(data)
             self.UpdateSettingsPane(self.styles_new[data])
             self.EnableSettings()
         evt.Skip()
 
     def OnListBox(self, evt):
         """Catches the selection of a style tag in the listbox
-        and updates the style window appropriatly.
+        and updates the style window appropriately.
         @param evt: event that called this handler
 
         """
-        e_id = evt.GetId()
-        e_obj = self.FindWindowById(e_id)
-        tag = e_obj.GetStringSelection()
-        if tag != wx.EmptyString:
+        tag = evt.GetEventObject().GetStringSelection()
+        if tag != wx.EmptyString and self.styles_new.has_key(tag):
             self.UpdateSettingsPane(self.styles_new[tag])
             self.EnableSettings()
         else:
@@ -571,7 +541,6 @@ class StyleEditor(wx.Dialog):
         self.LOG('[style_editor][info] Ok Clicked Closing Window')
         result = self.DiffStyles()
         if result == wx.ID_NO:
-            StyleMgr.styles = self.styles_orig
             evt.Skip()
         elif result == wx.ID_CANCEL:
             self.LOG('[style_editor][info] canceled closing')
@@ -583,12 +552,10 @@ class StyleEditor(wx.Dialog):
     def OnExport(self, evt):
         """Catches save button event
         @param evt: event that called this handler
-        @postcondition: export file dialog is opened
 
         """
-        self.LOG('[style_editor] [Save] Saving style changes')
+        self.LOG('[style_editor][export] Saving style changes')
         self.ExportStyleSheet()
-        evt.Skip()
 
     def OpenPreviewFile(self, file_lbl):
         """Opens a file using the names in the Syntax Files choice
@@ -596,22 +563,14 @@ class StyleEditor(wx.Dialog):
         @param file_lbl: name of file to open in test data directory
 
         """
-        fname = file_lbl.replace(u" ", u"_").lower()
-        fname = fname.replace(u"/", u"_")
-        if fname != u"makefile":
-            try:
-                fname = glob.glob(ed_glob.CONFIG['TEST_DIR'] + fname + ".*")[0]
-            except IndexError:
-                self.LOG('[style_editor][err] File %s Does not exist' % fname)
-                return False
-        else:
-            fname = ed_glob.CONFIG['TEST_DIR'] + fname
-
-        if fname == '' or fname == None:
+        fname = file_lbl.replace(u" ", u"_").replace(u"/", u"_").lower()
+        try:
+            fname = glob.glob(ed_glob.CONFIG['TEST_DIR'] + fname + ".*")[0]
+        except IndexError:
+            self.LOG('[style_editor][err] File %s Does not exist' % fname)
             return False
 
-        self.preview.dirname = util.GetPathName(fname)
-        self.preview.filename = util.GetFileName(fname)
+        self.preview.SetFileName(fname)
         self.preview.ClearAll()
         self.preview.LoadFile(fname)
         self.preview.FindLexer()
@@ -647,8 +606,6 @@ class StyleEditor(wx.Dialog):
             elif c_type == "wxChoice":
                 ctrl.SetStringSelection(val_map[sid])
             elif isinstance(ctrl, ColourSetter):
-                # Note: must call set label before set value or the label
-                # is not redrawn
                 ctrl.SetLabel(val_map[sid][:7])
                 ctrl.SetValue(wx.Color(int(val_map[sid][1:3], 16), 
                                        int(val_map[sid][3:5], 16), 
@@ -658,7 +615,7 @@ class StyleEditor(wx.Dialog):
     def UpdateStyleSet(self, id_):
         """Updates the value of the style tag to reflect any changes
         made in the settings controls.
-        @param id: identifier of the style tag in the list
+        @param id_: identifier of the style tag in the list
 
         """
         # Get the tag that has been modified
@@ -719,8 +676,7 @@ class ColourSetter(wx.Panel):
         self._label = label
         self._txt = wx.TextCtrl(self, value=label, style=wx.TE_CENTER)
         txtheight = self._txt.GetTextExtent('#000000')[1]
-        txtheight = txtheight + 4
-        self._txt.SetMaxSize((-1, txtheight))
+        self._txt.SetMaxSize((-1, txtheight + 4))
         self._txt.SetToolTip(wx.ToolTip(_("Enter a hex color value")))
         self._cbtn = csel.ColourSelect(self, colour=util.HexToRGB(label), 
                                        size=(20, 20))
@@ -772,7 +728,6 @@ class ColourSetter(wx.Panel):
         @param evt: EVT_COLOURSELECT
 
         """
-        e_id = evt.GetId()
         e_val = evt.GetValue()[0:3]
         red = hex(e_val[0])
         green = hex(e_val[1])
@@ -790,14 +745,11 @@ class ColourSetter(wx.Panel):
         @keyword evt: event that called this handler
 
         """
-        hexstr = self._txt.GetValue()
-        hexstr = hexstr.replace('#', '')
+        hexstr = self._txt.GetValue().replace('#', '')
         if len(hexstr) > 6:
-            hexstr = hexstr[:6]
-            self._txt.SetValue(u'#' + hexstr)
+            self._txt.SetValue(u'#' + hexstr[:6])
         hexstr = '#' + hexstr + (u'0' * (6 - len(hexstr)))
-        colour = util.HexToRGB(hexstr)
-        self._cbtn.SetValue(colour)
+        self._cbtn.SetValue(util.HexToRGB(hexstr))
         self.__PostEvent()
 
     def OnUpdateUI(self, evt):
@@ -805,12 +757,9 @@ class ColourSetter(wx.Panel):
         @param evt: UpdateUI
 
         """
-        txt = self._txt.GetValue().replace('#', '')
         ret = u''
-        for char in txt:
-            if char not in '0123456789abcdefABCDEF':
-                continue
-            else:
+        for char in self._txt.GetValue().replace('#', ''):
+            if char in '0123456789abcdefABCDEF':
                 ret = ret + char
         self._txt.SetValue(u'#' + ret)
 
@@ -851,3 +800,20 @@ class ColourSetter(wx.Panel):
                                hex(blue)[2:].zfill(2).upper())
         self._txt.SetValue(hex_str)
         self.__PostEvent()
+
+#-----------------------------------------------------------------------------#
+# Utility funtcions
+def DuplicateStyleDict(style_dict):
+    """Duplicates the style dictionary to make a true copy of
+    it, as simply assigning the dictionary to two different variables
+    only copies a reference leaving both variables pointing to the 
+    same object.
+    @param style_dict: dictionary of tags->StyleItems
+    @return: a copy of the given styleitem dictionary
+
+    """
+    new_dict = dict()
+    for tag in style_dict:
+        new_dict[tag] = StyleItem()
+        new_dict[tag].SetAttrFromStr(unicode(style_dict[tag]))
+    return new_dict
