@@ -1,21 +1,10 @@
 ###############################################################################
-#    Copyright (C) 2007 Cody Precord                                          #
-#    cprecord@editra.org                                                      #
-#                                                                             #
-#    Editra is free software; you can redistribute it and#or modify           #
-#    it under the terms of the GNU General Public License as published by     #
-#    the Free Software Foundation; either version 2 of the License, or        #
-#    (at your option) any later version.                                      #
-#                                                                             #
-#    Editra is distributed in the hope that it will be useful,                #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of           #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            #
-#    GNU General Public License for more details.                             #
-#                                                                             #
-#    You should have received a copy of the GNU General Public License        #
-#    along with this program; if not, write to the                            #
-#    Free Software Foundation, Inc.,                                          #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.                #
+# Name: syntax.py                                                             #
+# Purpose: Manage and dynamically load/provide syntax on request from editor. #
+#          Also manages the mappings of file extensions to lexers.            #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
 ###############################################################################
 
 """
@@ -57,8 +46,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: syntax.py 257 2007-07-06 11:59:50Z CodyPrecord $"
-__revision__ = "$Revision: 257 $"
+__svnid__ = "$Id: syntax.py 49415 2007-10-25 05:06:57Z CJP $"
+__revision__ = "$Revision: 49415 $"
 
 #-----------------------------------------------------------------------------#
 # Dependencies
@@ -189,7 +178,8 @@ class SyntaxMgr(object):
     def SyntaxData(self, ext):
         """Fetches the language data based on a file extention string.
         The file extension is used to look up the default lexer actions from the
-        EXT_REG dictionary (@see L{synglob.py}).
+        EXT_REG dictionary.
+        @see L{synglob}
         @param ext: a string representing the file extension
         @return: Returns a Dictionary of Lexer Config Data
 
@@ -271,7 +261,7 @@ class ExtensionRegister(dict):
     def __str__(self):
         """Converts the Register to a string that is formatted
         for output to a config file.
-        @return the register as a string
+        @return: the register as a string
 
         """
         keys = self.keys()
@@ -461,7 +451,7 @@ def SyntaxIds():
 
 def GetExtFromId(ext_id):
     """Takes a language ID and fetches an appropriate file extension string
-    @param extId: language id to get extension for
+    @param ext_id: language id to get extension for
     @return: file extension
     @rtype: string
 
