@@ -1,22 +1,11 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: updater.py                                                            #
+# Purpose: UI and services for checking update status and downloading updates #
+#          for Editra.                                                        #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -45,8 +34,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: updater.py 532 2007-09-26 11:59:58Z CodyPrecord $"
-__revision__ = "$Revision: 532 $"
+__cvsid__ = "$Id: updater.py 49397 2007-10-24 14:17:58Z CJP $"
+__revision__ = "$Revision: 49397 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -248,6 +237,10 @@ class UpdateProgress(wx.Gauge, UpdateService):
         self._status = _("Status Unknown")
         self._timer = wx.Timer(self, id=self.ID_TIMER)
 
+        #---- Layout ----#
+        if wx.Platform == '__WXMAC__':
+            self.SetWindowVariant(wx.WINDOW_VARIANT_LARGE)
+
         #---- Bind Events ----#
         self.Bind(wx.EVT_TIMER, self.OnUpdate, id = self.ID_TIMER)
         
@@ -265,7 +258,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
 
     def Abort(self):
         """Overides the UpdateService abort function
-        @postcondtion: any download actions in the L{UpdateService} are aborted
+        @postcondition: any download actions in the L{UpdateService} are aborted
 
         """
         self.LOG("[updateprog][info] Aborting action, stopping progress bar")
@@ -434,7 +427,6 @@ class UpdateProgress(wx.Gauge, UpdateService):
         """Processes the download and checks that the file has been downloaded
         properly. Then returns either True if the download was succesfull or
         False if it failed in some way.
-        @param *args: where to download file from
         @return: success status of download
         
         """
@@ -535,34 +527,28 @@ class DownloadDialog(wx.Frame):
                            wx.BITMAP_TYPE_PNG)
         tmp_bmp.Rescale(20, 20, wx.IMAGE_QUALITY_HIGH)
         mdc.DrawBitmap(tmp_bmp.ConvertToBitmap(), 11, 11)
-        bmp = mdc.GetAsBitmap()
-        mdc.Destroy()
+        mdc.SelectObject(wx.NullBitmap)
         bmp = wx.StaticBitmap(panel, wx.ID_ANY, bmp)
-        self._sizer.AddMany([((10, 10), (0, 0)), (bmp, (1, 1), (3, 2)),
-                             ((5, 5), (1, 3)),
+        self._sizer.AddMany([(bmp, (1, 1), (3, 2)),
                              (dl_file, (1, 4), (1, 4)),
-                             ((5, 5), (1, 9)), 
-                             (dl_loc, (2, 4), (1, 4)), 
-                             ((20, 20), (4, 1), (1, 2)),
-                             (self._progress, (5, 2), (1, 6), 
-                              wx.EXPAND | wx.ALIGN_CENTER_HORIZONTAL),
-                             (self._cancel_bt, (6, 2), (1, 6), wx.ALIGN_CENTER),
-                             ((5, 5), (7, 1))])
+                             (dl_loc, (2, 4), (1, 4))])
+
+        self._sizer.Add(self._progress, (4, 1), (1, 10), wx.EXPAND)
+
+        bsizer = wx.BoxSizer(wx.HORIZONTAL)
+        bsizer.AddStretchSpacer()
+        bsizer.Add(self._cancel_bt, 0, wx.ALIGN_CENTER_HORIZONTAL)
+        bsizer.AddStretchSpacer()
+
+        self._sizer.Add(bsizer, (6, 1), (1, 10), wx.EXPAND)
+        self._sizer.Add((5, 5), (7, 1))
+        self._sizer.Add((5, 5), (7, 11))
         panel.SetSizer(self._sizer)
-        mwsz = wx.BoxSizer(wx.VERTICAL)
+        mwsz = wx.BoxSizer(wx.HORIZONTAL)
         mwsz.Add(panel, 1, wx.EXPAND)
         self.SetSizer(mwsz)
         self.SetInitialSize()
 
-        # Adjust progress bar and status widths
-        size = self.GetSize()
-        if wx.Platform == '__WXMSW__':
-            width = size.GetWidth()
-            if width < 375:
-                width = 375
-            self.SetSize(wx.Size(width, size.GetHeight()))
-            self.SendSizeEvent()
-        self._progress.SetSize(wx.Size(int(size[0] * .80), 15))
         self.SetStatusWidths([-1, 100])
         self.SetStatusText(_("Downloading..."), self.SB_INFO)
 
@@ -656,7 +642,7 @@ class DownloadDialog(wx.Frame):
 
     def Show(self):
         """Shows the Dialog and starts downloading the updates
-        @postcondtion: window is registered with mainloop and shown on screen
+        @postcondition: window is registered with mainloop and shown on screen
         @todo: Allow setting of download location to be set when shown
 
         """
