@@ -1,22 +1,10 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: util.py                                                               #
+# Purpose: Misc utility functions used through out Editra                     #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -38,18 +26,17 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 537 2007-09-26 13:14:41Z CodyPrecord $"
-__revision__ = "$Revision: 537 $"
+__svnid__ = "$Id: util.py 49551 2007-10-31 12:01:14Z CJP $"
+__revision__ = "$Revision: 49551 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
 import sys
-import shutil
-import stat
 import codecs
 import mimetypes
 import wx
+import ed_event
 import ed_glob
 from syntax.syntax import GetFileExtensions
 import dev_tool
@@ -70,13 +57,10 @@ class DropTargetFT(wx.PyDropTarget):
         """
         wx.PyDropTarget.__init__(self)
         self.window = window
-        self.data = None
-        self.file_data_obj = None
-        self.text_data_obj = None
+        self._data = dict(data=None, fdata=None, tdata=None, 
+                          tcallb=textcallback, fcallb=filecallback)
         self._tmp = None
         self._lastp = None
-        self._tcallb = textcallback
-        self._fcallb = filecallback
         self.InitObjects()
 
     def CreateDragString(self, txt):
@@ -87,6 +71,7 @@ class DropTargetFT(wx.PyDropTarget):
         """
         if not issubclass(self.window.__class__, wx.stc.StyledTextCtrl):
             return
+
         stc = self.window
         txt = txt.split(stc.GetEOLChar())
         longest = (0, 0)
@@ -94,11 +79,11 @@ class DropTargetFT(wx.PyDropTarget):
             ext = stc.GetTextExtent(line)
             if ext[0] > longest[0]:
                 longest = ext
-        cords = list()
-        for x in xrange(len(txt)):
-            cords.append((0, x * longest[1]))
+
+        cords = [ (0, x * longest[1]) for x in xrange(len(txt)) ]
         mdc = wx.MemoryDC(wx.EmptyBitmap(longest[0] + 5, 
-                                         longest[1] * len(txt)))
+                                         longest[1] * len(txt), 32))
+        mdc.SetBackgroundMode(wx.TRANSPARENT)
         mdc.SetTextForeground(stc.GetDefaultForeColour())
         mdc.SetFont(stc.GetDefaultFont())
         mdc.DrawTextList(txt, cords)
@@ -109,23 +94,26 @@ class DropTargetFT(wx.PyDropTarget):
         @postcondition: all data objects are initialized
 
         """
-        self.data = wx.DataObjectComposite()
-        self.text_data_obj = wx.TextDataObject()
-        self.file_data_obj = wx.FileDataObject()
-        self.data.Add(self.text_data_obj, True)
-        self.data.Add(self.file_data_obj, False)
-        self.SetDataObject(self.data)
+        self._data['data'] = wx.DataObjectComposite()
+        self._data['tdata'] = wx.TextDataObject()
+        self._data['fdata'] = wx.FileDataObject()
+        self._data['data'].Add(self._data['tdata'], True)
+        self._data['data'].Add(self._data['fdata'], False)
+        self.SetDataObject(self._data['data'])
 
     def OnEnter(self, x_cord, y_cord, drag_result):
         """Called when a drag starts
         @return: result of drop object entering window
 
         """
-        if self.GetData():
-            files = self.file_data_obj.GetFilenames()
-            text = self.text_data_obj.GetText()
-        else:
-            return drag_result
+        try:
+            if self.GetData():
+                files = self._data['fdata'].GetFilenames()
+                text = self._data['tdata'].GetText()
+            else:
+                return drag_result
+        except wx.PyAssertionError:
+            return wx.DragError
 
         self._lastp = (x_cord, y_cord)
         if len(files):
@@ -175,11 +163,21 @@ class DropTargetFT(wx.PyDropTarget):
 
         """
         self.window.SetCursor(wx.StockCursor(wx.CURSOR_ARROW))
-        if self.GetData():
-            files = self.file_data_obj.GetFilenames()
-            text = self.text_data_obj.GetText()
-            if len(files) > 0 and self._fcallb is not None:
-                self._fcallb(files)
+        try:
+            data = self.GetData()
+        except wx.PyAssertionError:
+            wx.PostEvent(self.window.GetTopLevelParent(), \
+                        ed_event.StatusEvent(ed_event.edEVT_STATUS, -1,
+                                             _("Unable to open dropped file or "
+                                               "text")))
+            data = False
+            drag_result = wx.DragCancel
+
+        if data:
+            files = self._data['fdata'].GetFilenames()
+            text = self._data['tdata'].GetText()
+            if len(files) > 0 and self._data['fcallb'] is not None:
+                self._data['fcallb'](files)
             elif(len(text) > 0):
                 if SetClipboardText(text):
                     win = self.window
@@ -248,46 +246,41 @@ def GetDecodedText(fname):
     a compatible decoder. Returns a tuple of the text and the
     encoding it was decoded from.
     @param fname: name of file to open and get text from
+    @return: tuple of (text, encoding string)
+    @note: must allow exceptions to be raised (side effect)
 
     """
-    try:
-        f_handle = file(fname, 'rb')
-        txt = f_handle.read()
-        f_handle.close()
-    except (IOError, OSError):
-        f_handle.close()
-        return -1
-    else:
-        decoded = None
+    f_handle = file(fname, 'rb')
+    txt = f_handle.read()
+    f_handle.close()
 
-        # First look for a bom byte
-        bbyte = None
-        for e, b in BOM.iteritems():
-            if txt.startswith(b) and e not in ['ascii', 'latin-1']:
-                bbyte = e
+    # First try looking for a bom byte
+    tenc = ENC
+    for enc, bom in BOM.iteritems():
+        if txt.startswith(bom) and enc not in ['ascii', 'latin-1']:
+            if enc in tenc:
+                tenc.remove(enc)
+            tenc.insert(0, enc)
+            break
 
-        tenc = ENC
-        if bbyte:
-            if bbyte in tenc:
-                tenc.remove(bbyte)
-            tenc.insert(0, bbyte)
-
-        for enc in ENC:
-            try:
-                decoded = txt.decode(enc)
-            except (UnicodeDecodeError, UnicodeWarning):
-                continue
-            else:
-                break
-
-        if 'enc' not in locals():
-            enc = u''
-        if decoded:
-            dev_tool.DEBUGP("[txtdecoder] Decoded text as %s" % enc)
-            return decoded, enc
+    decoded = None
+    for enc in tenc:
+        try:
+            decoded = txt.decode(enc)
+        except (UnicodeDecodeError, UnicodeWarning):
+            continue
         else:
-            dev_tool.DEBUGP("[txtdecoder][err] Decode Failed")
-            return txt, enc
+            break
+
+    if 'enc' not in locals():
+        enc = u''
+
+    if decoded:
+        dev_tool.DEBUGP("[txtdecoder] Decoded text as %s" % enc)
+        return decoded, enc
+    else:
+        dev_tool.DEBUGP("[txtdecoder][err] Decode Failed")
+        return txt, enc
 
 def FilterFiles(file_list):
     """Filters a list of paths and returns a list of paths
@@ -332,18 +325,6 @@ def FilterFiles(file_list):
                     good.append(path)
     return good
 
-def CanWrite(path):
-    """Returns whether the user has write permissions
-    to the given path.
-    @param path: path to check for writability
-
-    """
-    writable = False
-    if os.path.exists(path):
-        mode = os.stat(path)[stat.ST_MODE]
-        writable = bool(stat.S_IMODE(mode) & stat.S_IWRITE)
-    return writable
-
 def GetFileModTime(file_name):
     """Returns the time that the given file was last modified on
     @param file_name: path of file to get mtime of
@@ -458,15 +439,6 @@ def GetExtension(file_str):
     extension = pieces[-1]
     return extension
 
-def GetIds(obj_lst):
-    """Gets a list of IDs from a list of objects
-    @param obj_lst: list of objects to get ids from
-    @return: list of ids
-    @note: I believe this is no longer used anywhere and may be removed soon
-
-    """
-    return [obj.GetId() for obj in obj_lst]
-
 def ResolvAbsPath(rel_path):
     """Takes a relative path and converts it to an
     absolute path.
@@ -514,7 +486,7 @@ def MakeConfigDir(name):
     config_dir = wx.GetHomeDir() + GetPathChar() + u"." + ed_glob.PROG_NAME
     try:
         os.mkdir(config_dir + GetPathChar() + name)
-    finally:
+    except (OSError, IOError):
         pass
 
 def CreateConfigDir():
@@ -528,26 +500,22 @@ def CreateConfigDir():
     prof_dir = ed_glob.CONFIG['PROFILE_DIR']
     config_dir = u"%s%s.%s" % (wx.GetHomeDir(), pchar, ed_glob.PROG_NAME)
     profile_dir = u"%s%sprofiles" % (config_dir, pchar)
-    config_file = u"%sdefault.ppb" % prof_dir
-    loader =  u"%s.loader2" % prof_dir
     dest_file = u"%s%sdefault.ppb" % (profile_dir, pchar)
     ext_cfg = ["cache", "styles", "plugins"]
 
     #---- Create Directories ----#
     if not os.path.exists(config_dir):
         os.mkdir(config_dir)
+
     if not os.path.exists(profile_dir):
         os.mkdir(profile_dir)
+
     for cfg in ext_cfg:
         if not HasConfigDir(cfg):
             MakeConfigDir(cfg)
 
-    #---- Copy Default Config Files ----#
-    shutil.copyfile(config_file, dest_file)
-    shutil.copyfile(loader, profile_dir + pchar + u".loader2")
-
     import profiler
-    profiler.Profile().Load(dest_file)
+    profiler.Profile().LoadDefaults()
     profiler.Profile_Set("MYPROFILE", dest_file)
     profiler.UpdateProfileLoader()
 
@@ -560,6 +528,8 @@ def ResolvConfigDir(config_dir, sys_only=False):
     string.
     @param config_dir: name of config directory to resolve
     @keyword sys_only: only get paths of system config directory or user one
+    @note: This method is probably much more complex than it needs to be but
+           the code has proven itself.
 
     """
     path_char = GetPathChar()
@@ -581,8 +551,7 @@ def ResolvConfigDir(config_dir, sys_only=False):
         return path
 
     # If we get here we need to do some platform dependant lookup
-    # to find everything. This is probably much more of a mess than
-    # need be.
+    # to find everything.
     path = sys.argv[0]
 
     # If it is a link get the real path
@@ -623,8 +592,8 @@ def ResolvConfigDir(config_dir, sys_only=False):
                                              config_dir, path_char)
     else:
         pro_path = pro_path + path_char + config_dir + path_char
-    pro_path = os.path.normpath(pro_path) + path_char
-    return pro_path
+
+    return os.path.normpath(pro_path) + path_char
 
 def GetResources(resource):
     """Returns a list of resource directories from a given toplevel config dir
@@ -633,12 +602,9 @@ def GetResources(resource):
 
     """
     rec_dir = ResolvConfigDir(resource)
-    rec_lst = []
     if os.path.exists(rec_dir):
-        recs = os.listdir(rec_dir)
-        for rec in recs:
-            if os.path.isdir(rec_dir + rec) and rec[0] != u".":
-                rec_lst.append(rec.title())
+        rec_lst = [ rec.title() for rec in os.listdir(rec_dir)
+                    if os.path.isdir(rec_dir + rec) and rec[0] != u"." ]
         return rec_lst
     else:
         return -1
@@ -667,6 +633,7 @@ def GetResourceFiles(resource, trim=True, get_all=False):
         recs = os.listdir(rec_dir)
         if get_all and os.path.exists(rec_dir2):
             recs.extend(os.listdir(rec_dir2))
+
         for rec in recs:
             if os.path.isfile(rec_dir + rec) or \
               (get_all and os.path.isfile(rec_dir2 + rec)):
@@ -683,7 +650,7 @@ def Log(msg):
     """
     wx.GetApp().GetLog()(msg)
 
-# GUI helper functions
+#---- GUI helper functions ----#
 def AdjustColour(color, percent, alpha=wx.ALPHA_OPAQUE):
     """ Brighten/Darken input colour by percent and adjust alpha
     channel if needed. Returns the modified color.
@@ -701,10 +668,10 @@ def AdjustColour(color, percent, alpha=wx.ALPHA_OPAQUE):
     high = 100
 
     # We take the percent way of the color from color -. white
-    red = color.Red() + ((percent * rdif * 100) / high) / 100
-    green = color.Green() + ((percent * gdif * 100) / high) / 100
-    blue = color.Blue() + ((percent * bdif * 100) / high) / 100
-    return wx.Colour(red, green, blue, alpha)
+    red = color.Red() + ((percent * rdif) / high)
+    green = color.Green() + ((percent * gdif) / high)
+    blue = color.Blue() + ((percent * bdif) / high)
+    return wx.Colour(max(red, 0), max(green, 0), max(blue, 0), alpha)
 
 def HexToRGB(hex_str):
     """Returns a list of red/green/blue values from a
@@ -739,36 +706,7 @@ def SetWindowIcon(window):
     finally:
         pass
 
-# String Manupulation/Conversion Utilities
-def StrToTuple(tu_str):
-    """Takes a tuple of ints that has been converted to a string format and
-    reformats it back to a tuple value.
-    @param tu_str: a string of a tuple of ints i.e '(1, 4)'
-    @return: string turned into the tuple it represents
-
-    """
-    if tu_str[0] != u"(":
-        return ""
-
-    tu_str = tu_str.strip(u'(,)')
-    tu_str = tu_str.replace(u',', u'')
-    tu_str = tu_str.split()
-    neg = False
-    
-    ret_tu = list()
-    for val in tu_str:
-        # workaround of negative numbers
-        if val[0] == u'-':
-            neg = True
-
-        if val.isdigit() or neg:
-            if neg:
-                neg = False
-                ret_tu.append(int(val)*-1)
-            else:
-                ret_tu.append(int(val))
-
-    return tuple(ret_tu)
+#-----------------------------------------------------------------------------#
 
 class IntValidator(wx.PyValidator):
     """A Generic integer validator"""
@@ -797,8 +735,7 @@ class IntValidator(wx.PyValidator):
         @param win: window to validate
 
         """
-        ctrl = self.GetWindow()
-        val = ctrl.GetValue()      
+        val = win.GetValue()      
         return val.isdigit()
 
     def OnChar(self, event):
@@ -807,11 +744,8 @@ class IntValidator(wx.PyValidator):
 
         """
         key = event.GetKeyCode()
-        if key < wx.WXK_SPACE or key == wx.WXK_DELETE or key > 255:
-            event.Skip()
-            return
-
-        if chr(key) in '0123456789':
+        if key < wx.WXK_SPACE or key == wx.WXK_DELETE or \
+           key > 255 or chr(key) in '0123456789':
             event.Skip()
             return
 
